const equalFn = (a, b) => a === b;
const $PROXY = Symbol("solid-proxy");
const signalOptions = {
  equals: equalFn
};
let runEffects = runQueue;
const NOTPENDING = {};
const STALE = 1;
const PENDING = 2;
const UNOWNED = {
  owned: null,
  cleanups: null,
  context: null,
  owner: null
};
const [transPending, setTransPending] = /*@__PURE__*/createSignal(false);
var Owner = null;
let Transition = null;
let Listener = null;
let Pending = null;
let Updates = null;
let Effects = null;
let ExecCount = 0;
function createRoot(fn, detachedOwner) {
  detachedOwner && (Owner = detachedOwner);
  const listener = Listener,
        owner = Owner,
        root = fn.length === 0 && !false ? UNOWNED : {
    owned: null,
    cleanups: null,
    context: null,
    owner
  };
  Owner = root;
  Listener = null;
  let result;
  try {
    runUpdates(() => result = fn(() => cleanNode(root)), true);
  } finally {
    Listener = listener;
    Owner = owner;
  }
  return result;
}
function createSignal(value, options) {
  options = options ? Object.assign({}, signalOptions, options) : signalOptions;
  const s = {
    value,
    observers: null,
    observerSlots: null,
    pending: NOTPENDING,
    comparator: options.equals || undefined
  };
  return [readSignal.bind(s), value => {
    if (typeof value === "function") {
      value = value(s.pending !== NOTPENDING ? s.pending : s.value);
    }
    return writeSignal(s, value);
  }];
}
function createComputed(fn, value, options) {
  updateComputation(createComputation(fn, value, true, STALE));
}
function createRenderEffect(fn, value, options) {
  updateComputation(createComputation(fn, value, false, STALE));
}
function createEffect(fn, value, options) {
  runEffects = runUserEffects;
  const c = createComputation(fn, value, false, STALE);
  c.user = true;
  Effects && Effects.push(c);
}
function createMemo(fn, value, options) {
  options = options ? Object.assign({}, signalOptions, options) : signalOptions;
  const c = createComputation(fn, value, true, 0);
  c.pending = NOTPENDING;
  c.observers = null;
  c.observerSlots = null;
  c.comparator = options.equals || undefined;
  updateComputation(c);
  return readSignal.bind(c);
}
function createResource(source, fetcher, options) {
  if (arguments.length === 2) {
    if (typeof fetcher === "object") {
      options = fetcher;
      fetcher = source;
      source = true;
    }
  } else if (arguments.length === 1) {
    fetcher = source;
    source = true;
  }
  const contexts = new Set(),
        [s, set] = createSignal(options?.initialValue),
        [track, trigger] = createSignal(undefined, {
    equals: false
  }),
        [loading, setLoading] = createSignal(false),
        [error, setError] = createSignal();
  let err = undefined,
      pr = null,
      initP = null,
      dynamic = typeof source === "function";
  function loadEnd(p, v, e) {
    if (pr === p) {
      setError(err = e);
      pr = null;
      completeLoad(v);
    }
    return v;
  }
  function completeLoad(v) {
    batch(() => {
      set(() => v);
      setLoading(false);
      for (const c of contexts.keys()) c.decrement();
      contexts.clear();
    });
  }
  function read() {
    const c = SuspenseContext ,
          v = s();
    if (err) throw err;
    if (Listener && !Listener.user && c) {
      createComputed(() => {
        track();
        if (pr) {
          if (c.resolved ) ;else if (!contexts.has(c)) {
            c.increment();
            contexts.add(c);
          }
        }
      });
    }
    return v;
  }
  function load() {
    setError(err = undefined);
    const lookup = dynamic ? source() : source;
    if (lookup == null || lookup === false) {
      loadEnd(pr, untrack(s));
      return;
    }
    const p = initP || untrack(() => fetcher(lookup, s));
    initP = null;
    if (typeof p !== "object" || !("then" in p)) {
      loadEnd(pr, p);
      return;
    }
    pr = p;
    batch(() => {
      setLoading(true);
      trigger();
    });
    p.then(v => loadEnd(p, v), e => loadEnd(p, e, e));
  }
  Object.defineProperties(read, {
    loading: {
      get() {
        return loading();
      }
    },
    error: {
      get() {
        return error();
      }
    }
  });
  if (dynamic) createComputed(load);else load();
  return [read, {
    refetch: load,
    mutate: set
  }];
}
function batch(fn) {
  if (Pending) return fn();
  let result;
  const q = Pending = [];
  try {
    result = fn();
  } finally {
    Pending = null;
  }
  runUpdates(() => {
    for (let i = 0; i < q.length; i += 1) {
      const data = q[i];
      if (data.pending !== NOTPENDING) {
        const pending = data.pending;
        data.pending = NOTPENDING;
        writeSignal(data, pending);
      }
    }
  }, false);
  return result;
}
function untrack(fn) {
  let result,
      listener = Listener;
  Listener = null;
  result = fn();
  Listener = listener;
  return result;
}
function on(deps, fn, options) {
  const isArray = Array.isArray(deps);
  let prevInput;
  let defer = options && options.defer;
  return prevValue => {
    let input;
    if (isArray) {
      input = [];
      for (let i = 0; i < deps.length; i++) input.push(deps[i]());
    } else input = deps();
    if (defer) {
      defer = false;
      return undefined;
    }
    const result = untrack(() => fn(input, prevInput, prevValue));
    prevInput = input;
    return result;
  };
}
function onCleanup(fn) {
  if (Owner === null) ;else if (Owner.cleanups === null) Owner.cleanups = [fn];else Owner.cleanups.push(fn);
  return fn;
}
function getListener() {
  return Listener;
}
function getOwner() {
  return Owner;
}
function runWithOwner(o, fn) {
  const prev = Owner;
  Owner = o;
  try {
    return fn();
  } finally {
    Owner = prev;
  }
}
function startTransition(fn, cb) {
  queueMicrotask(() => {
    batch(fn);
    if (cb) cb();
  });
}
function useTransition() {
  return [transPending, startTransition];
}
function createContext(defaultValue) {
  const id = Symbol("context");
  return {
    id,
    Provider: createProvider(id),
    defaultValue
  };
}
function useContext(context) {
  return lookup(Owner, context.id) || context.defaultValue;
}
function children(fn) {
  const children = createMemo(fn);
  return createMemo(() => resolveChildren(children()));
}
let SuspenseContext;
function readSignal() {
  if (this.state && this.sources) {
    const updates = Updates;
    Updates = null;
    this.state === STALE || Transition   ? updateComputation(this) : lookDownstream(this);
    Updates = updates;
  }
  if (Listener) {
    const sSlot = this.observers ? this.observers.length : 0;
    if (!Listener.sources) {
      Listener.sources = [this];
      Listener.sourceSlots = [sSlot];
    } else {
      Listener.sources.push(this);
      Listener.sourceSlots.push(sSlot);
    }
    if (!this.observers) {
      this.observers = [Listener];
      this.observerSlots = [Listener.sources.length - 1];
    } else {
      this.observers.push(Listener);
      this.observerSlots.push(Listener.sources.length - 1);
    }
  }
  return this.value;
}
function writeSignal(node, value, isComp) {
  if (node.comparator) {
    if (node.comparator(node.value, value)) return value;
  }
  if (Pending) {
    if (node.pending === NOTPENDING) Pending.push(node);
    node.pending = value;
    return value;
  }
  let TransitionRunning = false;
  node.value = value;
  if (node.observers && node.observers.length) {
    runUpdates(() => {
      for (let i = 0; i < node.observers.length; i += 1) {
        const o = node.observers[i];
        if (TransitionRunning && Transition.disposed.has(o)) ;
        if (o.pure) Updates.push(o);else Effects.push(o);
        if (o.observers && (TransitionRunning && !o.tState || !TransitionRunning && !o.state)) markUpstream(o);
        if (TransitionRunning) ;else o.state = STALE;
      }
      if (Updates.length > 10e5) {
        Updates = [];
        if (false) ;
        throw new Error();
      }
    }, false);
  }
  return value;
}
function updateComputation(node) {
  if (!node.fn) return;
  cleanNode(node);
  const owner = Owner,
        listener = Listener,
        time = ExecCount;
  Listener = Owner = node;
  runComputation(node, node.value, time);
  Listener = listener;
  Owner = owner;
}
function runComputation(node, value, time) {
  let nextValue;
  try {
    nextValue = node.fn(value);
  } catch (err) {
    handleError(err);
  }
  if (!node.updatedAt || node.updatedAt <= time) {
    if (node.observers && node.observers.length) {
      writeSignal(node, nextValue);
    } else node.value = nextValue;
    node.updatedAt = time;
  }
}
function createComputation(fn, init, pure, state = STALE, options) {
  const c = {
    fn,
    state: state,
    updatedAt: null,
    owned: null,
    sources: null,
    sourceSlots: null,
    cleanups: null,
    value: init,
    owner: Owner,
    context: null,
    pure
  };
  if (Owner === null) ;else if (Owner !== UNOWNED) {
    {
      if (!Owner.owned) Owner.owned = [c];else Owner.owned.push(c);
    }
  }
  return c;
}
function runTop(node) {
  const runningTransition = Transition ;
  if (node.state !== STALE) return node.state = 0;
  if (node.suspense && untrack(node.suspense.inFallback)) return node.suspense.effects.push(node);
  const ancestors = [node];
  while ((node = node.owner) && (!node.updatedAt || node.updatedAt < ExecCount)) {
    if (node.state || runningTransition ) ancestors.push(node);
  }
  for (let i = ancestors.length - 1; i >= 0; i--) {
    node = ancestors[i];
    if (node.state === STALE || runningTransition ) {
      updateComputation(node);
    } else if (node.state === PENDING || runningTransition ) {
      const updates = Updates;
      Updates = null;
      lookDownstream(node);
      Updates = updates;
    }
  }
}
function runUpdates(fn, init) {
  if (Updates) return fn();
  let wait = false;
  if (!init) Updates = [];
  if (Effects) wait = true;else Effects = [];
  ExecCount++;
  try {
    fn();
  } catch (err) {
    handleError(err);
  } finally {
    completeUpdates(wait);
  }
}
function completeUpdates(wait) {
  if (Updates) {
    runQueue(Updates);
    Updates = null;
  }
  if (wait) return;
  if (Effects.length) batch(() => {
    runEffects(Effects);
    Effects = null;
  });else {
    Effects = null;
  }
}
function runQueue(queue) {
  for (let i = 0; i < queue.length; i++) runTop(queue[i]);
}
function runUserEffects(queue) {
  let i,
      userLength = 0;
  for (i = 0; i < queue.length; i++) {
    const e = queue[i];
    if (!e.user) runTop(e);else queue[userLength++] = e;
  }
  const resume = queue.length;
  for (i = 0; i < userLength; i++) runTop(queue[i]);
  for (i = resume; i < queue.length; i++) runTop(queue[i]);
}
function lookDownstream(node) {
  node.state = 0;
  for (let i = 0; i < node.sources.length; i += 1) {
    const source = node.sources[i];
    if (source.sources) {
      if (source.state === STALE || Transition  ) runTop(source);else if (source.state === PENDING) lookDownstream(source);
    }
  }
}
function markUpstream(node) {
  const runningTransition = Transition ;
  for (let i = 0; i < node.observers.length; i += 1) {
    const o = node.observers[i];
    if (!o.state || runningTransition ) {
      o.state = PENDING;
      if (o.pure) Updates.push(o);else Effects.push(o);
      o.observers && markUpstream(o);
    }
  }
}
function cleanNode(node) {
  let i;
  if (node.sources) {
    while (node.sources.length) {
      const source = node.sources.pop(),
            index = node.sourceSlots.pop(),
            obs = source.observers;
      if (obs && obs.length) {
        const n = obs.pop(),
              s = source.observerSlots.pop();
        if (index < obs.length) {
          n.sourceSlots[s] = index;
          obs[index] = n;
          source.observerSlots[index] = s;
        }
      }
    }
  }
  if (node.owned) {
    for (i = 0; i < node.owned.length; i++) cleanNode(node.owned[i]);
    node.owned = null;
  }
  if (node.cleanups) {
    for (i = 0; i < node.cleanups.length; i++) node.cleanups[i]();
    node.cleanups = null;
  }
  node.state = 0;
  node.context = null;
}
function handleError(err) {
  throw err;
}
function lookup(owner, key) {
  return owner && (owner.context && owner.context[key] || owner.owner && lookup(owner.owner, key));
}
function resolveChildren(children) {
  if (typeof children === "function" && !children.length) return resolveChildren(children());
  if (Array.isArray(children)) {
    const results = [];
    for (let i = 0; i < children.length; i++) {
      const result = resolveChildren(children[i]);
      Array.isArray(result) ? results.push.apply(results, result) : results.push(result);
    }
    return results;
  }
  return children;
}
function createProvider(id) {
  return function provider(props) {
    let res;
    createComputed(() => res = untrack(() => {
      Owner.context = {
        [id]: props.value
      };
      return children(() => props.children);
    }));
    return res;
  };
}

const FALLBACK = Symbol("fallback");
function dispose(d) {
  for (let i = 0; i < d.length; i++) d[i]();
}
function mapArray(list, mapFn, options = {}) {
  let items = [],
      mapped = [],
      disposers = [],
      len = 0,
      indexes = mapFn.length > 1 ? [] : null;
  onCleanup(() => dispose(disposers));
  return () => {
    let newItems = list() || [],
        i,
        j;
    return untrack(() => {
      let newLen = newItems.length,
          newIndices,
          newIndicesNext,
          temp,
          tempdisposers,
          tempIndexes,
          start,
          end,
          newEnd,
          item;
      if (newLen === 0) {
        if (len !== 0) {
          dispose(disposers);
          disposers = [];
          items = [];
          mapped = [];
          len = 0;
          indexes && (indexes = []);
        }
        if (options.fallback) {
          items = [FALLBACK];
          mapped[0] = createRoot(disposer => {
            disposers[0] = disposer;
            return options.fallback();
          });
          len = 1;
        }
      }
      else if (len === 0) {
        mapped = new Array(newLen);
        for (j = 0; j < newLen; j++) {
          items[j] = newItems[j];
          mapped[j] = createRoot(mapper);
        }
        len = newLen;
      } else {
        temp = new Array(newLen);
        tempdisposers = new Array(newLen);
        indexes && (tempIndexes = new Array(newLen));
        for (start = 0, end = Math.min(len, newLen); start < end && items[start] === newItems[start]; start++);
        for (end = len - 1, newEnd = newLen - 1; end >= start && newEnd >= start && items[end] === newItems[newEnd]; end--, newEnd--) {
          temp[newEnd] = mapped[end];
          tempdisposers[newEnd] = disposers[end];
          indexes && (tempIndexes[newEnd] = indexes[end]);
        }
        newIndices = new Map();
        newIndicesNext = new Array(newEnd + 1);
        for (j = newEnd; j >= start; j--) {
          item = newItems[j];
          i = newIndices.get(item);
          newIndicesNext[j] = i === undefined ? -1 : i;
          newIndices.set(item, j);
        }
        for (i = start; i <= end; i++) {
          item = items[i];
          j = newIndices.get(item);
          if (j !== undefined && j !== -1) {
            temp[j] = mapped[i];
            tempdisposers[j] = disposers[i];
            indexes && (tempIndexes[j] = indexes[i]);
            j = newIndicesNext[j];
            newIndices.set(item, j);
          } else disposers[i]();
        }
        for (j = start; j < newLen; j++) {
          if (j in temp) {
            mapped[j] = temp[j];
            disposers[j] = tempdisposers[j];
            if (indexes) {
              indexes[j] = tempIndexes[j];
              indexes[j](j);
            }
          } else mapped[j] = createRoot(mapper);
        }
        mapped = mapped.slice(0, len = newLen);
        items = newItems.slice(0);
      }
      return mapped;
    });
    function mapper(disposer) {
      disposers[j] = disposer;
      if (indexes) {
        const [s, set] = createSignal(j);
        indexes[j] = set;
        return mapFn(newItems[j], s);
      }
      return mapFn(newItems[j]);
    }
  };
}

function createComponent(Comp, props) {
  return untrack(() => Comp(props));
}
function trueFn() {
  return true;
}
const propTraps = {
  get(_, property, receiver) {
    if (property === $PROXY) return receiver;
    return _.get(property);
  },
  has(_, property) {
    return _.has(property);
  },
  set: trueFn,
  deleteProperty: trueFn,
  getOwnPropertyDescriptor(_, property) {
    return {
      configurable: true,
      enumerable: true,
      get() {
        return _.get(property);
      },
      set: trueFn,
      deleteProperty: trueFn
    };
  },
  ownKeys(_) {
    return _.keys();
  }
};
function mergeProps(...sources) {
  return new Proxy({
    get(property) {
      for (let i = sources.length - 1; i >= 0; i--) {
        const v = sources[i][property];
        if (v !== undefined) return v;
      }
    },
    has(property) {
      for (let i = sources.length - 1; i >= 0; i--) {
        if (property in sources[i]) return true;
      }
      return false;
    },
    keys() {
      const keys = [];
      for (let i = 0; i < sources.length; i++) keys.push(...Object.keys(sources[i]));
      return [...new Set(keys)];
    }
  }, propTraps);
}
function splitProps(props, ...keys) {
  const blocked = new Set(keys.flat());
  const descriptors = Object.getOwnPropertyDescriptors(props);
  const res = keys.map(k => {
    const clone = {};
    for (let i = 0; i < k.length; i++) {
      const key = k[i];
      Object.defineProperty(clone, key, descriptors[key] ? descriptors[key] : {
        get() {
          return props[key];
        }
      });
    }
    return clone;
  });
  res.push(new Proxy({
    get(property) {
      return blocked.has(property) ? undefined : props[property];
    },
    has(property) {
      return blocked.has(property) ? false : property in props;
    },
    keys() {
      return Object.keys(props).filter(k => !blocked.has(k));
    }
  }, propTraps));
  return res;
}

function For(props) {
  const fallback = "fallback" in props && {
    fallback: () => props.fallback
  };
  return createMemo(mapArray(() => props.each, props.children, fallback ? fallback : undefined));
}
function Show(props) {
  let strictEqual = false;
  const condition = createMemo(() => props.when, undefined, {
    equals: (a, b) => strictEqual ? a === b : !a === !b
  });
  return createMemo(() => {
    const c = condition();
    if (c) {
      const child = props.children;
      return (strictEqual = typeof child === "function" && child.length > 0) ? untrack(() => child(c)) : child;
    }
    return props.fallback;
  });
}
function Switch(props) {
  let strictEqual = false;
  const conditions = children(() => props.children),
        evalConditions = createMemo(() => {
    let conds = conditions();
    if (!Array.isArray(conds)) conds = [conds];
    for (let i = 0; i < conds.length; i++) {
      const c = conds[i].when;
      if (c) return [i, c, conds[i]];
    }
    return [-1];
  }, undefined, {
    equals: (a, b) => a && a[0] === b[0] && (strictEqual ? a[1] === b[1] : !a[1] === !b[1]) && a[2] === b[2]
  });
  return createMemo(() => {
    const [index, when, cond] = evalConditions();
    if (index < 0) return props.fallback;
    const c = cond.children;
    return (strictEqual = typeof c === "function" && c.length > 0) ? untrack(() => c(when)) : c;
  });
}
function Match(props) {
  return props;
}

const booleans = ["allowfullscreen", "async", "autofocus", "autoplay", "checked", "controls", "default", "disabled", "formnovalidate", "hidden", "indeterminate", "ismap", "loop", "multiple", "muted", "nomodule", "novalidate", "open", "playsinline", "readonly", "required", "reversed", "seamless", "selected"];
const Properties = new Set(["className", "value", "readOnly", "formNoValidate", "isMap", "noModule", "playsInline", ...booleans]);
const ChildProperties = new Set(["innerHTML", "textContent", "innerText", "children"]);
const Aliases = {
  className: "class",
  htmlFor: "for"
};
const PropAliases = {
  class: "className",
  formnovalidate: "formNoValidate",
  ismap: "isMap",
  nomodule: "noModule",
  playsinline: "playsInline",
  readonly: "readOnly"
};
const DelegatedEvents = new Set(["beforeinput", "click", "dblclick", "focusin", "focusout", "input", "keydown", "keyup", "mousedown", "mousemove", "mouseout", "mouseover", "mouseup", "pointerdown", "pointermove", "pointerout", "pointerover", "pointerup", "touchend", "touchmove", "touchstart"]);
const SVGElements = new Set([
"altGlyph", "altGlyphDef", "altGlyphItem", "animate", "animateColor", "animateMotion", "animateTransform", "circle", "clipPath", "color-profile", "cursor", "defs", "desc", "ellipse", "feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence", "filter", "font", "font-face", "font-face-format", "font-face-name", "font-face-src", "font-face-uri", "foreignObject", "g", "glyph", "glyphRef", "hkern", "image", "line", "linearGradient", "marker", "mask", "metadata", "missing-glyph", "mpath", "path", "pattern", "polygon", "polyline", "radialGradient", "rect",
"set", "stop",
"svg", "switch", "symbol", "text", "textPath",
"tref", "tspan", "use", "view", "vkern"]);
const SVGNamespace = {
  xlink: "http://www.w3.org/1999/xlink",
  xml: "http://www.w3.org/XML/1998/namespace"
};

function memo(fn, equals) {
  return createMemo(fn, undefined, !equals ? {
    equals
  } : undefined);
}

function reconcileArrays(parentNode, a, b) {
  let bLength = b.length,
      aEnd = a.length,
      bEnd = bLength,
      aStart = 0,
      bStart = 0,
      after = a[aEnd - 1].nextSibling,
      map = null;
  while (aStart < aEnd || bStart < bEnd) {
    if (a[aStart] === b[bStart]) {
      aStart++;
      bStart++;
      continue;
    }
    while (a[aEnd - 1] === b[bEnd - 1]) {
      aEnd--;
      bEnd--;
    }
    if (aEnd === aStart) {
      const node = bEnd < bLength ? bStart ? b[bStart - 1].nextSibling : b[bEnd - bStart] : after;
      while (bStart < bEnd) parentNode.insertBefore(b[bStart++], node);
    } else if (bEnd === bStart) {
      while (aStart < aEnd) {
        if (!map || !map.has(a[aStart])) parentNode.removeChild(a[aStart]);
        aStart++;
      }
    } else if (a[aStart] === b[bEnd - 1] && b[bStart] === a[aEnd - 1]) {
      const node = a[--aEnd].nextSibling;
      parentNode.insertBefore(b[bStart++], a[aStart++].nextSibling);
      parentNode.insertBefore(b[--bEnd], node);
      a[aEnd] = b[bEnd];
    } else {
      if (!map) {
        map = new Map();
        let i = bStart;
        while (i < bEnd) map.set(b[i], i++);
      }
      const index = map.get(a[aStart]);
      if (index != null) {
        if (bStart < index && index < bEnd) {
          let i = aStart,
              sequence = 1,
              t;
          while (++i < aEnd && i < bEnd) {
            if ((t = map.get(a[i])) == null || t !== index + sequence) break;
            sequence++;
          }
          if (sequence > index - bStart) {
            const node = a[aStart];
            while (bStart < index) parentNode.insertBefore(b[bStart++], node);
          } else parentNode.replaceChild(b[bStart++], a[aStart++]);
        } else aStart++;
      } else parentNode.removeChild(a[aStart++]);
    }
  }
}

const $$EVENTS = "_$DX_DELEGATE";
function template(html, check, isSVG) {
  const t = document.createElement("template");
  t.innerHTML = html;
  let node = t.content.firstChild;
  if (isSVG) node = node.firstChild;
  return node;
}
function delegateEvents(eventNames, document = window.document) {
  const e = document[$$EVENTS] || (document[$$EVENTS] = new Set());
  for (let i = 0, l = eventNames.length; i < l; i++) {
    const name = eventNames[i];
    if (!e.has(name)) {
      e.add(name);
      document.addEventListener(name, eventHandler);
    }
  }
}
function setAttribute(node, name, value) {
  if (value == null) node.removeAttribute(name);else node.setAttribute(name, value);
}
function setAttributeNS(node, namespace, name, value) {
  if (value == null) node.removeAttributeNS(namespace, name);else node.setAttributeNS(namespace, name, value);
}
function addEventListener(node, name, handler, delegate) {
  if (delegate) {
    if (Array.isArray(handler)) {
      node[`$$${name}`] = handler[0];
      node[`$$${name}Data`] = handler[1];
    } else node[`$$${name}`] = handler;
  } else if (Array.isArray(handler)) {
    node.addEventListener(name, e => handler[0](handler[1], e));
  } else node.addEventListener(name, handler);
}
function classList(node, value, prev = {}) {
  const classKeys = Object.keys(value || {}),
        prevKeys = Object.keys(prev);
  let i, len;
  for (i = 0, len = prevKeys.length; i < len; i++) {
    const key = prevKeys[i];
    if (!key || key === "undefined" || value[key]) continue;
    toggleClassKey(node, key, false);
    delete prev[key];
  }
  for (i = 0, len = classKeys.length; i < len; i++) {
    const key = classKeys[i],
          classValue = !!value[key];
    if (!key || key === "undefined" || prev[key] === classValue || !classValue) continue;
    toggleClassKey(node, key, true);
    prev[key] = classValue;
  }
  return prev;
}
function style(node, value, prev = {}) {
  const nodeStyle = node.style;
  if (value == null || typeof value === "string") return nodeStyle.cssText = value;
  typeof prev === "string" && (prev = {});
  let v, s;
  for (s in prev) {
    value[s] == null && nodeStyle.removeProperty(s);
    delete prev[s];
  }
  for (s in value) {
    v = value[s];
    if (v !== prev[s]) {
      nodeStyle.setProperty(s, v);
      prev[s] = v;
    }
  }
  return prev;
}
function spread(node, accessor, isSVG, skipChildren) {
  if (typeof accessor === "function") {
    createRenderEffect(current => spreadExpression(node, accessor(), current, isSVG, skipChildren));
  } else spreadExpression(node, accessor, undefined, isSVG, skipChildren);
}
function insert(parent, accessor, marker, initial) {
  if (marker !== undefined && !initial) initial = [];
  if (typeof accessor !== "function") return insertExpression(parent, accessor, initial, marker);
  createRenderEffect(current => insertExpression(parent, accessor(), current, marker), initial);
}
function assign(node, props, isSVG, skipChildren, prevProps = {}) {
  let isCE, isProp, isChildProp;
  for (const prop in props) {
    if (prop === "children") {
      if (!skipChildren) insertExpression(node, props.children);
      continue;
    }
    const value = props[prop];
    if (value === prevProps[prop]) continue;
    if (prop === "style") {
      style(node, value, prevProps[prop]);
    } else if (prop === "classList") {
      classList(node, value, prevProps[prop]);
    } else if (prop === "ref") {
      value(node);
    } else if (prop.slice(0, 3) === "on:") {
      node.addEventListener(prop.slice(3), value);
    } else if (prop.slice(0, 10) === "oncapture:") {
      node.addEventListener(prop.slice(10), value, true);
    } else if (prop.slice(0, 2) === "on") {
      const name = prop.slice(2).toLowerCase();
      const delegate = DelegatedEvents.has(name);
      addEventListener(node, name, value, delegate);
      delegate && delegateEvents([name]);
    } else if ((isChildProp = ChildProperties.has(prop)) || !isSVG && (PropAliases[prop] || (isProp = Properties.has(prop))) || (isCE = node.nodeName.includes("-"))) {
      if (isCE && !isProp && !isChildProp) node[toPropertyName(prop)] = value;else node[PropAliases[prop] || prop] = value;
    } else {
      const ns = isSVG && prop.indexOf(":") > -1 && SVGNamespace[prop.split(":")[0]];
      if (ns) setAttributeNS(node, ns, prop, value);else setAttribute(node, Aliases[prop] || prop, value);
    }
    prevProps[prop] = value;
  }
}
function toPropertyName(name) {
  return name.toLowerCase().replace(/-([a-z])/g, (_, w) => w.toUpperCase());
}
function toggleClassKey(node, key, value) {
  const classNames = key.trim().split(/\s+/);
  for (let i = 0, nameLen = classNames.length; i < nameLen; i++) node.classList.toggle(classNames[i], value);
}
function eventHandler(e) {
  const key = `$$${e.type}`;
  let node = e.composedPath && e.composedPath()[0] || e.target;
  if (e.target !== node) {
    Object.defineProperty(e, "target", {
      configurable: true,
      value: node
    });
  }
  Object.defineProperty(e, "currentTarget", {
    configurable: true,
    get() {
      return node;
    }
  });
  while (node !== null) {
    const handler = node[key];
    if (handler && !node.disabled) {
      const data = node[`${key}Data`];
      data !== undefined ? handler(data, e) : handler(e);
      if (e.cancelBubble) return;
    }
    node = node.host && node.host !== node && node.host instanceof Node ? node.host : node.parentNode;
  }
}
function spreadExpression(node, props, prevProps = {}, isSVG, skipChildren) {
  if (!skipChildren && "children" in props) {
    createRenderEffect(() => prevProps.children = insertExpression(node, props.children, prevProps.children));
  }
  createRenderEffect(() => assign(node, props, isSVG, true, prevProps));
  return prevProps;
}
function insertExpression(parent, value, current, marker, unwrapArray) {
  while (typeof current === "function") current = current();
  if (value === current) return current;
  const t = typeof value,
        multi = marker !== undefined;
  parent = multi && current[0] && current[0].parentNode || parent;
  if (t === "string" || t === "number") {
    if (t === "number") value = value.toString();
    if (multi) {
      let node = current[0];
      if (node && node.nodeType === 3) {
        node.data = value;
      } else node = document.createTextNode(value);
      current = cleanChildren(parent, current, marker, node);
    } else {
      if (current !== "" && typeof current === "string") {
        current = parent.firstChild.data = value;
      } else current = parent.textContent = value;
    }
  } else if (value == null || t === "boolean") {
    current = cleanChildren(parent, current, marker);
  } else if (t === "function") {
    createRenderEffect(() => {
      let v = value();
      while (typeof v === "function") v = v();
      current = insertExpression(parent, v, current, marker);
    });
    return () => current;
  } else if (Array.isArray(value)) {
    const array = [];
    if (normalizeIncomingArray(array, value, unwrapArray)) {
      createRenderEffect(() => current = insertExpression(parent, array, current, marker, true));
      return () => current;
    }
    if (array.length === 0) {
      current = cleanChildren(parent, current, marker);
      if (multi) return current;
    } else {
      if (Array.isArray(current)) {
        if (current.length === 0) {
          appendNodes(parent, array, marker);
        } else reconcileArrays(parent, current, array);
      } else if (current == null || current === "") {
        appendNodes(parent, array);
      } else {
        reconcileArrays(parent, multi && current || [parent.firstChild], array);
      }
    }
    current = array;
  } else if (value instanceof Node) {
    if (Array.isArray(current)) {
      if (multi) return current = cleanChildren(parent, current, marker, value);
      cleanChildren(parent, current, null, value);
    } else if (current == null || current === "" || !parent.firstChild) {
      parent.appendChild(value);
    } else parent.replaceChild(value, parent.firstChild);
    current = value;
  } else ;
  return current;
}
function normalizeIncomingArray(normalized, array, unwrap) {
  let dynamic = false;
  for (let i = 0, len = array.length; i < len; i++) {
    let item = array[i],
        t;
    if (item instanceof Node) {
      normalized.push(item);
    } else if (item == null || item === true || item === false) ; else if (Array.isArray(item)) {
      dynamic = normalizeIncomingArray(normalized, item) || dynamic;
    } else if ((t = typeof item) === "string") {
      normalized.push(document.createTextNode(item));
    } else if (t === "function") {
      if (unwrap) {
        while (typeof item === "function") item = item();
        dynamic = normalizeIncomingArray(normalized, Array.isArray(item) ? item : [item]) || dynamic;
      } else {
        normalized.push(item);
        dynamic = true;
      }
    } else normalized.push(document.createTextNode(item.toString()));
  }
  return dynamic;
}
function appendNodes(parent, array, marker) {
  for (let i = 0, len = array.length; i < len; i++) parent.insertBefore(array[i], marker);
}
function cleanChildren(parent, current, marker, replacement) {
  if (marker === undefined) return parent.textContent = "";
  const node = replacement || document.createTextNode("");
  if (current.length) {
    let inserted = false;
    for (let i = current.length - 1; i >= 0; i--) {
      const el = current[i];
      if (node !== el) {
        const isParent = el.parentNode === parent;
        if (!inserted && !i) isParent ? parent.replaceChild(node, el) : parent.insertBefore(node, marker);else isParent && parent.removeChild(el);
      } else inserted = true;
    }
  } else parent.insertBefore(node, marker);
  return [node];
}
const SVG_NAMESPACE = "http://www.w3.org/2000/svg";
function createElement(tagName, isSVG = false) {
  return isSVG ? document.createElementNS(SVG_NAMESPACE, tagName) : document.createElement(tagName);
}
function Dynamic(props) {
  const [p, others] = splitProps(props, ["component"]);
  return createMemo(() => {
    const component = p.component;
    switch (typeof component) {
      case "function":
        return untrack(() => component(others));
      case "string":
        const isSvg = SVGElements.has(component);
        const el = createElement(component, isSvg);
        spread(el, others, isSvg);
        return el;
    }
  });
}

function cloneProps(props) {
  const propKeys = Object.keys(props);
  return propKeys.reduce((memo, k) => {
    const prop = props[k];
    memo[k] = Object.assign({}, prop);
    if (isObject$4(prop.value) && !isFunction(prop.value) && !Array.isArray(prop.value)) memo[k].value = Object.assign({}, prop.value);
    if (Array.isArray(prop.value)) memo[k].value = prop.value.slice(0);
    return memo;
  }, {});
}

function normalizePropDefs(props) {
  if (!props) return {};
  const propKeys = Object.keys(props);
  return propKeys.reduce((memo, k) => {
    const v = props[k];
    memo[k] = !(isObject$4(v) && "value" in v) ? {
      value: v
    } : v;
    memo[k].attribute || (memo[k].attribute = toAttribute(k));
    return memo;
  }, {});
}
function propValues(props) {
  const propKeys = Object.keys(props);
  return propKeys.reduce((memo, k) => {
    memo[k] = props[k].value;
    return memo;
  }, {});
}
function initializeProps(element, propDefinition) {
  const props = cloneProps(propDefinition),
        propKeys = Object.keys(propDefinition);
  propKeys.forEach(key => {
    const prop = props[key],
          attr = element.getAttribute(prop.attribute),
          value = element[key];
    if (attr) prop.value = parseAttributeValue(attr);
    if (value != null) prop.value = Array.isArray(value) ? value.slice(0) : value;
    reflect(element, prop.attribute, prop.value);
    Object.defineProperty(element, key, {
      get() {
        return prop.value;
      },

      set(val) {
        const oldValue = prop.value;
        prop.value = val;
        reflect(this, prop.attribute, prop.value);

        for (let i = 0, l = this.__propertyChangedCallbacks.length; i < l; i++) {
          this.__propertyChangedCallbacks[i](key, val, oldValue);
        }
      },

      enumerable: true,
      configurable: true
    });
  });
  return props;
}
function parseAttributeValue(value) {
  if (!value) return;
  let parsed;

  try {
    parsed = JSON.parse(value);
  } catch (err) {
    parsed = value;
  }

  if (!(typeof parsed === "string")) return parsed;
  if (/^[0-9]*$/.test(parsed)) return +parsed;
  return parsed;
}
function reflect(node, attribute, value) {
  if (isObject$4(value)) return;
  let reflect = value ? typeof value.toString === "function" ? value.toString() : undefined : undefined;

  if (reflect && reflect !== "false") {
    node.__updating[attribute] = true;
    if (reflect === "true") reflect = "";
    node.setAttribute(attribute, reflect);
    Promise.resolve().then(() => delete node.__updating[attribute]);
  } else node.removeAttribute(attribute);
}
function toAttribute(propName) {
  return propName.replace(/\.?([A-Z]+)/g, (x, y) => "-" + y.toLowerCase()).replace("_", "-").replace(/^-/, "");
}
function isObject$4(obj) {
  return obj != null && (typeof obj === "object" || typeof obj === "function");
}
function isFunction(val) {
  return Object.prototype.toString.call(val) === "[object Function]";
}
function isConstructor(f) {
  return typeof f === "function" && f.toString().indexOf("class") === 0;
}

let currentElement;
function createElementType(BaseElement, propDefinition) {
  const propKeys = Object.keys(propDefinition);
  return class CustomElement extends BaseElement {
    static get observedAttributes() {
      return propKeys.map(k => propDefinition[k].attribute);
    }

    constructor() {
      super();
      this.__initialized = false;
      this.__released = false;
      this.__releaseCallbacks = [];
      this.__propertyChangedCallbacks = [];
      this.__updating = {};
      this.props = {};
    }

    connectedCallback() {
      // check that infact it connected since polyfill sometimes double calls
      if (!this.isConnected || this.__initialized) return;
      this.__releaseCallbacks = [];
      this.__propertyChangedCallbacks = [];
      this.__updating = {};
      this.props = initializeProps(this, propDefinition);
      const props = propValues(this.props),
            ComponentType = this.Component,
            outerElement = currentElement;

      try {
        currentElement = this;
        this.__initialized = true;
        if (isConstructor(ComponentType)) new ComponentType(props, {
          element: this
        });else ComponentType(props, {
          element: this
        });
      } finally {
        currentElement = outerElement;
      }
    }

    async disconnectedCallback() {
      // prevent premature releasing when element is only temporarely removed from DOM
      await Promise.resolve();
      if (this.isConnected) return;
      this.__propertyChangedCallbacks.length = 0;
      let callback = null;

      while (callback = this.__releaseCallbacks.pop()) callback(this);

      delete this.__initialized;
      this.__released = true;
    }

    attributeChangedCallback(name, oldVal, newVal) {
      if (!this.__initialized) return;
      if (this.__updating[name]) return;
      name = this.lookupProp(name);

      if (name in propDefinition) {
        if (newVal == null && !this[name]) return;
        this[name] = parseAttributeValue(newVal);
      }
    }

    lookupProp(attrName) {
      if (!propDefinition) return;
      return propKeys.find(k => attrName === k || attrName === propDefinition[k].attribute);
    }

    get renderRoot() {
      return this.shadowRoot || this.attachShadow({
        mode: "open"
      });
    }

    addReleaseCallback(fn) {
      this.__releaseCallbacks.push(fn);
    }

    addPropertyChangedCallback(fn) {
      this.__propertyChangedCallbacks.push(fn);
    }

  };
}

function register(tag, props = {}, options = {}) {
  const {
    BaseElement = HTMLElement,
    extension
  } = options;
  return ComponentType => {
    if (!tag) throw new Error("tag is required to register a Component");
    let ElementType = customElements.get(tag);

    if (ElementType) {
      // Consider disabling this in a production mode
      ElementType.prototype.Component = ComponentType;
      return ElementType;
    }

    ElementType = createElementType(BaseElement, normalizePropDefs(props));
    ElementType.prototype.Component = ComponentType;
    ElementType.prototype.registeredTag = tag;
    customElements.define(tag, ElementType, extension);
    return ElementType;
  };
}

function createProps(raw) {
    const keys = Object.keys(raw);
    const props = {};
    for (let i = 0; i < keys.length; i++) {
        const [get, set] = createSignal(raw[keys[i]]);
        Object.defineProperty(props, keys[i], {
            get,
            set(v) { set(() => v); }
        });
    }
    return props;
}
function withSolid(ComponentType) {
    return (rawProps, options) => {
        const { element } = options;
        return createRoot((dispose) => {
            const props = createProps(rawProps);
            element.addPropertyChangedCallback((key, val) => (props[key] = val));
            element.addReleaseCallback(() => {
                element.renderRoot.textContent = "";
                dispose();
            });
            const comp = ComponentType(props, options);
            return insert(element.renderRoot, comp);
        }, (element.assignedSlot && element.assignedSlot._$owner) || element._$owner);
    };
}
function customElement(tag, props, ComponentType) {
    if (arguments.length === 2) {
        ComponentType = props;
        props = {};
    }
    return register(tag, props)(withSolid(ComponentType));
}

function bindEvent(target, type, handler) {
    target.addEventListener(type, handler);
    return () => target.removeEventListener(type, handler);
}
function intercept([value, setValue], get, set) {
    return [get ? () => get(value()) : value, set ? (v) => setValue(set(v)) : setValue];
}
function createIntegration(get, set, init, utils) {
    let ignore = false;
    const signal = intercept(createSignal({ value: get() }, { equals: (a, b) => a.value === b.value }), undefined, next => {
        !ignore && set(next);
        return next;
    });
    init &&
        onCleanup(init((value = get()) => {
            ignore = true;
            signal[1]({ value });
            ignore = false;
        }));
    return {
        signal,
        utils
    };
}
function normalizeIntegration(integration) {
    if (!integration) {
        return {
            signal: createSignal({ value: "" })
        };
    }
    else if (Array.isArray(integration)) {
        return {
            signal: integration
        };
    }
    return integration;
}
function pathIntegration() {
    return createIntegration(() => window.location.pathname + window.location.search + window.location.hash, ({ value, replace }) => {
        if (replace) {
            window.history.replaceState(null, "", value);
        }
        else {
            window.history.pushState(null, "", value);
        }
        window.scrollTo(0, 0);
    }, notify => bindEvent(window, "popstate", () => notify()));
}

const hasSchemeRegex = /^(?:[a-z0-9]+:)?\/\//i;
const trimPathRegex = /^\/+|\/+$|\s+/;
function normalize(path) {
    const s = path.replace(trimPathRegex, "");
    return s ? "/" + s : "";
}
function resolvePath(base, path, from) {
    if (hasSchemeRegex.test(path)) {
        return undefined;
    }
    const basePath = normalize(base);
    const fromPath = from && normalize(from);
    let result = "";
    if (!fromPath || path.charAt(0) === "/") {
        result = basePath;
    }
    else if (fromPath.toLowerCase().indexOf(basePath.toLowerCase()) !== 0) {
        result = basePath + fromPath;
    }
    else {
        result = fromPath;
    }
    return result + normalize(path) || "/";
}
function invariant(value, message) {
    if (value == null) {
        throw new Error(message);
    }
    return value;
}
function joinPaths(from, to) {
    return `${from.replace(/[/*]+$/, "")}/${to.replace(/^\/+/, "")}`;
}
function extractQuery(url) {
    const query = {};
    url.searchParams.forEach((value, key) => {
        query[key] = value;
    });
    return query;
}
function createMatcher(path, partial) {
    const [pattern, splat] = path.split("/*", 2);
    const segments = pattern.split("/").filter(Boolean);
    const len = segments.length;
    return (location) => {
        const locSegments = location.split("/").filter(Boolean);
        const lenDiff = locSegments.length - len;
        if (lenDiff < 0 || (lenDiff > 0 && splat === undefined && !partial)) {
            return null;
        }
        const match = {
            path: len ? "" : "/",
            params: {}
        };
        for (let i = 0; i < len; i++) {
            const segment = segments[i];
            const locSegment = locSegments[i];
            if (segment[0] === ":") {
                match.params[segment.slice(1)] = locSegment;
            }
            else if (segment.localeCompare(locSegment, undefined, { sensitivity: 'base' }) !== 0) {
                return null;
            }
            match.path += `/${locSegment}`;
        }
        if (splat) {
            match.params[splat] = lenDiff ? locSegments.slice(-lenDiff).join("/") : "";
        }
        return match;
    };
}
function scoreRoute(route) {
    const [pattern, splat] = route.pattern.split("/*", 2);
    const segments = pattern.split("/").filter(Boolean);
    return segments.reduce((score, segment) => score + (segment.startsWith(":") ? 2 : 3), segments.length - (splat === undefined ? 0 : 1));
}
function createMemoObject(fn) {
    const map = new Map();
    const owner = getOwner();
    return new Proxy({}, {
        get(_, property) {
            const memo = map.get(property) ||
                runWithOwner(owner, () => {
                    const p = createMemo(() => fn()[property]);
                    map.set(property, p);
                    return p;
                });
            return memo();
        }
    });
}

const MAX_REDIRECTS = 100;
const RouterContextObj = createContext();
const RouteContextObj = createContext();
const useRouter = () => invariant(useContext(RouterContextObj), "Make sure your app is wrapped in a <Router />");
const useRoute = () => useContext(RouteContextObj) || useRouter().base;
const useResolvedPath = (path) => {
    const route = useRoute();
    return createMemo(() => route.resolvePath(path()));
};
const useHref = (to) => {
    const router = useRouter();
    return createMemo(() => {
        const to_ = to();
        return to_ !== undefined ? router.renderPath(to_) : to_;
    });
};
const useNavigate = () => useRouter().navigatorFactory();
const useData = (delta = 0) => {
    let current = useRoute();
    let n = delta;
    while (n-- > 0) {
        if (!current.parent) {
            throw new RangeError(`Route ancestor ${delta} is out of bounds`);
        }
        current = current.parent;
    }
    return current.data;
};
function createRoute(routeDef, base = "", fallback) {
    const { path: originalPath, component, data, children } = routeDef;
    const isLeaf = !children || (Array.isArray(children) && !children.length);
    const path = joinPaths(base, originalPath);
    const pattern = isLeaf ? path : path.split("/*", 1)[0];
    return {
        originalPath,
        pattern,
        element: component
            ? () => createComponent(component, {})
            : () => {
                const { element } = routeDef;
                return element === undefined && fallback
                    ? createComponent(fallback, {})
                    : element;
            },
        preload: routeDef.component
            ? component.preload
            : routeDef.preload,
        data,
        matcher: createMatcher(pattern, !isLeaf)
    };
}
function createBranch(routes, index = 0) {
    return {
        routes,
        score: scoreRoute(routes[routes.length - 1]) * 10000 - index,
        matcher(location) {
            const matches = [];
            for (let i = routes.length - 1; i >= 0; i--) {
                const route = routes[i];
                const match = route.matcher(location);
                if (!match) {
                    return null;
                }
                matches.unshift({
                    ...match,
                    route
                });
            }
            return matches;
        }
    };
}
function createBranches(routeDef, base = "", fallback, stack = [], branches = []) {
    const routeDefs = Array.isArray(routeDef) ? routeDef : [routeDef];
    for (let i = 0, len = routeDefs.length; i < len; i++) {
        const def = routeDefs[i];
        const route = createRoute(def, base, fallback);
        stack.push(route);
        if (def.children) {
            createBranches(def.children, route.pattern, fallback, stack, branches);
        }
        else {
            const branch = createBranch([...stack], branches.length);
            branches.push(branch);
        }
        stack.pop();
    }
    // Stack will be empty on final return
    return stack.length ? branches : branches.sort((a, b) => b.score - a.score);
}
function getRouteMatches(branches, location) {
    for (let i = 0, len = branches.length; i < len; i++) {
        const match = branches[i].matcher(location);
        if (match) {
            return match;
        }
    }
    return [];
}
function createLocation(path) {
    const origin = new URL("http://sar");
    const url = createMemo(prev => {
        const path_ = path();
        try {
            return new URL(path_, origin);
        }
        catch (err) {
            console.error(`Invalid path ${path_}`);
            return prev;
        }
    }, origin, {
        equals: (a, b) => a.href === b.href
    });
    const pathname = createMemo(() => url().pathname);
    const search = createMemo(() => url().search.slice(1));
    const hash = createMemo(() => url().hash.slice(1));
    const state = createMemo(() => null);
    const key = createMemo(() => "");
    return {
        get pathname() {
            return pathname();
        },
        get search() {
            return search();
        },
        get hash() {
            return hash();
        },
        get state() {
            return state();
        },
        get key() {
            return key();
        },
        query: createMemoObject(on(search, () => extractQuery(url())))
    };
}
function createRouterContext(integration, base = "", data, out) {
    const { signal: [source, setSource], utils } = normalizeIntegration(integration);
    const basePath = resolvePath("", base);
    const output = undefined;
    if (basePath === undefined) {
        throw new Error(`${basePath} is not a valid base path`);
    }
    else if (basePath && !source().value) {
        setSource({ value: basePath, replace: true });
    }
    const [isRouting, start] = useTransition();
    const [reference, setReference] = createSignal(source().value);
    const location = createLocation(reference);
    const referrers = [];
    const baseRoute = {
        pattern: basePath,
        params: {},
        path: () => basePath,
        outlet: () => null,
        resolvePath(to) {
            return resolvePath(basePath, to);
        }
    };
    if (data) {
        baseRoute.data = data({ params: {}, location, navigate: navigatorFactory(baseRoute) });
    }
    function navigateFromRoute(route, to, options) {
        // Untrack in case someone navigates in an effect - don't want to track `reference` or route paths
        untrack(() => {
            if (typeof to === "number") {
                console.warn("Relative navigation is not implemented - doing nothing :)");
                return;
            }
            const { replace, resolve } = {
                replace: false,
                resolve: true,
                ...options
            };
            const resolvedTo = resolve ? route.resolvePath(to) : resolvePath("", to);
            if (resolvedTo === undefined) {
                throw new Error(`Path '${to}' is not a routable path`);
            }
            else if (referrers.length >= MAX_REDIRECTS) {
                throw new Error("Too many redirects");
            }
            const current = reference();
            if (resolvedTo !== current) {
                {
                    const len = referrers.push({ value: current, replace });
                    start(() => setReference(resolvedTo), () => {
                        if (referrers.length === len) {
                            navigateEnd(resolvedTo);
                        }
                    });
                }
            }
        });
    }
    function navigatorFactory(route) {
        // Workaround for vite issue (https://github.com/vitejs/vite/issues/3803)
        route = route || useContext(RouteContextObj) || baseRoute;
        return (to, options) => navigateFromRoute(route, to, options);
    }
    function navigateEnd(next) {
        const first = referrers[0];
        if (first) {
            if (next !== first.value) {
                setSource({
                    value: next,
                    replace: first.replace
                });
            }
            referrers.length = 0;
        }
    }
    createRenderEffect(() => {
        const next = source().value;
        if (next !== untrack(reference)) {
            start(() => setReference(next));
        }
    });
    return {
        base: baseRoute,
        out: output,
        location,
        isRouting,
        renderPath: (utils && utils.renderPath) || ((path) => path),
        navigatorFactory
    };
}
function createRouteContext(router, parent, child, match) {
    const { base, location, navigatorFactory } = router;
    const { pattern, element: outlet, preload, data } = match().route;
    const path = createMemo(() => match().path);
    const params = createMemoObject(() => match().params);
    preload && preload();
    const route = {
        parent,
        pattern,
        get child() {
            return child();
        },
        path,
        params,
        outlet,
        resolvePath(to) {
            return resolvePath(base.path(), to, path());
        }
    };
    if (data) {
        route.data = data({ params, location, navigate: navigatorFactory(route) });
    }
    return route;
}

const _tmpl$$k = template(`<a></a>`);
const Router = props => {
  const {
    source,
    url,
    base,
    data,
    out
  } = props;
  const integration = source || (pathIntegration());
  const routerState = createRouterContext(integration, base, data);
  return createComponent(RouterContextObj.Provider, {
    value: routerState,

    get children() {
      return props.children;
    }

  });
};
const Routes = props => {
  const router = useRouter();
  const parentRoute = useRoute();
  const basePath = useResolvedPath(() => props.base || "");
  const branches = createMemo(() => createBranches(props.children, basePath() || "", Outlet));
  const matches = createMemo(() => getRouteMatches(branches(), router.location.pathname));

  if (router.out) {
    router.out.matches.push(matches().map(({
      route,
      path,
      params
    }) => ({
      originalPath: route.originalPath,
      pattern: route.pattern,
      path,
      params
    })));
  }

  const disposers = [];
  let root;
  const routeStates = createMemo(on(matches, (nextMatches, prevMatches, prev) => {
    let equal = prevMatches && nextMatches.length === prevMatches.length;
    const next = [];

    for (let i = 0, len = nextMatches.length; i < len; i++) {
      const prevMatch = prevMatches && prevMatches[i];
      const nextMatch = nextMatches[i];

      if (prev && prevMatch && nextMatch.route.pattern === prevMatch.route.pattern) {
        next[i] = prev[i];
      } else {
        equal = false;

        if (disposers[i]) {
          disposers[i]();
        }

        createRoot(dispose => {
          disposers[i] = dispose;
          next[i] = createRouteContext(router, next[i - 1] || parentRoute, () => routeStates()[i + 1], () => matches()[i]);
        });
      }
    }

    disposers.splice(nextMatches.length).forEach(dispose => dispose());

    if (prev && equal) {
      return prev;
    }

    root = next[0];
    return next;
  }));
  return createComponent(Show, {
    get when() {
      return routeStates() && root;
    },

    children: route => createComponent(RouteContextObj.Provider, {
      value: route,

      get children() {
        return route.outlet();
      }

    })
  });
};
const useRoutes = (routes, base) => {
  return () => createComponent(Routes, {
    base: base,
    children: routes
  });
};
const Outlet = () => {
  const route = useRoute();
  return createComponent(Show, {
    get when() {
      return route.child;
    },

    children: child => createComponent(RouteContextObj.Provider, {
      value: child,

      get children() {
        return child.outlet();
      }

    })
  });
};

function LinkBase(props) {
  const [, rest] = splitProps(props, ["children", "to", "href", "onClick"]);
  const navigate = useNavigate();
  const href = useHref(() => props.to);

  const handleClick = evt => {
    const {
      onClick,
      to,
      target
    } = props;

    if (typeof onClick === "function") {
      onClick(evt);
    } else if (onClick) {
      onClick[0](onClick[1], evt);
    }

    if (to !== undefined && !evt.defaultPrevented && evt.button === 0 && (!target || target === "_self") && !(evt.metaKey || evt.altKey || evt.ctrlKey || evt.shiftKey)) {
      evt.preventDefault();
      navigate(to, {
        resolve: false,
        replace: props.replace || false
      });
    }
  };

  return (() => {
    const _el$ = _tmpl$$k.cloneNode(true);

    _el$.$$click = handleClick;

    spread(_el$, rest, false, true);

    insert(_el$, () => props.children);

    createRenderEffect(() => setAttribute(_el$, "href", href() || props.href));

    return _el$;
  })();
}

function Link(props) {
  const to = useResolvedPath(() => props.href);
  return createComponent(LinkBase, mergeProps(props, {
    get to() {
      return to();
    }

  }));
}

delegateEvents(["click"]);

var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */

function isObject$3(value) {
  var type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

var isObject_1 = isObject$3;

/** Detect free variable `global` from Node.js. */

var freeGlobal$1 = typeof commonjsGlobal == 'object' && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;

var _freeGlobal = freeGlobal$1;

var freeGlobal = _freeGlobal;

/** Detect free variable `self`. */
var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

/** Used as a reference to the global object. */
var root$2 = freeGlobal || freeSelf || Function('return this')();

var _root = root$2;

var root$1 = _root;

/**
 * Gets the timestamp of the number of milliseconds that have elapsed since
 * the Unix epoch (1 January 1970 00:00:00 UTC).
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Date
 * @returns {number} Returns the timestamp.
 * @example
 *
 * _.defer(function(stamp) {
 *   console.log(_.now() - stamp);
 * }, _.now());
 * // => Logs the number of milliseconds it took for the deferred invocation.
 */
var now$1 = function() {
  return root$1.Date.now();
};

var now_1 = now$1;

/** Used to match a single whitespace character. */

var reWhitespace = /\s/;

/**
 * Used by `_.trim` and `_.trimEnd` to get the index of the last non-whitespace
 * character of `string`.
 *
 * @private
 * @param {string} string The string to inspect.
 * @returns {number} Returns the index of the last non-whitespace character.
 */
function trimmedEndIndex$1(string) {
  var index = string.length;

  while (index-- && reWhitespace.test(string.charAt(index))) {}
  return index;
}

var _trimmedEndIndex = trimmedEndIndex$1;

var trimmedEndIndex = _trimmedEndIndex;

/** Used to match leading whitespace. */
var reTrimStart = /^\s+/;

/**
 * The base implementation of `_.trim`.
 *
 * @private
 * @param {string} string The string to trim.
 * @returns {string} Returns the trimmed string.
 */
function baseTrim$1(string) {
  return string
    ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, '')
    : string;
}

var _baseTrim = baseTrim$1;

var root = _root;

/** Built-in value references. */
var Symbol$3 = root.Symbol;

var _Symbol = Symbol$3;

var Symbol$2 = _Symbol;

/** Used for built-in method references. */
var objectProto$1 = Object.prototype;

/** Used to check objects for own properties. */
var hasOwnProperty = objectProto$1.hasOwnProperty;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString$1 = objectProto$1.toString;

/** Built-in value references. */
var symToStringTag$1 = Symbol$2 ? Symbol$2.toStringTag : undefined;

/**
 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the raw `toStringTag`.
 */
function getRawTag$1(value) {
  var isOwn = hasOwnProperty.call(value, symToStringTag$1),
      tag = value[symToStringTag$1];

  try {
    value[symToStringTag$1] = undefined;
    var unmasked = true;
  } catch (e) {}

  var result = nativeObjectToString$1.call(value);
  if (unmasked) {
    if (isOwn) {
      value[symToStringTag$1] = tag;
    } else {
      delete value[symToStringTag$1];
    }
  }
  return result;
}

var _getRawTag = getRawTag$1;

/** Used for built-in method references. */

var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var nativeObjectToString = objectProto.toString;

/**
 * Converts `value` to a string using `Object.prototype.toString`.
 *
 * @private
 * @param {*} value The value to convert.
 * @returns {string} Returns the converted string.
 */
function objectToString$1(value) {
  return nativeObjectToString.call(value);
}

var _objectToString = objectToString$1;

var Symbol$1 = _Symbol,
    getRawTag = _getRawTag,
    objectToString = _objectToString;

/** `Object#toString` result references. */
var nullTag = '[object Null]',
    undefinedTag = '[object Undefined]';

/** Built-in value references. */
var symToStringTag = Symbol$1 ? Symbol$1.toStringTag : undefined;

/**
 * The base implementation of `getTag` without fallbacks for buggy environments.
 *
 * @private
 * @param {*} value The value to query.
 * @returns {string} Returns the `toStringTag`.
 */
function baseGetTag$1(value) {
  if (value == null) {
    return value === undefined ? undefinedTag : nullTag;
  }
  return (symToStringTag && symToStringTag in Object(value))
    ? getRawTag(value)
    : objectToString(value);
}

var _baseGetTag = baseGetTag$1;

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */

function isObjectLike$1(value) {
  return value != null && typeof value == 'object';
}

var isObjectLike_1 = isObjectLike$1;

var baseGetTag = _baseGetTag,
    isObjectLike = isObjectLike_1;

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol$1(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && baseGetTag(value) == symbolTag);
}

var isSymbol_1 = isSymbol$1;

var baseTrim = _baseTrim,
    isObject$2 = isObject_1,
    isSymbol = isSymbol_1;

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber$1(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject$2(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject$2(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = baseTrim(value);
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

var toNumber_1 = toNumber$1;

var isObject$1 = isObject_1,
    now = now_1,
    toNumber = toNumber_1;

/** Error message constants. */
var FUNC_ERROR_TEXT = 'Expected a function';

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax = Math.max,
    nativeMin = Math.min;

/**
 * Creates a debounced function that delays invoking `func` until after `wait`
 * milliseconds have elapsed since the last time the debounced function was
 * invoked. The debounced function comes with a `cancel` method to cancel
 * delayed `func` invocations and a `flush` method to immediately invoke them.
 * Provide `options` to indicate whether `func` should be invoked on the
 * leading and/or trailing edge of the `wait` timeout. The `func` is invoked
 * with the last arguments provided to the debounced function. Subsequent
 * calls to the debounced function return the result of the last `func`
 * invocation.
 *
 * **Note:** If `leading` and `trailing` options are `true`, `func` is
 * invoked on the trailing edge of the timeout only if the debounced function
 * is invoked more than once during the `wait` timeout.
 *
 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
 *
 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
 * for details over the differences between `_.debounce` and `_.throttle`.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to debounce.
 * @param {number} [wait=0] The number of milliseconds to delay.
 * @param {Object} [options={}] The options object.
 * @param {boolean} [options.leading=false]
 *  Specify invoking on the leading edge of the timeout.
 * @param {number} [options.maxWait]
 *  The maximum time `func` is allowed to be delayed before it's invoked.
 * @param {boolean} [options.trailing=true]
 *  Specify invoking on the trailing edge of the timeout.
 * @returns {Function} Returns the new debounced function.
 * @example
 *
 * // Avoid costly calculations while the window size is in flux.
 * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
 *
 * // Invoke `sendMail` when clicked, debouncing subsequent calls.
 * jQuery(element).on('click', _.debounce(sendMail, 300, {
 *   'leading': true,
 *   'trailing': false
 * }));
 *
 * // Ensure `batchLog` is invoked once after 1 second of debounced calls.
 * var debounced = _.debounce(batchLog, 250, { 'maxWait': 1000 });
 * var source = new EventSource('/stream');
 * jQuery(source).on('message', debounced);
 *
 * // Cancel the trailing debounced invocation.
 * jQuery(window).on('popstate', debounced.cancel);
 */
function debounce(func, wait, options) {
  var lastArgs,
      lastThis,
      maxWait,
      result,
      timerId,
      lastCallTime,
      lastInvokeTime = 0,
      leading = false,
      maxing = false,
      trailing = true;

  if (typeof func != 'function') {
    throw new TypeError(FUNC_ERROR_TEXT);
  }
  wait = toNumber(wait) || 0;
  if (isObject$1(options)) {
    leading = !!options.leading;
    maxing = 'maxWait' in options;
    maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
    trailing = 'trailing' in options ? !!options.trailing : trailing;
  }

  function invokeFunc(time) {
    var args = lastArgs,
        thisArg = lastThis;

    lastArgs = lastThis = undefined;
    lastInvokeTime = time;
    result = func.apply(thisArg, args);
    return result;
  }

  function leadingEdge(time) {
    // Reset any `maxWait` timer.
    lastInvokeTime = time;
    // Start the timer for the trailing edge.
    timerId = setTimeout(timerExpired, wait);
    // Invoke the leading edge.
    return leading ? invokeFunc(time) : result;
  }

  function remainingWait(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime,
        timeWaiting = wait - timeSinceLastCall;

    return maxing
      ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke)
      : timeWaiting;
  }

  function shouldInvoke(time) {
    var timeSinceLastCall = time - lastCallTime,
        timeSinceLastInvoke = time - lastInvokeTime;

    // Either this is the first call, activity has stopped and we're at the
    // trailing edge, the system time has gone backwards and we're treating
    // it as the trailing edge, or we've hit the `maxWait` limit.
    return (lastCallTime === undefined || (timeSinceLastCall >= wait) ||
      (timeSinceLastCall < 0) || (maxing && timeSinceLastInvoke >= maxWait));
  }

  function timerExpired() {
    var time = now();
    if (shouldInvoke(time)) {
      return trailingEdge(time);
    }
    // Restart the timer.
    timerId = setTimeout(timerExpired, remainingWait(time));
  }

  function trailingEdge(time) {
    timerId = undefined;

    // Only invoke if we have `lastArgs` which means `func` has been
    // debounced at least once.
    if (trailing && lastArgs) {
      return invokeFunc(time);
    }
    lastArgs = lastThis = undefined;
    return result;
  }

  function cancel() {
    if (timerId !== undefined) {
      clearTimeout(timerId);
    }
    lastInvokeTime = 0;
    lastArgs = lastCallTime = lastThis = timerId = undefined;
  }

  function flush() {
    return timerId === undefined ? result : trailingEdge(now());
  }

  function debounced() {
    var time = now(),
        isInvoking = shouldInvoke(time);

    lastArgs = arguments;
    lastThis = this;
    lastCallTime = time;

    if (isInvoking) {
      if (timerId === undefined) {
        return leadingEdge(lastCallTime);
      }
      if (maxing) {
        // Handle invocations in a tight loop.
        clearTimeout(timerId);
        timerId = setTimeout(timerExpired, wait);
        return invokeFunc(lastCallTime);
      }
    }
    if (timerId === undefined) {
      timerId = setTimeout(timerExpired, wait);
    }
    return result;
  }
  debounced.cancel = cancel;
  debounced.flush = flush;
  return debounced;
}

var debounce_1 = debounce;

var extendStatics=function(e,t){return (extendStatics=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t;}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r]);})(e,t)};function __extends(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=e;}extendStatics(e,t),e.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r);}var util,__assign=function(){return (__assign=Object.assign||function(e){for(var t,r=1,n=arguments.length;r<n;r++)for(var a in t=arguments[r])Object.prototype.hasOwnProperty.call(t,a)&&(e[a]=t[a]);return e}).apply(this,arguments)};function __awaiter(e,s,i,u){return new(i=i||Promise)(function(r,t){function n(e){try{o(u.next(e));}catch(e){t(e);}}function a(e){try{o(u.throw(e));}catch(e){t(e);}}function o(e){var t;e.done?r(e.value):((t=e.value)instanceof i?t:new i(function(e){e(t);})).then(n,a);}o((u=u.apply(e,s||[])).next());})}function __generator(r,n){var a,o,s,i={label:0,sent:function(){if(1&s[0])throw s[1];return s[1]},trys:[],ops:[]},e={next:t(0),throw:t(1),return:t(2)};return "function"==typeof Symbol&&(e[Symbol.iterator]=function(){return this}),e;function t(t){return function(e){return function(t){if(a)throw new TypeError("Generator is already executing.");for(;i;)try{if(a=1,o&&(s=2&t[0]?o.return:t[0]?o.throw||((s=o.return)&&s.call(o),0):o.next)&&!(s=s.call(o,t[1])).done)return s;switch(o=0,(t=s?[2&t[0],s.value]:t)[0]){case 0:case 1:s=t;break;case 4:return i.label++,{value:t[1],done:!1};case 5:i.label++,o=t[1],t=[0];continue;case 7:t=i.ops.pop(),i.trys.pop();continue;default:if(!(s=0<(s=i.trys).length&&s[s.length-1])&&(6===t[0]||2===t[0])){i=0;continue}if(3===t[0]&&(!s||t[1]>s[0]&&t[1]<s[3])){i.label=t[1];break}if(6===t[0]&&i.label<s[1]){i.label=s[1],s=t;break}if(s&&i.label<s[2]){i.label=s[2],i.ops.push(t);break}s[2]&&i.ops.pop(),i.trys.pop();continue}t=n.call(r,i);}catch(e){t=[6,e],o=0;}finally{a=s=0;}if(5&t[0])throw t[1];return {value:t[0]?t[1]:void 0,done:!0}}([t,e])}}}function __values(e){var t="function"==typeof Symbol&&Symbol.iterator,r=t&&e[t],n=0;if(r)return r.call(e);if(e&&"number"==typeof e.length)return {next:function(){return {value:(e=e&&n>=e.length?void 0:e)&&e[n++],done:!e}}};throw new TypeError(t?"Object is not iterable.":"Symbol.iterator is not defined.")}function __read(e,t){var r="function"==typeof Symbol&&e[Symbol.iterator];if(!r)return e;var n,a,o=r.call(e),s=[];try{for(;(void 0===t||0<t--)&&!(n=o.next()).done;)s.push(n.value);}catch(e){a={error:e};}finally{try{n&&!n.done&&(r=o.return)&&r.call(o);}finally{if(a)throw a.error}}return s}function __spreadArray(e,t,r){if(r||2===arguments.length)for(var n,a=0,o=t.length;a<o;a++)!n&&a in t||((n=n||Array.prototype.slice.call(t,0,a))[a]=t[a]);return e.concat(n||Array.prototype.slice.call(t))}!function(u){u.assertNever=function(e){throw new Error},u.arrayToEnum=function(e){var t,r,n={};try{for(var a=__values(e),o=a.next();!o.done;o=a.next()){var s=o.value;n[s]=s;}}catch(e){t={error:e};}finally{try{o&&!o.done&&(r=a.return)&&r.call(a);}finally{if(t)throw t.error}}return n},u.getValidEnumValues=function(t){var r,e,n=u.objectKeys(t).filter(function(e){return "number"!=typeof t[t[e]]}),a={};try{for(var o=__values(n),s=o.next();!s.done;s=o.next()){var i=s.value;a[i]=t[i];}}catch(e){r={error:e};}finally{try{s&&!s.done&&(e=o.return)&&e.call(o);}finally{if(r)throw r.error}}return u.objectValues(a)},u.objectValues=function(t){return u.objectKeys(t).map(function(e){return t[e]})},u.objectKeys="function"==typeof Object.keys?function(e){return Object.keys(e)}:function(e){var t,r=[];for(t in e)Object.prototype.hasOwnProperty.call(e,t)&&r.push(t);return r},u.find=function(e,t){var r,n;try{for(var a=__values(e),o=a.next();!o.done;o=a.next()){var s=o.value;if(t(s))return s}}catch(e){r={error:e};}finally{try{o&&!o.done&&(n=a.return)&&n.call(a);}finally{if(r)throw r.error}}},u.isInteger="function"==typeof Number.isInteger?function(e){return Number.isInteger(e)}:function(e){return "number"==typeof e&&isFinite(e)&&Math.floor(e)===e};}(util=util||{});var ZodIssueCode=util.arrayToEnum(["invalid_type","custom","invalid_union","invalid_enum_value","unrecognized_keys","invalid_arguments","invalid_return_type","invalid_date","invalid_string","too_small","too_big","invalid_intersection_types","not_multiple_of"]),quotelessJson=function(e){return JSON.stringify(e,null,2).replace(/"([^"]+)":/g,"$1:")},ZodError=function(r){function t(e){var t=this.constructor,u=r.call(this)||this;u.issues=[],u.format=function(){var p={_errors:[]},c=function(e){var t,r;try{for(var n=__values(e.issues),a=n.next();!a.done;a=n.next()){var o=a.value;if("invalid_union"===o.code)o.unionErrors.map(c);else if("invalid_return_type"===o.code)c(o.returnTypeError);else if("invalid_arguments"===o.code)c(o.argumentsError);else if(0===o.path.length)p._errors.push(o.message);else for(var s=p,i=0;i<o.path.length;){var u,d=o.path[i];i===o.path.length-1?(s[d]=s[d]||{_errors:[]},s[d]._errors.push(o.message)):"string"==typeof d?s[d]=s[d]||{_errors:[]}:"number"==typeof d&&((u=[])._errors=[],s[d]=s[d]||u),s=s[d],i++;}}}catch(e){t={error:e};}finally{try{a&&!a.done&&(r=n.return)&&r.call(n);}finally{if(t)throw t.error}}};return c(u),p},u.addIssue=function(e){u.issues=__spreadArray(__spreadArray([],__read(u.issues),!1),[e],!1);},u.addIssues=function(e){void 0===e&&(e=[]),u.issues=__spreadArray(__spreadArray([],__read(u.issues),!1),__read(e),!1);},u.flatten=function(e){var t,r;void 0===e&&(e=function(e){return e.message});var n={},a=[];try{for(var o=__values(u.issues),s=o.next();!s.done;s=o.next()){var i=s.value;0<i.path.length?(n[i.path[0]]=n[i.path[0]]||[],n[i.path[0]].push(e(i))):a.push(e(i));}}catch(e){t={error:e};}finally{try{s&&!s.done&&(r=o.return)&&r.call(o);}finally{if(t)throw t.error}}return {formErrors:a,fieldErrors:n}};t=t.prototype;return Object.setPrototypeOf?Object.setPrototypeOf(u,t):u.__proto__=t,u.name="ZodError",u.issues=e,u}return __extends(t,r),Object.defineProperty(t.prototype,"errors",{get:function(){return this.issues},enumerable:!1,configurable:!0}),t.prototype.toString=function(){return this.message},Object.defineProperty(t.prototype,"message",{get:function(){return JSON.stringify(this.issues,null,2)},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isEmpty",{get:function(){return 0===this.issues.length},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"formErrors",{get:function(){return this.flatten()},enumerable:!1,configurable:!0}),t.create=function(e){return new t(e)},t}(Error),defaultErrorMap=function(e,t){var r;switch(e.code){case ZodIssueCode.invalid_type:r="undefined"===e.received?"Required":"Expected "+e.expected+", received "+e.received;break;case ZodIssueCode.unrecognized_keys:r="Unrecognized key(s) in object: "+e.keys.map(function(e){return "'"+e+"'"}).join(", ");break;case ZodIssueCode.invalid_union:r="Invalid input";break;case ZodIssueCode.invalid_enum_value:r="Invalid enum value. Expected "+e.options.map(function(e){return "string"==typeof e?"'"+e+"'":e}).join(" | ")+", received "+("string"==typeof t.data?"'"+t.data+"'":t.data);break;case ZodIssueCode.invalid_arguments:r="Invalid function arguments";break;case ZodIssueCode.invalid_return_type:r="Invalid function return type";break;case ZodIssueCode.invalid_date:r="Invalid date";break;case ZodIssueCode.invalid_string:r="regex"!==e.validation?"Invalid "+e.validation:"Invalid";break;case ZodIssueCode.too_small:r="array"===e.type?"Should have "+(e.inclusive?"at least":"more than")+" "+e.minimum+" items":"string"===e.type?"Should be "+(e.inclusive?"at least":"over")+" "+e.minimum+" characters":"number"===e.type?"Value should be greater than "+(e.inclusive?"or equal to ":"")+e.minimum:"Invalid input";break;case ZodIssueCode.too_big:r="array"===e.type?"Should have "+(e.inclusive?"at most":"less than")+" "+e.maximum+" items":"string"===e.type?"Should be "+(e.inclusive?"at most":"under")+" "+e.maximum+" characters long":"number"===e.type?"Value should be less than "+(e.inclusive?"or equal to ":"")+e.maximum:"Invalid input";break;case ZodIssueCode.custom:r="Invalid input";break;case ZodIssueCode.invalid_intersection_types:r="Intersection results could not be merged";break;case ZodIssueCode.not_multiple_of:r="Should be multiple of "+e.multipleOf;break;default:r=t.defaultError,util.assertNever(e);}return {message:r}},overrideErrorMap=defaultErrorMap,setErrorMap=function(e){overrideErrorMap=e;},ZodParsedType=util.arrayToEnum(["string","nan","number","integer","float","boolean","date","bigint","symbol","function","undefined","null","array","object","unknown","promise","void","never","map","set"]);function cacheAndReturn(e,t,r){return r&&r.set(e,t),t}var getParsedType=function(e,t){if(t&&t.has(e))return t.get(e);switch(typeof e){case"undefined":return cacheAndReturn(e,ZodParsedType.undefined,t);case"string":return cacheAndReturn(e,ZodParsedType.string,t);case"number":return cacheAndReturn(e,isNaN(e)?ZodParsedType.nan:ZodParsedType.number,t);case"boolean":return cacheAndReturn(e,ZodParsedType.boolean,t);case"function":return cacheAndReturn(e,ZodParsedType.function,t);case"bigint":return cacheAndReturn(e,ZodParsedType.bigint,t);case"object":return Array.isArray(e)?cacheAndReturn(e,ZodParsedType.array,t):null===e?cacheAndReturn(e,ZodParsedType.null,t):e.then&&"function"==typeof e.then&&e.catch&&"function"==typeof e.catch?cacheAndReturn(e,ZodParsedType.promise,t):e instanceof Map?cacheAndReturn(e,ZodParsedType.map,t):e instanceof Set?cacheAndReturn(e,ZodParsedType.set,t):e instanceof Date?cacheAndReturn(e,ZodParsedType.date,t):cacheAndReturn(e,ZodParsedType.object,t);default:return cacheAndReturn(e,ZodParsedType.unknown,t)}},makeIssue=function(e){var t,r,n=e.data,a=e.path,o=e.errorMaps,e=e.issueData,a=__spreadArray(__spreadArray([],__read(a),!1),__read(e.path||[]),!1),s=__assign(__assign({},e),{path:a}),i="",o=o.filter(function(e){return !!e}).slice().reverse();try{for(var u=__values(o),d=u.next();!d.done;d=u.next())i=(0,d.value)(s,{data:n,defaultError:i}).message;}catch(e){t={error:e};}finally{try{d&&!d.done&&(r=u.return)&&r.call(u);}finally{if(t)throw t.error}}return __assign(__assign({},e),{path:a,message:e.message||i})},EMPTY_PATH=[];function addIssueToContext(e,t){t=makeIssue({issueData:t,data:e.data,path:e.path,errorMaps:[e.contextualErrorMap,e.schemaErrorMap,overrideErrorMap,defaultErrorMap].filter(function(e){return !!e})});e.issues.push(t);}var errorUtil,ParseStatus=function(){function l(){this.value="valid";}return l.prototype.dirty=function(){"valid"===this.value&&(this.value="dirty");},l.prototype.abort=function(){"aborted"!==this.value&&(this.value="aborted");},l.mergeArray=function(e,t){var r,n,a=[];try{for(var o=__values(t),s=o.next();!s.done;s=o.next()){var i=s.value;if("aborted"===i.status)return INVALID;"dirty"===i.status&&e.dirty(),a.push(i.value);}}catch(e){r={error:e};}finally{try{s&&!s.done&&(n=o.return)&&n.call(o);}finally{if(r)throw r.error}}return {status:e.value,value:a}},l.mergeObjectAsync=function(p,c){return __awaiter(this,void 0,void 0,function(){var t,r,n,a,o,s,i,u,d;return __generator(this,function(e){switch(e.label){case 0:t=[],e.label=1;case 1:e.trys.push([1,7,8,9]),r=__values(c),n=r.next(),e.label=2;case 2:return n.done?[3,6]:(a=n.value,s=(o=t).push,d={},[4,a.key]);case 3:return d.key=e.sent(),[4,a.value];case 4:s.apply(o,[(d.value=e.sent(),d)]),e.label=5;case 5:return n=r.next(),[3,2];case 6:return [3,9];case 7:return i=e.sent(),i={error:i},[3,9];case 8:try{n&&!n.done&&(u=r.return)&&u.call(r);}finally{if(i)throw i.error}return [7];case 9:return [2,l.mergeObjectSync(p,t)]}})})},l.mergeObjectSync=function(e,t){var r,n,a={};try{for(var o=__values(t),s=o.next();!s.done;s=o.next()){var i=s.value,u=i.key,d=i.value;if("aborted"===u.status)return INVALID;if("aborted"===d.status)return INVALID;"dirty"===u.status&&e.dirty(),"dirty"===d.status&&e.dirty(),void 0===d.value&&!i.alwaysSet||(a[u.value]=d.value);}}catch(e){r={error:e};}finally{try{s&&!s.done&&(n=o.return)&&n.call(o);}finally{if(r)throw r.error}}return {status:e.value,value:a}},l}(),INVALID=Object.freeze({status:"aborted"}),DIRTY=function(e){return {status:"dirty",value:e}},OK=function(e){return {status:"valid",value:e}},isAborted=function(e){return "aborted"===e.status},isDirty=function(e){return "dirty"===e.status},isValid=function(e){return "valid"===e.status},isAsync=function(e){return e instanceof Promise};!function(e){e.errToObj=function(e){return "string"==typeof e?{message:e}:e||{}},e.toString=function(e){return "string"==typeof e?e:null==e?void 0:e.message};}(errorUtil=errorUtil||{});var handleResult=function(e,t){if(isValid(t))return {success:!0,data:t.value};if(!e.issues.length)throw new Error("Validation failed but no issues detected.");return {success:!1,error:new ZodError(e.issues)}};function processCreateParams(r){if(!r)return {};if(r.errorMap&&(r.invalid_type_error||r.required_error))throw new Error('Can\'t use "invalid" or "required" in conjunction with custom error map.');if(r.errorMap)return {errorMap:r.errorMap};return {errorMap:function(e,t){return "invalid_type"!==e.code?{message:t.defaultError}:void 0===t.data&&r.required_error?{message:r.required_error}:r.invalid_type_error?{message:r.invalid_type_error}:{message:t.defaultError}}}}var objectUtil,ZodType=function(){function e(e){this.spa=this.safeParseAsync,this.superRefine=this._refinement,this._def=e,this.transform=this.transform.bind(this),this.default=this.default.bind(this);}return Object.defineProperty(e.prototype,"description",{get:function(){return this._def.description},enumerable:!1,configurable:!0}),e.prototype._processInputParams=function(e){return {status:new ParseStatus,ctx:__assign(__assign({},e.parent),{data:e.data,parsedType:getParsedType(e.data,e.parent.typeCache),schemaErrorMap:this._def.errorMap,path:e.path,parent:e.parent})}},e.prototype._parseSync=function(e){e=this._parse(e);if(isAsync(e))throw new Error("Synchronous parse encountered promise.");return e},e.prototype._parseAsync=function(e){e=this._parse(e);return Promise.resolve(e)},e.prototype.parse=function(e,t){t=this.safeParse(e,t);if(t.success)return t.data;throw t.error},e.prototype.safeParse=function(e,t){t={path:(null==t?void 0:t.path)||[],issues:[],contextualErrorMap:null==t?void 0:t.errorMap,schemaErrorMap:this._def.errorMap,async:null!==(t=null==t?void 0:t.async)&&void 0!==t&&t,typeCache:new Map,parent:null,data:e,parsedType:getParsedType(e)},e=this._parseSync({data:e,path:t.path,parent:t});return handleResult(t,e)},e.prototype.parseAsync=function(r,n){return __awaiter(this,void 0,void 0,function(){var t;return __generator(this,function(e){switch(e.label){case 0:return [4,this.safeParseAsync(r,n)];case 1:if((t=e.sent()).success)return [2,t.data];throw t.error}})})},e.prototype.safeParseAsync=function(n,a){return __awaiter(this,void 0,void 0,function(){var t,r;return __generator(this,function(e){switch(e.label){case 0:return t={path:(null==a?void 0:a.path)||[],issues:[],contextualErrorMap:null==a?void 0:a.errorMap,schemaErrorMap:this._def.errorMap,async:!0,typeCache:new Map,parent:null,data:n,parsedType:getParsedType(n)},r=this._parse({data:n,path:[],parent:t}),[4,isAsync(r)?r:Promise.resolve(r)];case 1:return r=e.sent(),[2,handleResult(t,r)]}})})},e.prototype.refine=function(a,o){return this._refinement(function(t,r){function n(){return r.addIssue(__assign({code:ZodIssueCode.custom},(e=t,"string"==typeof o||void 0===o?{message:o}:"function"==typeof o?o(e):o)));var e;}var e=a(t);return e instanceof Promise?e.then(function(e){return !!e||(n(),!1)}):!!e||(n(),!1)})},e.prototype.refinement=function(r,n){return this._refinement(function(e,t){return !!r(e)||(t.addIssue("function"==typeof n?n(e,t):n),!1)})},e.prototype._refinement=function(e){return new ZodEffects({schema:this,typeName:ZodFirstPartyTypeKind.ZodEffects,effect:{type:"refinement",refinement:e}})},e.prototype.optional=function(){return ZodOptional.create(this)},e.prototype.nullable=function(){return ZodNullable.create(this)},e.prototype.nullish=function(){return this.optional().nullable()},e.prototype.array=function(){return ZodArray.create(this)},e.prototype.promise=function(){return ZodPromise.create(this)},e.prototype.or=function(e){return ZodUnion.create([this,e])},e.prototype.and=function(e){return ZodIntersection.create(this,e)},e.prototype.transform=function(e){return new ZodEffects({schema:this,typeName:ZodFirstPartyTypeKind.ZodEffects,effect:{type:"transform",transform:e}})},e.prototype.default=function(e){return new ZodDefault({innerType:this,defaultValue:"function"==typeof e?e:function(){return e},typeName:ZodFirstPartyTypeKind.ZodDefault})},e.prototype.describe=function(e){return new this.constructor(__assign(__assign({},this._def),{description:e}))},e.prototype.isOptional=function(){return this.safeParse(void 0).success},e.prototype.isNullable=function(){return this.safeParse(null).success},e}(),cuidRegex=/^c[^\s-]{8,}$/i,uuidRegex=/^([a-f0-9]{8}-[a-f0-9]{4}-[1-5][a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}|00000000-0000-0000-0000-000000000000)$/i,emailRegex=/^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i,ZodString=function(e){function t(){var n=null!==e&&e.apply(this,arguments)||this;return n._regex=function(t,e,r){return n.refinement(function(e){return t.test(e)},__assign({validation:e,code:ZodIssueCode.invalid_string},errorUtil.errToObj(r)))},n.nonempty=function(e){return n.min(1,errorUtil.errToObj(e))},n}return __extends(t,e),t.prototype._parse=function(e){var t,r,e=this._processInputParams(e),n=e.status,a=e.ctx;if(a.parsedType!==ZodParsedType.string)return addIssueToContext(a,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.string,received:a.parsedType}),INVALID;try{for(var o=__values(this._def.checks),s=o.next();!s.done;s=o.next()){var i=s.value;if("min"===i.kind)a.data.length<i.value&&(addIssueToContext(a,{code:ZodIssueCode.too_small,minimum:i.value,type:"string",inclusive:!0,message:i.message}),n.dirty());else if("max"===i.kind)a.data.length>i.value&&(addIssueToContext(a,{code:ZodIssueCode.too_big,maximum:i.value,type:"string",inclusive:!0,message:i.message}),n.dirty());else if("email"===i.kind)emailRegex.test(a.data)||(addIssueToContext(a,{validation:"email",code:ZodIssueCode.invalid_string,message:i.message}),n.dirty());else if("uuid"===i.kind)uuidRegex.test(a.data)||(addIssueToContext(a,{validation:"uuid",code:ZodIssueCode.invalid_string,message:i.message}),n.dirty());else if("cuid"===i.kind)cuidRegex.test(a.data)||(addIssueToContext(a,{validation:"cuid",code:ZodIssueCode.invalid_string,message:i.message}),n.dirty());else if("url"===i.kind)try{new URL(a.data);}catch(e){addIssueToContext(a,{validation:"url",code:ZodIssueCode.invalid_string,message:i.message}),n.dirty();}else "regex"===i.kind&&(i.regex.lastIndex=0,i.regex.test(a.data)||(addIssueToContext(a,{validation:"regex",code:ZodIssueCode.invalid_string,message:i.message}),n.dirty()));}}catch(e){t={error:e};}finally{try{s&&!s.done&&(r=o.return)&&r.call(o);}finally{if(t)throw t.error}}return {status:n.value,value:a.data}},t.prototype._addCheck=function(e){return new t(__assign(__assign({},this._def),{checks:__spreadArray(__spreadArray([],__read(this._def.checks),!1),[e],!1)}))},t.prototype.email=function(e){return this._addCheck(__assign({kind:"email"},errorUtil.errToObj(e)))},t.prototype.url=function(e){return this._addCheck(__assign({kind:"url"},errorUtil.errToObj(e)))},t.prototype.uuid=function(e){return this._addCheck(__assign({kind:"uuid"},errorUtil.errToObj(e)))},t.prototype.cuid=function(e){return this._addCheck(__assign({kind:"cuid"},errorUtil.errToObj(e)))},t.prototype.regex=function(e,t){return this._addCheck(__assign({kind:"regex",regex:e},errorUtil.errToObj(t)))},t.prototype.min=function(e,t){return this._addCheck(__assign({kind:"min",value:e},errorUtil.errToObj(t)))},t.prototype.max=function(e,t){return this._addCheck(__assign({kind:"max",value:e},errorUtil.errToObj(t)))},t.prototype.length=function(e,t){return this.min(e,t).max(e,t)},Object.defineProperty(t.prototype,"isEmail",{get:function(){return !!this._def.checks.find(function(e){return "email"===e.kind})},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isURL",{get:function(){return !!this._def.checks.find(function(e){return "url"===e.kind})},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isUUID",{get:function(){return !!this._def.checks.find(function(e){return "uuid"===e.kind})},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"isCUID",{get:function(){return !!this._def.checks.find(function(e){return "cuid"===e.kind})},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"minLength",{get:function(){var t=-1/0;return this._def.checks.map(function(e){"min"===e.kind&&(null===t||e.value>t)&&(t=e.value);}),t},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"maxLength",{get:function(){var t=null;return this._def.checks.map(function(e){"max"===e.kind&&(null===t||e.value<t)&&(t=e.value);}),t},enumerable:!1,configurable:!0}),t.create=function(e){return new t(__assign({checks:[],typeName:ZodFirstPartyTypeKind.ZodString},processCreateParams(e)))},t}(ZodType),ZodNumber=function(t){function a(){var e=null!==t&&t.apply(this,arguments)||this;return e.min=e.gte,e.max=e.lte,e.step=e.multipleOf,e}return __extends(a,t),a.prototype._parse=function(e){var t,r,e=this._processInputParams(e),n=e.status,a=e.ctx;if(a.parsedType!==ZodParsedType.number)return addIssueToContext(a,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.number,received:a.parsedType}),INVALID;try{for(var o=__values(this._def.checks),s=o.next();!s.done;s=o.next()){var i=s.value;"int"===i.kind?util.isInteger(a.data)||(addIssueToContext(a,{code:ZodIssueCode.invalid_type,expected:"integer",received:"float",message:i.message}),n.dirty()):"min"===i.kind?(i.inclusive?a.data<i.value:a.data<=i.value)&&(addIssueToContext(a,{code:ZodIssueCode.too_small,minimum:i.value,type:"number",inclusive:i.inclusive,message:i.message}),n.dirty()):"max"===i.kind?(i.inclusive?a.data>i.value:a.data>=i.value)&&(addIssueToContext(a,{code:ZodIssueCode.too_big,maximum:i.value,type:"number",inclusive:i.inclusive,message:i.message}),n.dirty()):"multipleOf"===i.kind?a.data%i.value!=0&&(addIssueToContext(a,{code:ZodIssueCode.not_multiple_of,multipleOf:i.value,message:i.message}),n.dirty()):util.assertNever(i);}}catch(e){t={error:e};}finally{try{s&&!s.done&&(r=o.return)&&r.call(o);}finally{if(t)throw t.error}}return {status:n.value,value:a.data}},a.prototype.gte=function(e,t){return this.setLimit("min",e,!0,errorUtil.toString(t))},a.prototype.gt=function(e,t){return this.setLimit("min",e,!1,errorUtil.toString(t))},a.prototype.lte=function(e,t){return this.setLimit("max",e,!0,errorUtil.toString(t))},a.prototype.lt=function(e,t){return this.setLimit("max",e,!1,errorUtil.toString(t))},a.prototype.setLimit=function(e,t,r,n){return new a(__assign(__assign({},this._def),{checks:__spreadArray(__spreadArray([],__read(this._def.checks),!1),[{kind:e,value:t,inclusive:r,message:errorUtil.toString(n)}],!1)}))},a.prototype._addCheck=function(e){return new a(__assign(__assign({},this._def),{checks:__spreadArray(__spreadArray([],__read(this._def.checks),!1),[e],!1)}))},a.prototype.int=function(e){return this._addCheck({kind:"int",message:errorUtil.toString(e)})},a.prototype.positive=function(e){return this._addCheck({kind:"min",value:0,inclusive:!1,message:errorUtil.toString(e)})},a.prototype.negative=function(e){return this._addCheck({kind:"max",value:0,inclusive:!1,message:errorUtil.toString(e)})},a.prototype.nonpositive=function(e){return this._addCheck({kind:"max",value:0,inclusive:!0,message:errorUtil.toString(e)})},a.prototype.nonnegative=function(e){return this._addCheck({kind:"min",value:0,inclusive:!0,message:errorUtil.toString(e)})},a.prototype.multipleOf=function(e,t){return this._addCheck({kind:"multipleOf",value:e,message:errorUtil.toString(t)})},Object.defineProperty(a.prototype,"minValue",{get:function(){var t,e,r=null;try{for(var n=__values(this._def.checks),a=n.next();!a.done;a=n.next()){var o=a.value;"min"===o.kind&&(null===r||o.value>r)&&(r=o.value);}}catch(e){t={error:e};}finally{try{a&&!a.done&&(e=n.return)&&e.call(n);}finally{if(t)throw t.error}}return r},enumerable:!1,configurable:!0}),Object.defineProperty(a.prototype,"maxValue",{get:function(){var t,e,r=null;try{for(var n=__values(this._def.checks),a=n.next();!a.done;a=n.next()){var o=a.value;"max"===o.kind&&(null===r||o.value<r)&&(r=o.value);}}catch(e){t={error:e};}finally{try{a&&!a.done&&(e=n.return)&&e.call(n);}finally{if(t)throw t.error}}return r},enumerable:!1,configurable:!0}),Object.defineProperty(a.prototype,"isInt",{get:function(){return !!this._def.checks.find(function(e){return "int"===e.kind})},enumerable:!1,configurable:!0}),a.create=function(e){return new a(__assign(__assign({checks:[],typeName:ZodFirstPartyTypeKind.ZodNumber},processCreateParams(e)),processCreateParams(e)))},a}(ZodType),ZodBigInt=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType!==ZodParsedType.bigint?(addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.bigint,received:e.parsedType}),INVALID):OK(e.data)},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodBigInt},processCreateParams(e)))},t}(ZodType),ZodBoolean=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType!==ZodParsedType.boolean?(addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.boolean,received:e.parsedType}),INVALID):OK(e.data)},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodBoolean},processCreateParams(e)))},t}(ZodType),ZodDate=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){var t=this._processInputParams(e),e=t.status,t=t.ctx;return t.parsedType!==ZodParsedType.date?(addIssueToContext(t,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.date,received:t.parsedType}),INVALID):isNaN(t.data.getTime())?(addIssueToContext(t,{code:ZodIssueCode.invalid_date}),INVALID):{status:e.value,value:new Date(t.data.getTime())}},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodDate},processCreateParams(e)))},t}(ZodType),ZodUndefined=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType!==ZodParsedType.undefined?(addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.undefined,received:e.parsedType}),INVALID):OK(e.data)},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodUndefined},processCreateParams(e)))},t}(ZodType),ZodNull=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType!==ZodParsedType.null?(addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.null,received:e.parsedType}),INVALID):OK(e.data)},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodNull},processCreateParams(e)))},t}(ZodType),ZodAny=function(t){function r(){var e=null!==t&&t.apply(this,arguments)||this;return e._any=!0,e}return __extends(r,t),r.prototype._parse=function(e){e=this._processInputParams(e).ctx;return OK(e.data)},r.create=function(e){return new r(__assign({typeName:ZodFirstPartyTypeKind.ZodAny},processCreateParams(e)))},r}(ZodType),ZodUnknown=function(t){function r(){var e=null!==t&&t.apply(this,arguments)||this;return e._unknown=!0,e}return __extends(r,t),r.prototype._parse=function(e){e=this._processInputParams(e).ctx;return OK(e.data)},r.create=function(e){return new r(__assign({typeName:ZodFirstPartyTypeKind.ZodUnknown},processCreateParams(e)))},r}(ZodType),ZodNever=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.never,received:e.parsedType}),INVALID},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodNever},processCreateParams(e)))},t}(ZodType),ZodVoid=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType!==ZodParsedType.undefined?(addIssueToContext(e,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.void,received:e.parsedType}),INVALID):OK(e.data)},t.create=function(e){return new t(__assign({typeName:ZodFirstPartyTypeKind.ZodVoid},processCreateParams(e)))},t}(ZodType),ZodArray=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var e=this._processInputParams(e),t=e.status,r=e.ctx,n=this._def;if(r.parsedType!==ZodParsedType.array)return addIssueToContext(r,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.array,received:r.parsedType}),INVALID;if(null!==n.minLength&&r.data.length<n.minLength.value&&(addIssueToContext(r,{code:ZodIssueCode.too_small,minimum:n.minLength.value,type:"array",inclusive:!0,message:n.minLength.message}),t.dirty()),null!==n.maxLength&&r.data.length>n.maxLength.value&&(addIssueToContext(r,{code:ZodIssueCode.too_big,maximum:n.maxLength.value,type:"array",inclusive:!0,message:n.maxLength.message}),t.dirty()),r.async)return Promise.all(r.data.map(function(e,t){return n.type._parseAsync({parent:r,path:__spreadArray(__spreadArray([],__read(r.path),!1),[t],!1),data:e})})).then(function(e){return ParseStatus.mergeArray(t,e)});e=r.data.map(function(e,t){return n.type._parseSync({parent:r,path:__spreadArray(__spreadArray([],__read(r.path),!1),[t],!1),data:e})});return ParseStatus.mergeArray(t,e)},Object.defineProperty(r.prototype,"element",{get:function(){return this._def.type},enumerable:!1,configurable:!0}),r.prototype.min=function(e,t){return new r(__assign(__assign({},this._def),{minLength:{value:e,message:errorUtil.toString(t)}}))},r.prototype.max=function(e,t){return new r(__assign(__assign({},this._def),{maxLength:{value:e,message:errorUtil.toString(t)}}))},r.prototype.length=function(e,t){return this.min(e,t).max(e,t)},r.prototype.nonempty=function(e){return this.min(1,e)},r.create=function(e,t){return new r(__assign({type:e,minLength:null,maxLength:null,typeName:ZodFirstPartyTypeKind.ZodArray},processCreateParams(t)))},r}(ZodType);(objectUtil||(objectUtil={})).mergeShapes=function(e,t){return __assign(__assign({},e),t)};var AugmentFactory=function(t){return function(e){return new ZodObject(__assign(__assign({},t),{shape:function(){return __assign(__assign({},t.shape()),e)}}))}};function deepPartialify(e){if(e instanceof ZodObject){var t,r={};for(t in e.shape){var n=e.shape[t];r[t]=ZodOptional.create(deepPartialify(n));}return new ZodObject(__assign(__assign({},e._def),{shape:function(){return r}}))}return e instanceof ZodArray?ZodArray.create(deepPartialify(e.element)):e instanceof ZodOptional?ZodOptional.create(deepPartialify(e.unwrap())):e instanceof ZodNullable?ZodNullable.create(deepPartialify(e.unwrap())):e instanceof ZodTuple?ZodTuple.create(e.items.map(function(e){return deepPartialify(e)})):e}var ZodObject=function(t){function s(){var e=null!==t&&t.apply(this,arguments)||this;return e._cached=null,e.nonstrict=e.passthrough,e.augment=AugmentFactory(e._def),e.extend=AugmentFactory(e._def),e}return __extends(s,t),s.prototype._getCached=function(){if(null!==this._cached)return this._cached;var e=this._def.shape(),t=util.objectKeys(e);return this._cached={shape:e,keys:t}},s.prototype._parse=function(e){var t,r,n,a,o,s=this,i=this._processInputParams(e),u=i.status,d=i.ctx;if(d.parsedType!==ZodParsedType.object)return addIssueToContext(d,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.object,received:d.parsedType}),INVALID;var e=this._getCached(),p=e.shape,i=e.keys,e=util.objectKeys(d.data).filter(function(e){return !(e in p)}),c=[];try{for(var l=__values(i),y=l.next();!y.done;y=l.next()){var f=y.value,_=p[f],h=d.data[f];c.push({key:{status:"valid",value:f},value:_._parse({parent:d,data:h,path:__spreadArray(__spreadArray([],__read(d.path),!1),[f],!1)}),alwaysSet:f in d.data});}}catch(e){v={error:e};}finally{try{y&&!y.done&&(t=l.return)&&t.call(l);}finally{if(v)throw v.error}}if(this._def.catchall instanceof ZodNever){var v=this._def.unknownKeys;if("passthrough"===v)try{for(var m=__values(e),Z=m.next();!Z.done;Z=m.next()){f=Z.value;c.push({key:{status:"valid",value:f},value:{status:"valid",value:d.data[f]}});}}catch(e){r={error:e};}finally{try{Z&&!Z.done&&(n=m.return)&&n.call(m);}finally{if(r)throw r.error}}else if("strict"===v)0<e.length&&(addIssueToContext(d,{code:ZodIssueCode.unrecognized_keys,keys:e}),u.dirty());else if("strip"!==v)throw new Error("Internal ZodObject error: invalid unknownKeys value.")}else {var g=this._def.catchall;try{for(var T=__values(e),b=T.next();!b.done;b=T.next()){f=b.value,h=d.data[f];c.push({key:{status:"valid",value:f},value:g._parse({parent:d,path:__spreadArray(__spreadArray([],__read(d.path),!1),[f],!1),data:h}),alwaysSet:f in d.data});}}catch(e){a={error:e};}finally{try{b&&!b.done&&(o=T.return)&&o.call(T);}finally{if(a)throw a.error}}}return d.async?Promise.resolve().then(function(){return __awaiter(s,void 0,void 0,function(){var t,r,n,a,o,s,i,u,d;return __generator(this,function(e){switch(e.label){case 0:t=[],e.label=1;case 1:e.trys.push([1,7,8,9]),r=__values(c),n=r.next(),e.label=2;case 2:return n.done?[3,6]:[4,(a=n.value).key];case 3:return d=e.sent(),s=(o=t).push,d={key:d},[4,a.value];case 4:s.apply(o,[(d.value=e.sent(),d.alwaysSet=a.alwaysSet,d)]),e.label=5;case 5:return n=r.next(),[3,2];case 6:return [3,9];case 7:return i=e.sent(),i={error:i},[3,9];case 8:try{n&&!n.done&&(u=r.return)&&u.call(r);}finally{if(i)throw i.error}return [7];case 9:return [2,t]}})})}).then(function(e){return ParseStatus.mergeObjectSync(u,e)}):ParseStatus.mergeObjectSync(u,c)},Object.defineProperty(s.prototype,"shape",{get:function(){return this._def.shape()},enumerable:!1,configurable:!0}),s.prototype.strict=function(a){var o=this;return errorUtil.errToObj,new s(__assign(__assign(__assign({},this._def),{unknownKeys:"strict"}),void 0!==a?{errorMap:function(e,t){var r,n,t=null!==(n=null===(r=(n=o._def).errorMap)||void 0===r?void 0:r.call(n,e,t).message)&&void 0!==n?n:t.defaultError;return "unrecognized_keys"===e.code?{message:null!==(e=errorUtil.errToObj(a).message)&&void 0!==e?e:t}:{message:t}}}:{}))},s.prototype.strip=function(){return new s(__assign(__assign({},this._def),{unknownKeys:"strip"}))},s.prototype.passthrough=function(){return new s(__assign(__assign({},this._def),{unknownKeys:"passthrough"}))},s.prototype.setKey=function(e,t){var r;return this.augment(((r={})[e]=t,r))},s.prototype.merge=function(e){var t=objectUtil.mergeShapes(this._def.shape(),e._def.shape());return new s({unknownKeys:e._def.unknownKeys,catchall:e._def.catchall,shape:function(){return t},typeName:ZodFirstPartyTypeKind.ZodObject})},s.prototype.catchall=function(e){return new s(__assign(__assign({},this._def),{catchall:e}))},s.prototype.pick=function(e){var t=this,r={};return util.objectKeys(e).map(function(e){r[e]=t.shape[e];}),new s(__assign(__assign({},this._def),{shape:function(){return r}}))},s.prototype.omit=function(t){var r=this,n={};return util.objectKeys(this.shape).map(function(e){-1===util.objectKeys(t).indexOf(e)&&(n[e]=r.shape[e]);}),new s(__assign(__assign({},this._def),{shape:function(){return n}}))},s.prototype.deepPartial=function(){return deepPartialify(this)},s.prototype.partial=function(t){var e,r=this,n={};if(t)return util.objectKeys(this.shape).map(function(e){-1===util.objectKeys(t).indexOf(e)?n[e]=r.shape[e]:n[e]=r.shape[e].optional();}),new s(__assign(__assign({},this._def),{shape:function(){return n}}));for(e in this.shape){var a=this.shape[e];n[e]=a.optional();}return new s(__assign(__assign({},this._def),{shape:function(){return n}}))},s.prototype.required=function(){var e,t={};for(e in this.shape){for(var r=this.shape[e];r instanceof ZodOptional;)r=r._def.innerType;t[e]=r;}return new s(__assign(__assign({},this._def),{shape:function(){return t}}))},s.create=function(e,t){return new s(__assign({shape:function(){return e},unknownKeys:"strip",catchall:ZodNever.create(),typeName:ZodFirstPartyTypeKind.ZodObject},processCreateParams(t)))},s.strictCreate=function(e,t){return new s(__assign({shape:function(){return e},unknownKeys:"strict",catchall:ZodNever.create(),typeName:ZodFirstPartyTypeKind.ZodObject},processCreateParams(t)))},s.lazycreate=function(e,t){return new s(__assign({shape:e,unknownKeys:"strip",catchall:ZodNever.create(),typeName:ZodFirstPartyTypeKind.ZodObject},processCreateParams(t)))},s}(ZodType),ZodUnion=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var t=this,c=this._processInputParams(e).ctx,e=this._def.options;function r(e){var t,r,n,a,o;try{for(var s=__values(e),i=s.next();!i.done;i=s.next())if("valid"===(u=i.value).result.status)return u.result}catch(e){t={error:e};}finally{try{i&&!i.done&&(r=s.return)&&r.call(s);}finally{if(t)throw t.error}}try{for(var u,d=__values(e),p=d.next();!p.done;p=d.next())if("dirty"===(u=p.value).result.status)return (o=c.issues).push.apply(o,__spreadArray([],__read(u.ctx.issues),!1)),u.result}catch(e){n={error:e};}finally{try{p&&!p.done&&(a=d.return)&&a.call(d);}finally{if(n)throw n.error}}e=e.map(function(e){return new ZodError(e.ctx.issues)});return addIssueToContext(c,{code:ZodIssueCode.invalid_union,unionErrors:e}),INVALID}return c.async?Promise.all(e.map(function(n){return __awaiter(t,void 0,void 0,function(){var t,r;return __generator(this,function(e){switch(e.label){case 0:return t=__assign(__assign({},c),{issues:[],parent:null}),r={},[4,n._parseAsync({data:c.data,path:c.path,parent:t})];case 1:return [2,(r.result=e.sent(),r.ctx=t,r)]}})})})).then(r):r(e.map(function(e){var t=__assign(__assign({},c),{issues:[],parent:null});return {result:e._parseSync({data:c.data,path:c.path,parent:t}),ctx:t}}))},Object.defineProperty(r.prototype,"options",{get:function(){return this._def.options},enumerable:!1,configurable:!0}),r.create=function(e,t){return new r(__assign({options:e,typeName:ZodFirstPartyTypeKind.ZodUnion},processCreateParams(t)))},r}(ZodType);function mergeValues(e,t){var r,n,a=getParsedType(e),o=getParsedType(t);if(e===t)return {valid:!0,data:e};if(a===ZodParsedType.object&&o===ZodParsedType.object){var s=util.objectKeys(t),i=util.objectKeys(e).filter(function(e){return -1!==s.indexOf(e)}),u=__assign(__assign({},e),t);try{for(var d=__values(i),p=d.next();!p.done;p=d.next()){var c=p.value;if(!(l=mergeValues(e[c],t[c])).valid)return {valid:!1};u[c]=l.data;}}catch(e){r={error:e};}finally{try{p&&!p.done&&(n=d.return)&&n.call(d);}finally{if(r)throw r.error}}return {valid:!0,data:u}}if(a!==ZodParsedType.array||o!==ZodParsedType.array)return {valid:!1};if(e.length!==t.length)return {valid:!1};for(var l,y=[],f=0;f<e.length;f++){if(!(l=mergeValues(e[f],t[f])).valid)return {valid:!1};y.push(l.data);}return {valid:!0,data:y}}var ZodIntersection=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return __extends(n,e),n.prototype._parse=function(e){function r(e,t){if(isAborted(e)||isAborted(t))return INVALID;var r=mergeValues(e.value,t.value);return r.valid?((isDirty(e)||isDirty(t))&&n.dirty(),{status:n.value,value:r.data}):(addIssueToContext(a,{code:ZodIssueCode.invalid_intersection_types}),INVALID)}var e=this._processInputParams(e),n=e.status,a=e.ctx;return a.async?Promise.all([this._def.left._parseAsync({data:a.data,path:a.path,parent:a}),this._def.right._parseAsync({data:a.data,path:a.path,parent:a})]).then(function(e){var t=__read(e,2),e=t[0],t=t[1];return r(e,t)}):r(this._def.left._parseSync({data:a.data,path:a.path,parent:a}),this._def.right._parseSync({data:a.data,path:a.path,parent:a}))},n.create=function(e,t,r){return new n(__assign({left:e,right:t,typeName:ZodFirstPartyTypeKind.ZodIntersection},processCreateParams(r)))},n}(ZodType),ZodTuple=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var n=this,e=this._processInputParams(e),t=e.status,a=e.ctx;if(a.parsedType!==ZodParsedType.array)return addIssueToContext(a,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.array,received:a.parsedType}),INVALID;if(a.data.length<this._def.items.length)return addIssueToContext(a,{code:ZodIssueCode.too_small,minimum:this._def.items.length,inclusive:!0,type:"array"}),INVALID;!this._def.rest&&a.data.length>this._def.items.length&&(addIssueToContext(a,{code:ZodIssueCode.too_big,maximum:this._def.items.length,inclusive:!0,type:"array"}),t.dirty());e=a.data.map(function(e,t){var r=n._def.items[t]||n._def.rest;return r?r._parse({data:e,path:__spreadArray(__spreadArray([],__read(a.path),!1),[t],!1),parent:a}):null}).filter(function(e){return !!e});return a.async?Promise.all(e).then(function(e){return ParseStatus.mergeArray(t,e)}):ParseStatus.mergeArray(t,e)},Object.defineProperty(r.prototype,"items",{get:function(){return this._def.items},enumerable:!1,configurable:!0}),r.prototype.rest=function(e){return new r(__assign(__assign({},this._def),{rest:e}))},r.create=function(e,t){return new r(__assign({items:e,typeName:ZodFirstPartyTypeKind.ZodTuple,rest:null},processCreateParams(t)))},r}(ZodType),ZodRecord=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return __extends(n,e),Object.defineProperty(n.prototype,"keySchema",{get:function(){return this._def.keyType},enumerable:!1,configurable:!0}),Object.defineProperty(n.prototype,"valueSchema",{get:function(){return this._def.valueType},enumerable:!1,configurable:!0}),n.prototype._parse=function(e){var t=this._processInputParams(e),e=t.status,r=t.ctx;if(r.parsedType!==ZodParsedType.object)return addIssueToContext(r,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.object,received:r.parsedType}),INVALID;var n,a=[],o=this._def.keyType,s=this._def.valueType;for(n in r.data)a.push({key:o._parse({data:n,path:__spreadArray(__spreadArray([],__read(r.path),!1),[n],!1),parent:r}),value:s._parse({data:r.data[n],path:__spreadArray(__spreadArray([],__read(r.path),!1),[n],!1),parent:r})});return r.async?ParseStatus.mergeObjectAsync(e,a):ParseStatus.mergeObjectSync(e,a)},Object.defineProperty(n.prototype,"element",{get:function(){return this._def.valueType},enumerable:!1,configurable:!0}),n.create=function(e,t,r){return new n(t instanceof ZodType?__assign({keyType:e,valueType:t,typeName:ZodFirstPartyTypeKind.ZodRecord},processCreateParams(r)):__assign({keyType:ZodString.create(),valueType:e,typeName:ZodFirstPartyTypeKind.ZodRecord},processCreateParams(t)))},n}(ZodType),ZodMap=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return __extends(n,e),n.prototype._parse=function(e){var t,r,n=this,e=this._processInputParams(e),u=e.status,a=e.ctx;if(a.parsedType!==ZodParsedType.map)return addIssueToContext(a,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.map,received:a.parsedType}),INVALID;var o=this._def.keyType,s=this._def.valueType,d=__spreadArray([],__read(a.data.entries()),!1).map(function(e,t){var r=__read(e,2),e=r[0],r=r[1];return {key:o._parse({data:e,path:__spreadArray(__spreadArray([],__read(a.path),!1),[t,"key"],!1),parent:a}),value:s._parse({data:r,path:__spreadArray(__spreadArray([],__read(a.path),!1),[t,"value"],!1),parent:a})}});if(a.async){var p=new Map;return Promise.resolve().then(function(){return __awaiter(n,void 0,void 0,function(){var t,r,n,a,o,s,i;return __generator(this,function(e){switch(e.label){case 0:e.trys.push([0,6,7,8]),t=__values(d),r=t.next(),e.label=1;case 1:return r.done?[3,5]:[4,(n=r.value).key];case 2:return a=e.sent(),[4,n.value];case 3:if(o=e.sent(),"aborted"===a.status||"aborted"===o.status)return [2,INVALID];"dirty"!==a.status&&"dirty"!==o.status||u.dirty(),p.set(a.value,o.value),e.label=4;case 4:return r=t.next(),[3,1];case 5:return [3,8];case 6:return s=e.sent(),s={error:s},[3,8];case 7:try{r&&!r.done&&(i=t.return)&&i.call(t);}finally{if(s)throw s.error}return [7];case 8:return [2,{status:u.value,value:p}]}})})})}var i=new Map;try{for(var c=__values(d),l=c.next();!l.done;l=c.next()){var y=l.value,f=y.key,_=y.value;if("aborted"===f.status||"aborted"===_.status)return INVALID;"dirty"!==f.status&&"dirty"!==_.status||u.dirty(),i.set(f.value,_.value);}}catch(e){t={error:e};}finally{try{l&&!l.done&&(r=c.return)&&r.call(c);}finally{if(t)throw t.error}}return {status:u.value,value:i}},n.create=function(e,t,r){return new n(__assign({valueType:t,keyType:e,typeName:ZodFirstPartyTypeKind.ZodMap},processCreateParams(r)))},n}(ZodType),ZodSet=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var e=this._processInputParams(e),i=e.status,r=e.ctx;if(r.parsedType!==ZodParsedType.set)return addIssueToContext(r,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.set,received:r.parsedType}),INVALID;var n=this._def.valueType;function t(e){var t,r,n=new Set;try{for(var a=__values(e),o=a.next();!o.done;o=a.next()){var s=o.value;if("aborted"===s.status)return INVALID;"dirty"===s.status&&i.dirty(),n.add(s.value);}}catch(e){t={error:e};}finally{try{o&&!o.done&&(r=a.return)&&r.call(a);}finally{if(t)throw t.error}}return {status:i.value,value:n}}e=__spreadArray([],__read(r.data.values()),!1).map(function(e,t){return n._parse({data:e,path:__spreadArray(__spreadArray([],__read(r.path),!1),[t],!1),parent:r})});return r.async?Promise.all(e).then(t):t(e)},r.create=function(e,t){return new r(__assign({valueType:e,typeName:ZodFirstPartyTypeKind.ZodSet},processCreateParams(t)))},r}(ZodType),ZodFunction=function(t){function n(){var e=null!==t&&t.apply(this,arguments)||this;return e.validate=e.implement,e}return __extends(n,t),n.prototype._parse=function(e){var o=this,r=this._processInputParams(e).ctx;if(r.parsedType!==ZodParsedType.function)return addIssueToContext(r,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.function,received:r.parsedType}),INVALID;function s(e,t){return makeIssue({data:e,path:r.path,errorMaps:[r.contextualErrorMap,r.schemaErrorMap,overrideErrorMap,defaultErrorMap].filter(function(e){return !!e}),issueData:{code:ZodIssueCode.invalid_arguments,argumentsError:t}})}function i(e,t){return makeIssue({data:e,path:r.path,errorMaps:[r.contextualErrorMap,r.schemaErrorMap,overrideErrorMap,defaultErrorMap].filter(function(e){return !!e}),issueData:{code:ZodIssueCode.invalid_return_type,returnTypeError:t}})}var u={errorMap:r.contextualErrorMap},d=r.data;return this._def.returns instanceof ZodPromise?OK(function(){for(var a=[],e=0;e<arguments.length;e++)a[e]=arguments[e];return __awaiter(o,void 0,void 0,function(){var t,r,n;return __generator(this,function(e){switch(e.label){case 0:return t=new ZodError([]),[4,this._def.args.parseAsync(a,u).catch(function(e){throw t.addIssue(s(a,e)),t})];case 1:return r=e.sent(),[4,d.apply(void 0,__spreadArray([],__read(r),!1))];case 2:return n=e.sent(),[4,this._def.returns._def.type.parseAsync(n,u).catch(function(e){throw t.addIssue(i(n,e)),t})];case 3:return [2,e.sent()]}})})}):OK(function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var r=o._def.args.safeParse(e,u);if(!r.success)throw new ZodError([s(e,r.error)]);var n=d.apply(void 0,__spreadArray([],__read(r.data),!1)),r=o._def.returns.safeParse(n,u);if(!r.success)throw new ZodError([i(n,r.error)]);return r.data})},n.prototype.parameters=function(){return this._def.args},n.prototype.returnType=function(){return this._def.returns},n.prototype.args=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return new n(__assign(__assign({},this._def),{args:ZodTuple.create(e).rest(ZodUnknown.create())}))},n.prototype.returns=function(e){return new n(__assign(__assign({},this._def),{returns:e}))},n.prototype.implement=function(e){return this.parse(e)},n.prototype.strictImplement=function(e){return this.parse(e)},n.create=function(e,t,r){return new n(__assign({args:(e||ZodTuple.create([])).rest(ZodUnknown.create()),returns:t||ZodUnknown.create(),typeName:ZodFirstPartyTypeKind.ZodFunction},processCreateParams(r)))},n}(ZodType),ZodLazy=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),Object.defineProperty(r.prototype,"schema",{get:function(){return this._def.getter()},enumerable:!1,configurable:!0}),r.prototype._parse=function(e){e=this._processInputParams(e).ctx;return this._def.getter()._parse({data:e.data,path:e.path,parent:e})},r.create=function(e,t){return new r(__assign({getter:e,typeName:ZodFirstPartyTypeKind.ZodLazy},processCreateParams(t)))},r}(ZodType),ZodLiteral=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var t=this._processInputParams(e),e=t.status,t=t.ctx;return t.data!==this._def.value?(addIssueToContext(t,{code:ZodIssueCode.invalid_type,expected:this._def.value,received:t.data}),INVALID):{status:e.value,value:t.data}},Object.defineProperty(r.prototype,"value",{get:function(){return this._def.value},enumerable:!1,configurable:!0}),r.create=function(e,t){return new r(__assign({value:e,typeName:ZodFirstPartyTypeKind.ZodLiteral},processCreateParams(t)))},r}(ZodType);function createZodEnum(e){return new ZodEnum({values:e,typeName:ZodFirstPartyTypeKind.ZodEnum})}var ZodFirstPartyTypeKind,ZodEnum=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){e=this._processInputParams(e).ctx;return -1===this._def.values.indexOf(e.data)?(addIssueToContext(e,{code:ZodIssueCode.invalid_enum_value,options:this._def.values}),INVALID):OK(e.data)},Object.defineProperty(t.prototype,"options",{get:function(){return this._def.values},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"enum",{get:function(){var t,e,r={};try{for(var n=__values(this._def.values),a=n.next();!a.done;a=n.next()){var o=a.value;r[o]=o;}}catch(e){t={error:e};}finally{try{a&&!a.done&&(e=n.return)&&e.call(n);}finally{if(t)throw t.error}}return r},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"Values",{get:function(){var t,e,r={};try{for(var n=__values(this._def.values),a=n.next();!a.done;a=n.next()){var o=a.value;r[o]=o;}}catch(e){t={error:e};}finally{try{a&&!a.done&&(e=n.return)&&e.call(n);}finally{if(t)throw t.error}}return r},enumerable:!1,configurable:!0}),Object.defineProperty(t.prototype,"Enum",{get:function(){var t,e,r={};try{for(var n=__values(this._def.values),a=n.next();!a.done;a=n.next()){var o=a.value;r[o]=o;}}catch(e){t={error:e};}finally{try{a&&!a.done&&(e=n.return)&&e.call(n);}finally{if(t)throw t.error}}return r},enumerable:!1,configurable:!0}),t.create=createZodEnum,t}(ZodType),ZodNativeEnum=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var t=this._processInputParams(e).ctx,e=util.getValidEnumValues(this._def.values);return -1===e.indexOf(t.data)?(addIssueToContext(t,{code:ZodIssueCode.invalid_enum_value,options:util.objectValues(e)}),INVALID):OK(t.data)},r.create=function(e,t){return new r(__assign({values:e,typeName:ZodFirstPartyTypeKind.ZodNativeEnum},processCreateParams(t)))},r}(ZodType),ZodPromise=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){var t=this,r=this._processInputParams(e).ctx;if(r.parsedType!==ZodParsedType.promise&&!1===r.async)return addIssueToContext(r,{code:ZodIssueCode.invalid_type,expected:ZodParsedType.promise,received:r.parsedType}),INVALID;e=r.parsedType===ZodParsedType.promise?r.data:Promise.resolve(r.data);return OK(e.then(function(e){return t._def.type.parseAsync(e,{path:r.path,errorMap:r.contextualErrorMap})}))},r.create=function(e,t){return new r(__assign({type:e,typeName:ZodFirstPartyTypeKind.ZodPromise},processCreateParams(t)))},r}(ZodType),ZodEffects=function(e){function n(){return null!==e&&e.apply(this,arguments)||this}return __extends(n,e),n.prototype.innerType=function(){return this._def.schema},n.prototype._parse=function(e){var t=this,e=this._processInputParams(e),r=e.status,n=e.ctx,a=this._def.effect||null;if("preprocess"===a.type){e=a.transform(n.data);return n.async?Promise.resolve(e).then(function(e){return t._def.schema._parseAsync({data:e,path:n.path,parent:n})}):this._def.schema._parseSync({data:e,path:n.path,parent:n})}if("refinement"===a.type){var o={addIssue:function(e){addIssueToContext(n,e),e.fatal?r.abort():r.dirty();},get path(){return n.path}};o.addIssue=o.addIssue.bind(o);function s(e){var t=a.refinement(e,o);if(n.async)return Promise.resolve(t);if(t instanceof Promise)throw new Error("Async refinement encountered during synchronous parse operation. Use .parseAsync instead.");return e}if(!1!==n.async)return this._def.schema._parseAsync({data:n.data,path:n.path,parent:n}).then(function(e){return "aborted"===e.status?INVALID:("dirty"===e.status&&r.dirty(),s(e.value).then(function(){return {status:r.value,value:e.value}}))});var i=this._def.schema._parseSync({data:n.data,path:n.path,parent:n});return "aborted"===i.status?INVALID:("dirty"===i.status&&r.dirty(),s(i.value),{status:r.value,value:i.value})}if("transform"===a.type){if(!1!==n.async)return this._def.schema._parseAsync({data:n.data,path:n.path,parent:n}).then(function(e){return isValid(e)?Promise.resolve(a.transform(e.value)).then(OK):e});i=this._def.schema._parseSync({data:n.data,path:n.path,parent:n});if(!isValid(i))return i;i=a.transform(i.value);if(i instanceof Promise)throw new Error("Asynchronous transform encountered during synchronous parse operation. Use .parseAsync instead.");return OK(i)}util.assertNever(a);},n.create=function(e,t,r){return new n(__assign({schema:e,typeName:ZodFirstPartyTypeKind.ZodEffects,effect:t},processCreateParams(r)))},n.createWithPreprocess=function(e,t,r){return new n(__assign({schema:t,effect:{type:"preprocess",transform:e},typeName:ZodFirstPartyTypeKind.ZodEffects},processCreateParams(r)))},n}(ZodType),ZodOptional=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType===ZodParsedType.undefined?OK(void 0):this._def.innerType._parse({data:e.data,path:e.path,parent:e})},r.prototype.unwrap=function(){return this._def.innerType},r.create=function(e,t){return new r(__assign({innerType:e,typeName:ZodFirstPartyTypeKind.ZodOptional},processCreateParams(t)))},r}(ZodType),ZodNullable=function(e){function r(){return null!==e&&e.apply(this,arguments)||this}return __extends(r,e),r.prototype._parse=function(e){e=this._processInputParams(e).ctx;return e.parsedType===ZodParsedType.null?OK(null):this._def.innerType._parse({data:e.data,path:e.path,parent:e})},r.prototype.unwrap=function(){return this._def.innerType},r.create=function(e,t){return new r(__assign({innerType:e,typeName:ZodFirstPartyTypeKind.ZodNullable},processCreateParams(t)))},r}(ZodType),ZodDefault=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends(t,e),t.prototype._parse=function(e){var t=this._processInputParams(e).ctx,e=t.data;return t.parsedType===ZodParsedType.undefined&&(e=this._def.defaultValue()),this._def.innerType._parse({data:e,path:t.path,parent:t})},t.prototype.removeDefault=function(){return this._def.innerType},t.create=function(e,t){return new ZodOptional(__assign({innerType:e,typeName:ZodFirstPartyTypeKind.ZodOptional},processCreateParams(t)))},t}(ZodType),custom=function(e,t){return e?ZodAny.create().refine(e,t):ZodAny.create()},late={object:ZodObject.lazycreate};!function(e){e.ZodString="ZodString",e.ZodNumber="ZodNumber",e.ZodBigInt="ZodBigInt",e.ZodBoolean="ZodBoolean",e.ZodDate="ZodDate",e.ZodUndefined="ZodUndefined",e.ZodNull="ZodNull",e.ZodAny="ZodAny",e.ZodUnknown="ZodUnknown",e.ZodNever="ZodNever",e.ZodVoid="ZodVoid",e.ZodArray="ZodArray",e.ZodObject="ZodObject",e.ZodUnion="ZodUnion",e.ZodIntersection="ZodIntersection",e.ZodTuple="ZodTuple",e.ZodRecord="ZodRecord",e.ZodMap="ZodMap",e.ZodSet="ZodSet",e.ZodFunction="ZodFunction",e.ZodLazy="ZodLazy",e.ZodLiteral="ZodLiteral",e.ZodEnum="ZodEnum",e.ZodEffects="ZodEffects",e.ZodNativeEnum="ZodNativeEnum",e.ZodOptional="ZodOptional",e.ZodNullable="ZodNullable",e.ZodDefault="ZodDefault",e.ZodPromise="ZodPromise";}(ZodFirstPartyTypeKind=ZodFirstPartyTypeKind||{});var instanceOfType=function(t,e){return void 0===e&&(e={message:"Input not instance of "+t.name}),custom(function(e){return e instanceof t},e)},stringType=ZodString.create,numberType=ZodNumber.create,bigIntType=ZodBigInt.create,booleanType=ZodBoolean.create,dateType=ZodDate.create,undefinedType=ZodUndefined.create,nullType=ZodNull.create,anyType=ZodAny.create,unknownType=ZodUnknown.create,neverType=ZodNever.create,voidType=ZodVoid.create,arrayType=ZodArray.create,objectType=ZodObject.create,strictObjectType=ZodObject.strictCreate,unionType=ZodUnion.create,intersectionType=ZodIntersection.create,tupleType=ZodTuple.create,recordType=ZodRecord.create,mapType=ZodMap.create,setType=ZodSet.create,functionType=ZodFunction.create,lazyType=ZodLazy.create,literalType=ZodLiteral.create,enumType=ZodEnum.create,nativeEnumType=ZodNativeEnum.create,promiseType=ZodPromise.create,effectsType=ZodEffects.create,optionalType=ZodOptional.create,nullableType=ZodNullable.create,preprocessType=ZodEffects.createWithPreprocess,ostring=function(){return stringType().optional()},onumber=function(){return numberType().optional()},oboolean=function(){return booleanType().optional()},external=Object.freeze({__proto__:null,ZodParsedType:ZodParsedType,getParsedType:getParsedType,makeIssue:makeIssue,EMPTY_PATH:EMPTY_PATH,addIssueToContext:addIssueToContext,ParseStatus:ParseStatus,INVALID:INVALID,DIRTY:DIRTY,OK:OK,isAborted:isAborted,isDirty:isDirty,isValid:isValid,isAsync:isAsync,ZodType:ZodType,ZodString:ZodString,ZodNumber:ZodNumber,ZodBigInt:ZodBigInt,ZodBoolean:ZodBoolean,ZodDate:ZodDate,ZodUndefined:ZodUndefined,ZodNull:ZodNull,ZodAny:ZodAny,ZodUnknown:ZodUnknown,ZodNever:ZodNever,ZodVoid:ZodVoid,ZodArray:ZodArray,get objectUtil(){return objectUtil},ZodObject:ZodObject,ZodUnion:ZodUnion,ZodIntersection:ZodIntersection,ZodTuple:ZodTuple,ZodRecord:ZodRecord,ZodMap:ZodMap,ZodSet:ZodSet,ZodFunction:ZodFunction,ZodLazy:ZodLazy,ZodLiteral:ZodLiteral,ZodEnum:ZodEnum,ZodNativeEnum:ZodNativeEnum,ZodPromise:ZodPromise,ZodEffects:ZodEffects,ZodTransformer:ZodEffects,ZodOptional:ZodOptional,ZodNullable:ZodNullable,ZodDefault:ZodDefault,custom:custom,Schema:ZodType,ZodSchema:ZodType,late:late,get ZodFirstPartyTypeKind(){return ZodFirstPartyTypeKind},any:anyType,array:arrayType,bigint:bigIntType,boolean:booleanType,date:dateType,effect:effectsType,enum:enumType,function:functionType,instanceof:instanceOfType,intersection:intersectionType,lazy:lazyType,literal:literalType,map:mapType,nativeEnum:nativeEnumType,never:neverType,null:nullType,nullable:nullableType,number:numberType,object:objectType,oboolean:oboolean,onumber:onumber,optional:optionalType,ostring:ostring,preprocess:preprocessType,promise:promiseType,record:recordType,set:setType,strictObject:strictObjectType,string:stringType,transformer:effectsType,tuple:tupleType,undefined:undefinedType,union:unionType,unknown:unknownType,void:voidType,ZodIssueCode:ZodIssueCode,quotelessJson:quotelessJson,ZodError:ZodError,defaultErrorMap:defaultErrorMap,get overrideErrorMap(){return overrideErrorMap},setErrorMap:setErrorMap});

var input = '';

const _tmpl$$j = template(`<span class="label"></span>`),
      _tmpl$2$9 = template(`<span class="cui-text-red-300 cui-text-sm"></span>`),
      _tmpl$3$7 = template(`<label class="input__wrapper"><div class="cui-rounded cui-mt-1 cui-block cui-w-full"></div></label>`),
      _tmpl$4$4 = template(`<span>&nbsp;</span>`);
const Props = external.object({
  name: external.string().optional(),
  label: external.string().optional(),
  errors: external.record(external.string(), external.string()).optional()
});

const Input = props => {
  return (() => {
    const _el$ = _tmpl$3$7.cloneNode(true),
          _el$3 = _el$.firstChild;

    insert(_el$, createComponent(Show, {
      get when() {
        return props.label;
      },

      get children() {
        const _el$2 = _tmpl$$j.cloneNode(true);

        insert(_el$2, () => props.label);

        return _el$2;
      }

    }), _el$3);

    insert(_el$3, () => props.children);

    insert(_el$, createComponent(Show, {
      get when() {
        return props.errors?.[props.name || ''];
      },

      get children() {
        const _el$4 = _tmpl$2$9.cloneNode(true);

        insert(_el$4, () => props.errors?.[props.name || ''] || _tmpl$4$4.cloneNode(true));

        return _el$4;
      }

    }), null);

    return _el$;
  })();
};

function getKeys(zodObj) {
  return Object.keys(zodObj.shape);
}
function runtimeParse(zodObj, payload) {
  return payload;
}

var autocomplete = '';

const _tmpl$$i = template(`<div class="cui-w-full cui-font-bold cui-uppercase cui-rounded-lg cui-w-full cui-py-1 cui-pl-1 cui-text-gray-700 cui-bg-gray-100 cui-leading-tight focus:cui-border-2 focus:cui-border-cta cui-focus:outline-none cui-focus:shadow-outline cui-lg:text-sm cui-text-xs"><div class="cui-flex cui-flex-wrap"><input class="cui-flex-grow cui-bg-gray-100 cui-outline-none"></div></div>`),
      _tmpl$2$8 = template(`<div class="cui-flex-initial cui-inline-block cui-p-1 cui-m-1 cui-border-2 cui-border-cta cui-rounded-md"><span class="cui-ml-2 cui-cursor-pointer">X</span></div>`),
      _tmpl$3$6 = template(`<div class="cui-p-2 cui-border-b-2 cui-border-gray-100"></div>`);
const propDefaults = {
  idField: 'id',
  displayField: 'name'
};

function AutoComplete(props) {
  let input = undefined;
  const [isOpen, setOpenState] = createSignal(false);
  props = mergeProps(propDefaults, props);
  const [inputProps] = splitProps(props, getKeys(Props));

  function selected(result) {
    setOpenState(false);

    if (props.multiple && Array.isArray(props.value)) {
      props.onInput?.([...props.value, result]);

      if (input) {
        input.value = '';
        input.focus();
      }
    } else {
      props.onInput?.(result);
    }
  }

  function remove(result) {
    props.onInput?.(Array.isArray(props.value) ? props.value.filter(v => v[props.idField] !== result[props.idField]) : null);
  }

  return createComponent(Input, mergeProps(inputProps, {
    get children() {
      return [(() => {
        const _el$ = _tmpl$$i.cloneNode(true),
              _el$2 = _el$.firstChild,
              _el$3 = _el$2.firstChild;

        _el$2.$$click = () => input?.focus();

        insert(_el$2, (() => {
          const _c$ = memo(() => !!props.multiple, true);

          return createComponent(Show, {
            get when() {
              return _c$() && Array.isArray(props.value);
            },

            get children() {
              return createComponent(For, {
                get each() {
                  return Array.isArray(props.value) ? props.value : [];
                },

                children: value => (() => {
                  const _el$4 = _tmpl$2$8.cloneNode(true),
                        _el$5 = _el$4.firstChild;

                  insert(_el$4, () => String(value[props.displayField]), _el$5);

                  _el$5.$$click = () => remove(value);

                  return _el$4;
                })()
              });
            }

          });
        })(), _el$3);

        addEventListener(_el$3, "input", debounce_1(e => {
          e.target.value && setOpenState(true);
          props.setFilters('search', e.target.value);
        }, 500), true);

        (el => {
          input = el;
          props.forwardRef?.[1](el);
        })(_el$3);

        createRenderEffect(() => _el$3.value = !props.multiple && !Array.isArray(props.value) && props.value?.[props.displayField] ? String(props.value?.[props.displayField]) : '');

        return _el$;
      })(), createComponent(Show, {
        get when() {
          return isOpen();
        },

        get children() {
          return createComponent(Sheet$1, {
            "class": "autocomplete__results",
            elevation: 2,

            get children() {
              return createComponent(ResourceLoader, {
                get resource() {
                  return props.resource;
                },

                children: data => createComponent(For, {
                  get each() {
                    return data.results.filter(r => {
                      if (Array.isArray(props.value)) {
                        return !props.value?.some(val => val[props.idField] === r[props.idField]);
                      } else {
                        return props.value !== r;
                      }
                    });
                  },

                  fallback: "No Results",
                  children: result => props.children ? props.children(result) : (() => {
                    const _el$6 = _tmpl$3$6.cloneNode(true);

                    _el$6.$$click = e => selected(result);

                    insert(_el$6, () => String(result[props.displayField]));

                    return _el$6;
                  })()
                })
              });
            }

          });
        }

      })];
    }

  }));
}

delegateEvents(["click", "input"]);

var btn = '';

const _tmpl$$h = template(`<button></button>`);
var BtnType;

(function (BtnType) {
  BtnType[BtnType["outline"] = 0] = "outline";
  BtnType[BtnType["text"] = 1] = "text";
  BtnType[BtnType["icon"] = 2] = "icon";
})(BtnType || (BtnType = {}));

const Btn = props => {
  const [btnProps, attrs] = splitProps(props, ['btnType', 'loading', 'children', 'size', 'disabled']);
  return (() => {
    const _el$ = _tmpl$$h.cloneNode(true);

    spread(_el$, attrs, false, true);

    insert(_el$, (() => {
      const _c$ = memo(() => !!!btnProps.loading, true);

      return () => _c$() ? btnProps.children : createComponent(Icon, {
        "class": "cui-animate-spin",
        size: "small",
        children: "loop"
      });
    })());

    createRenderEffect(_p$ => {
      const _v$ = `btn ${String(btnProps.btnType && `btn-${btnProps.btnType}`) || ""}`,
            _v$2 = btnProps.size === 'small',
            _v$3 = btnProps.loading || btnProps.disabled;

      _v$ !== _p$._v$ && (_el$.className = _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && _el$.classList.toggle("btn--small", _p$._v$2 = _v$2);
      _v$3 !== _p$._v$3 && (_el$.disabled = _p$._v$3 = _v$3);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined
    });

    return _el$;
  })();
};

const _tmpl$$g = template(`<button type="button" class="button-group__button"></button>`);

const ButtonGroupButton = props => {
  const {
    value,
    disabled,
    select
  } = useButtonGroupContext();
  const [_, attrs] = splitProps(props, ['value', 'children']);
  return (() => {
    const _el$ = _tmpl$$g.cloneNode(true);

    _el$.$$click = () => select(props.value);

    spread(_el$, attrs, false, true);

    insert(_el$, () => props.children);

    createRenderEffect(_p$ => {
      const _v$ = props.value === value(),
            _v$2 = disabled() || props.disabled;

      _v$ !== _p$._v$ && _el$.classList.toggle("button-group__button--active", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && (_el$.disabled = _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  })();
};

delegateEvents(["click"]);

const createStrictContext = (options = {}) => {
  const Context = createContext();
  const useStrictContext = () => {
    const context = useContext(Context);
    if (context === void 0) {
      throw Error(options.msg || "Context Provider is missing");
    }
    return context;
  };
  return [Context.Provider, useStrictContext];
};

var buttonGroup = '';

const _tmpl$$f = template(`<div class="button-group" role="group"></div>`);
const [ButtonGroupProvider, useButtonGroupContext] = createStrictContext();

const ButtonGroup = props => {
  const [value, setValue] = createSignal(props.value);
  const [disabled, setDisabled] = createSignal(props.disabled);
  createEffect(() => {
    setValue(props.value);
    setDisabled(props.disabled);
  });

  const onSelect = val => {
    if (props.nullable && props.value === val) {
      props.onInput?.(null);
    } else {
      props.onInput?.(val);
    }
  };

  return (() => {
    const _el$ = _tmpl$$f.cloneNode(true);

    insert(_el$, createComponent(ButtonGroupProvider, {
      value: {
        value,
        select: onSelect,
        disabled
      },

      get children() {
        return props.children;
      }

    }));

    createRenderEffect(_p$ => {
      const _v$ = props.size === 'small',
            _v$2 = props.size === 'large';

      _v$ !== _p$._v$ && _el$.classList.toggle("button-group--small", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && _el$.classList.toggle("button-group--large", _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  })();
};

ButtonGroup.Button = ButtonGroupButton;

const mergeClassNames = (...classNames) => {
  return classNames.reduce((prev, current) => {
    return `${prev} ${current ?? ''}`.trim().split(/\s+/).filter((item, pos, self) => self.indexOf(item) === pos).join(' ');
  }, '');
};

const useMergeStyles = (...styles) => {
  return styles.reduce((prev, current) => {
    return {
      className: mergeClassNames(prev.className, current.class, current.className),
      classList: { ...prev.classList,
        ...current.classList
      },
      style: { ...prev.style,
        ...current.style
      }
    };
  }, {
    className: undefined,
    classList: {},
    style: {}
  });
};

const StylableComponent = props => {
  const [_, elementStyles, attrs] = splitProps(props, ['tag', 'styleData'], ['class', 'classList', 'style', 'className']);
  const styles = createMemo(() => useMergeStyles(elementStyles, props.styleData));
  return createComponent(Dynamic, mergeProps({
    get component() {
      return props.tag;
    },

    get ["class"]() {
      return styles().className;
    },

    get classList() {
      return styles().classList;
    },

    get style() {
      return styles().style;
    }

  }, attrs, {
    get children() {
      return props.children;
    }

  }));
};

var chip = '';

template(`<span class="chip__content"></span>`);
      template(`<div class="chip__actions"></div>`);

var table = '';

const _tmpl$$e = template(`<tfoot class="table__footer"></tfoot>`),
      _tmpl$2$7 = template(`<table class="table"><thead class="table__header"><tr class="table__row"></tr></thead><tbody class="table__body"></tbody></table>`),
      _tmpl$3$5 = template(`<th><span class="table__field__label"></span></th>`),
      _tmpl$4$3 = template(`<tr class="table__row"></tr>`),
      _tmpl$5$3 = template(`<td></td>`);

const parseDataFieldAlignment = alignment => {
  switch (alignment) {
    case 'center':
      return 'center';

    case 'end':
      return 'flex-end';

    default:
      return 'flex-start';
  }
};

const DataTable = props => {
  const filteredItems = createMemo(() => {
    if (props.pagination) {
      const limit = props.pagination.limit * props.pagination.page;
      return props.items.slice(limit - props.pagination.limit, limit);
    } else {
      return props.items;
    }
  });
  return (() => {
    const _el$ = _tmpl$2$7.cloneNode(true),
          _el$2 = _el$.firstChild,
          _el$3 = _el$2.firstChild,
          _el$4 = _el$2.nextSibling;

    insert(_el$3, () => props.fields.map(header => (() => {
      const _el$6 = _tmpl$3$5.cloneNode(true),
            _el$7 = _el$6.firstChild;

      insert(_el$7, () => header.text);

      createRenderEffect(_p$ => {
        const _v$ = `table__cell table__column--${header.size}`,
              _v$2 = parseDataFieldAlignment(header.align);

        _v$ !== _p$._v$ && (_el$6.className = _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && _el$6.style.setProperty("justify-content", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$6;
    })()));

    insert(_el$4, createComponent(For, {
      get each() {
        return filteredItems();
      },

      get fallback() {
        return props.fallback;
      },

      children: item => (() => {
        const _el$8 = _tmpl$4$3.cloneNode(true);

        insert(_el$8, createComponent(For, {
          get each() {
            return props.fields;
          },

          children: field => (() => {
            const _el$9 = _tmpl$5$3.cloneNode(true);

            insert(_el$9, (() => {
              const _c$2 = memo(() => typeof field.value === 'function', true);

              return () => _c$2() ? () => field.value(item) : () => item[field.value];
            })());

            createRenderEffect(_p$ => {
              const _v$3 = `table__cell table__column--${field.size}`,
                    _v$4 = parseDataFieldAlignment(field.align);

              _v$3 !== _p$._v$3 && (_el$9.className = _p$._v$3 = _v$3);
              _v$4 !== _p$._v$4 && _el$9.style.setProperty("justify-content", _p$._v$4 = _v$4);
              return _p$;
            }, {
              _v$3: undefined,
              _v$4: undefined
            });

            return _el$9;
          })()
        }));

        return _el$8;
      })()
    }));

    insert(_el$, createComponent(Show, {
      get when() {
        return props.pagination && props.onPaginationUpdate;
      },

      get children() {
        const _el$5 = _tmpl$$e.cloneNode(true);

        insert(_el$5, (() => {
          const _c$ = memo(() => !!(props.pagination && props.onPaginationUpdate), true);

          return () => _c$() ? createComponent(Pagination, {
            get value() {
              return props.pagination;
            },

            get onInput() {
              return props.onPaginationUpdate;
            }

          }) : [];
        })());

        return _el$5;
      }

    }), null);

    return _el$;
  })();
};

var dialog = '';

const _tmpl$$d = template(`<div class="dialog"><div class="dialog__background"></div><div class="dialog__content"></div></div>`);

const Dialog = props => {
  const [showModal, setShowModal] = createSignal(Boolean(props.show));
  createEffect(() => {
    setShowModal(props.show);
  });

  const handleBackgroundClick = () => {
    props.onShowUpdate?.(false);
    setShowModal(false);
  };

  return (() => {
    const _c$ = memo(() => !!showModal(), true);

    return () => _c$() && (() => {
      const _el$ = _tmpl$$d.cloneNode(true),
            _el$2 = _el$.firstChild,
            _el$3 = _el$2.nextSibling;

      const _ref$ = props.ref;
      typeof _ref$ === "function" ? _ref$(_el$) : props.ref = _el$;
      _el$2.$$click = handleBackgroundClick;

      insert(_el$3, () => props.children);

      return _el$;
    })();
  })();
};

delegateEvents(["click"]);

const _tmpl$$c = template(`<div class="cui-p-5 cui-text-center cui-text-gray-700"><div>We couldn't find any results</div><div class="cui-text-sm cui-text-gray-600">Try different filters or search terms</div></div>`);
var EmptyList = (() => (() => {
  const _el$ = _tmpl$$c.cloneNode(true),
        _el$2 = _el$.firstChild;

  insert(_el$, createComponent(Icon, {
    size: "large",
    children: "zoom_out"
  }), _el$2);

  return _el$;
})());

const _tmpl$$b = template(`<div class="expansion-panel__item__header" tabindex="0"><div class="expansion-panel__item__header__content"></div></div>`);

const ExpansionPanelItemHeader = props => {
  const {
    disabled,
    toggle
  } = useExpansionPanelItemContext();

  const toggleExpansion = () => {
    if (!disabled()) {
      toggle();
    }
  };

  const handleKeyPress = e => {
    if (e.code === 'Enter') {
      toggleExpansion();
    }
  };

  return (() => {
    const _el$ = _tmpl$$b.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$.$$keydown = handleKeyPress;
    _el$.$$click = toggleExpansion;

    insert(_el$, createComponent(Btn, {
      btnType: "icon",

      get disabled() {
        return disabled();
      },

      tabIndex: -1,

      get children() {
        return createComponent(Icon, {
          "class": "expansion-panel__item__header__icon",
          children: "expand_more"
        });
      }

    }), _el$2);

    insert(_el$2, () => props.children);

    return _el$;
  })();
};

delegateEvents(["click", "keydown"]);

const _tmpl$$a = template(`<div class="expansion-panel__item__content"></div>`);

const ExpansionPanelItemContent = props => {
  return (() => {
    const _el$ = _tmpl$$a.cloneNode(true);

    insert(_el$, () => props.children);

    return _el$;
  })();
};

const _tmpl$$9 = template(`<div class="expansion-panel__item"></div>`);
const [ExpansionPanelItemProvider, useExpansionPanelItemContext] = createStrictContext();

const ExpansionPanelItem = props => {
  const [expanded, setExpanded] = createSignal(Boolean(props.expanded));
  const [disabled, setDisabled] = createSignal(Boolean(props.disabled));
  createEffect(() => {
    setDisabled(Boolean(props.disabled));
  });
  createEffect(() => {
    setExpanded(Boolean(props.expanded));
  });

  const toggle = () => {
    const newVal = setExpanded(val => !val);
    props.onUpdateExpanded?.(newVal);
  };

  return (() => {
    const _el$ = _tmpl$$9.cloneNode(true);

    insert(_el$, createComponent(ExpansionPanelItemProvider, {
      value: {
        expanded,
        disabled,
        toggle
      },

      get children() {
        return props.children;
      }

    }));

    createRenderEffect(() => _el$.classList.toggle("expansion-panel__item--expanded", !!expanded()));

    return _el$;
  })();
};

ExpansionPanelItem.Header = ExpansionPanelItemHeader;
ExpansionPanelItem.Content = ExpansionPanelItemContent;

var expansion = '';

const _tmpl$$8 = template(`<div class="expansion-panel"></div>`);

const ExpansionPanel = props => {
  return (() => {
    const _el$ = _tmpl$$8.cloneNode(true);

    insert(_el$, () => props.children);

    return _el$;
  })();
};

ExpansionPanel.Item = ExpansionPanelItem;

var header = '';

const _tmpl$$7 = template(`<header class="cui-mb-3 cui-pb-0.5"><h1 class="header"></h1></header>`);

const Header = props => {
  return (() => {
    const _el$ = _tmpl$$7.cloneNode(true),
          _el$2 = _el$.firstChild;

    insert(_el$2, () => props.title);

    return _el$;
  })();
};

var icon = '';

const iconSizeMap = {
  small: '16px',
  default: '24px',
  medium: '28px',
  large: '36px',
  xlarge: '40px'
};

const Icon = props => {
  const [iconProps, attrs] = splitProps(props, ['size', 'children', 'class', 'className', 'classList', 'style']);
  return createComponent(StylableComponent, mergeProps({
    tag: "i",
    "class": "icon material-icons",

    get style() {
      return {
        'font-size': iconSizeMap[iconProps.size || 'default']
      };
    },

    get styleData() {
      return {
        class: iconProps.class,
        className: iconProps.className,
        classList: iconProps.classList,
        style: iconProps.style
      };
    },

    "aria-hidden": true
  }, attrs, {
    get children() {
      return props.children;
    }

  }));
};

var pagination = '';

const _tmpl$$6 = template(`<section class="pagination"><div class="pagination__controls"><label for="limit">Rows per page:</label><select name="limit"></select><span class="pagination__controls__range"></span></div></section>`),
      _tmpl$2$6 = template(`<option></option>`);
var PaginationLimit;

(function (PaginationLimit) {
  PaginationLimit[PaginationLimit["Small"] = 10] = "Small";
  PaginationLimit[PaginationLimit["Medium"] = 25] = "Medium";
  PaginationLimit[PaginationLimit["Large"] = 50] = "Large";
  PaginationLimit[PaginationLimit["XLarge"] = 100] = "XLarge";
})(PaginationLimit || (PaginationLimit = {}));

const limitOptions = Object.values(PaginationLimit).filter(val => !isNaN(Number(val)));

const Pagination = props => {
  const range = createMemo(() => {
    return {
      from: (props.value.page - 1) * props.value.limit + 1,
      to: Math.min(props.value.page * props.value.limit, props.value.total)
    };
  });

  const disabledPrev = () => props.value.page <= 1;

  const disabledNext = () => range().to === props.value.total;

  const updatePageLimit = limit => {
    props.onInput({ ...props.value,
      page: 1,
      limit
    });
  };

  return (() => {
    const _el$ = _tmpl$$6.cloneNode(true),
          _el$2 = _el$.firstChild,
          _el$3 = _el$2.firstChild,
          _el$4 = _el$3.nextSibling,
          _el$5 = _el$4.nextSibling;

    _el$4.$$input = e => updatePageLimit(Number(e.currentTarget.value));

    insert(_el$4, createComponent(For, {
      each: limitOptions,
      children: limitOption => (() => {
        const _el$6 = _tmpl$2$6.cloneNode(true);

        insert(_el$6, limitOption);

        return _el$6;
      })()
    }));

    insert(_el$5, () => `${range().from} - ${range().to} of ${props.value.total}`);

    insert(_el$2, createComponent(Btn, {
      btnType: 'icon',

      get disabled() {
        return disabledPrev();
      },

      onClick: () => props.onInput({ ...props.value,
        page: props.value.page - 1
      }),

      get children() {
        return createComponent(Icon, {
          children: "navigate_before"
        });
      }

    }), null);

    insert(_el$2, createComponent(Btn, {
      btnType: 'icon',

      get disabled() {
        return disabledNext();
      },

      onClick: () => props.onInput({ ...props.value,
        page: props.value.page + 1
      }),

      get children() {
        return createComponent(Icon, {
          children: "navigate_next"
        });
      }

    }), null);

    createRenderEffect(() => _el$4.value = props.value.limit);

    return _el$;
  })();
};

delegateEvents(["input"]);

var search = '';

const _tmpl$$5 = template(`<div class="search-input__append"></div>`),
      _tmpl$2$5 = template(`<div class="search-input"><div class="search-input__prepend"></div><input class="search-input__input"></div>`);

const SearchInput = props => {
  let input = undefined;
  const [value, setValue] = createSignal(props.value);
  const [focused, setFocus] = createSignal(false);
  createEffect(() => {
    setValue(props.value);
  });

  const clear = () => {
    props.onInput?.('');
    setValue('');
  };

  const [_, attrs] = splitProps(props, ['value', 'onInput']);
  return createComponent(Input, {
    get children() {
      const _el$ = _tmpl$2$5.cloneNode(true),
            _el$2 = _el$.firstChild,
            _el$3 = _el$2.nextSibling;

      _el$.addEventListener("focus", () => {
        input?.focus();
      });

      insert(_el$2, createComponent(Icon, {
        children: "search"
      }));

      _el$3.addEventListener("focus", () => setFocus(true));

      _el$3.addEventListener("blur", () => setFocus(false));

      _el$3.$$input = e => {
        debounce_1(() => {
          props.onInput?.(e.target.value);
        }, 500)();
        setValue(e.target.value);
      };

      const _ref$ = input;
      typeof _ref$ === "function" ? _ref$(_el$3) : input = _el$3;

      setAttribute(_el$3, "tabindex", -1);

      spread(_el$3, attrs, false, false);

      insert(_el$, createComponent(Show, {
        get when() {
          return value();
        },

        get children() {
          const _el$4 = _tmpl$$5.cloneNode(true);

          insert(_el$4, createComponent(Btn, {
            btnType: "icon",
            size: "small",
            onClick: () => {
              clear();
            },
            tabIndex: -1,

            get children() {
              return createComponent(Icon, {
                children: "highlight_off"
              });
            }

          }));

          return _el$4;
        }

      }), null);

      createRenderEffect(_p$ => {
        const _v$ = focused(),
              _v$2 = props.disabled,
              _v$3 = !props.disabled ? 0 : undefined,
              _v$4 = value();

        _v$ !== _p$._v$ && _el$.classList.toggle("search-input--focused", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && _el$.classList.toggle("search-input--disabled", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "tabindex", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && (_el$3.value = _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

delegateEvents(["input"]);

const parsePixelValue = val => val ?? typeof val === 'string' ? val : val + 'px';
/**
 * Applys size related css properts based on props set
 * @param Component
 */


const sizeable = Component => {
  return props => {
    const style = { ...props.style,
      width: parsePixelValue(props.width),
      height: parsePixelValue(props.height),
      'min-width': parsePixelValue(props.minWidth),
      'max-width': parsePixelValue(props.maxWidth),
      'min-height': parsePixelValue(props.minHeight),
      'max-height': parsePixelValue(props.maxHeight)
    };
    return createComponent(Component, mergeProps({
      style: style
    }, props));
  };
};

/**
 * Applys elevation shadow styles based on props set
 * @param Component
 */
const elevatable = Component => {
  return props => {
    const classList = { ...props.classList,
      'cui-shadow-elevation-0': props.elevation === 0,
      'cui-shadow-elevation-1': props.elevation === 1,
      'cui-shadow-elevation-2': props.elevation === 2,
      'cui-shadow-elevation-3': props.elevation === 3,
      'cui-shadow-elevation-4': props.elevation === 4,
      'cui-shadow-elevation-5': props.elevation === 5,
      'cui-shadow-elevation-6': props.elevation === 6,
      'cui-shadow-elevation-7': props.elevation === 7,
      'cui-shadow-elevation-8': props.elevation === 8,
      'cui-shadow-elevation-9': props.elevation === 9,
      'cui-shadow-elevation-10': props.elevation === 10,
      'cui-shadow-elevation-11': props.elevation === 11,
      'cui-shadow-elevation-12': props.elevation === 12,
      'cui-shadow-elevation-13': props.elevation === 13,
      'cui-shadow-elevation-14': props.elevation === 14,
      'cui-shadow-elevation-15': props.elevation === 15,
      'cui-shadow-elevation-16': props.elevation === 16,
      'cui-shadow-elevation-17': props.elevation === 17,
      'cui-shadow-elevation-18': props.elevation === 18,
      'cui-shadow-elevation-19': props.elevation === 19,
      'cui-shadow-elevation-20': props.elevation === 20,
      'cui-shadow-elevation-21': props.elevation === 21,
      'cui-shadow-elevation-22': props.elevation === 22,
      'cui-shadow-elevation-23': props.elevation === 23,
      'cui-shadow-elevation-24': props.elevation && props.elevation >= 24
    };
    return createComponent(Component, mergeProps({
      classList: classList
    }, props));
  };
};

var sheet = '';

const Sheet = props => {
  const local = mergeProps({
    tag: 'div',
    elevation: 0
  }, props);
  return createComponent(StylableComponent, {
    get tag() {
      return local.tag;
    },

    "class": 'sheet',

    get styleData() {
      return {
        class: props.class,
        style: props.style,
        classList: props.classList,
        className: props.className
      };
    },

    get children() {
      return props.children;
    }

  });
};

var Sheet$1 = elevatable(sizeable(Sheet));

const _tmpl$$4 = template(`<div class="cui-px-4 cui-sm:px-6"><div class="cui-flex"><div class="cui-flex-grow"><h2 class="cui-text-lg cui-font-medium cui-text-gray-900" id="slide-over-title"></h2></div><div class="cui-flex-shrink"><button type="button" class="cui-rounded-md cui-text-gray-500  hover:cui-text-gray-900 focus:cui-outline-none focus:cui-ring-2 focus:cui-ring-white"><span class="cui-sr-only">Close panel</span></button></div></div></div>`),
      _tmpl$2$4 = template(`<div class="cui-mt-6 cui-relative cui-flex-1 cui-px-4 cui-sm:px-6"></div>`),
      _tmpl$3$4 = template(`<div class="cui-fixed cui-inset-0 cui-overflow-hidden" aria-labelledby="slide-over-title" role="dialog" aria-modal="true"><div class="cui-absolute cui-inset-0 cui-overflow-hidden"><div class="cui-absolute cui-inset-0 cui-bg-gray-500 cui-bg-opacity-75 cui-transition-opacity" aria-hidden="true"></div><div class="cui-fixed cui-inset-y-0 cui-right-0 cui-pl-10 cui-max-w-full cui-flex"><div class="cui-relative cui-w-screen cui-max-w-md"></div></div></div></div>`);

const Sidebar = props => (() => {
  const _el$ = _tmpl$3$4.cloneNode(true),
        _el$2 = _el$.firstChild,
        _el$3 = _el$2.firstChild,
        _el$4 = _el$3.nextSibling,
        _el$5 = _el$4.firstChild;

  insert(_el$5, createComponent(Sheet$1, {
    "class": "cui-h-full cui-flex cui-flex-col cui-py-6 cui-shadow-xl cui-overflow-y-scroll cui-pt-5",

    get children() {
      return [(() => {
        const _el$6 = _tmpl$$4.cloneNode(true),
              _el$7 = _el$6.firstChild,
              _el$8 = _el$7.firstChild,
              _el$9 = _el$8.firstChild,
              _el$10 = _el$8.nextSibling,
              _el$11 = _el$10.firstChild;
              _el$11.firstChild;

        insert(_el$9, () => props.title);

        addEventListener(_el$11, "click", props.onClose, true);

        insert(_el$11, createComponent(Icon, {
          children: "close"
        }), null);

        return _el$6;
      })(), (() => {
        const _el$13 = _tmpl$2$4.cloneNode(true);

        insert(_el$13, () => props.children);

        return _el$13;
      })()];
    }

  }));

  return _el$;
})();

delegateEvents(["click"]);

function ResourceLoader(props) {
  return createComponent(Switch, {
    get children() {
      return [createComponent(Match, {
        get when() {
          return props.resource.loading;
        },

        children: "Loading..."
      }), createComponent(Match, {
        get when() {
          return props.resource.error;
        },

        children: "Something went wrong"
      }), createComponent(Match, {
        get when() {
          return props.resource();
        },

        get children() {
          return props.children(props.resource());
        }

      })];
    }

  });
}

const $RAW = Symbol("store-raw"),
      $NODE = Symbol("store-node"),
      $NAME = Symbol("store-name");
function wrap$1(value, name) {
  let p = value[$PROXY];
  if (!p) {
    Object.defineProperty(value, $PROXY, {
      value: p = new Proxy(value, proxyTraps$1)
    });
    const keys = Object.keys(value),
          desc = Object.getOwnPropertyDescriptors(value);
    for (let i = 0, l = keys.length; i < l; i++) {
      const prop = keys[i];
      if (desc[prop].get) {
        const get = desc[prop].get.bind(p);
        Object.defineProperty(value, prop, {
          get
        });
      }
    }
  }
  return p;
}
function isWrappable(obj) {
  return obj != null && typeof obj === "object" && (!obj.__proto__ || obj.__proto__ === Object.prototype || Array.isArray(obj));
}
function unwrap(item, set = new Set()) {
  let result, unwrapped, v, prop;
  if (result = item != null && item[$RAW]) return result;
  if (!isWrappable(item) || set.has(item)) return item;
  if (Array.isArray(item)) {
    if (Object.isFrozen(item)) item = item.slice(0);else set.add(item);
    for (let i = 0, l = item.length; i < l; i++) {
      v = item[i];
      if ((unwrapped = unwrap(v, set)) !== v) item[i] = unwrapped;
    }
  } else {
    if (Object.isFrozen(item)) item = Object.assign({}, item);else set.add(item);
    const keys = Object.keys(item),
          desc = Object.getOwnPropertyDescriptors(item);
    for (let i = 0, l = keys.length; i < l; i++) {
      prop = keys[i];
      if (desc[prop].get) continue;
      v = item[prop];
      if ((unwrapped = unwrap(v, set)) !== v) item[prop] = unwrapped;
    }
  }
  return item;
}
function getDataNodes(target) {
  let nodes = target[$NODE];
  if (!nodes) Object.defineProperty(target, $NODE, {
    value: nodes = {}
  });
  return nodes;
}
function proxyDescriptor(target, property) {
  const desc = Reflect.getOwnPropertyDescriptor(target, property);
  if (!desc || desc.get || property === $PROXY || property === $NODE || property === $NAME) return desc;
  delete desc.value;
  delete desc.writable;
  desc.get = () => target[$PROXY][property];
  return desc;
}
function ownKeys(target) {
  if (getListener()) {
    const nodes = getDataNodes(target);
    (nodes._ || (nodes._ = createDataNode()))();
  }
  return Reflect.ownKeys(target);
}
function createDataNode() {
  const [s, set] = createSignal(undefined, {
    equals: false,
    internal: true
  });
  s.$ = set;
  return s;
}
const proxyTraps$1 = {
  get(target, property, receiver) {
    if (property === $RAW) return target;
    if (property === $PROXY) return receiver;
    const value = target[property];
    if (property === $NODE || property === "__proto__") return value;
    const wrappable = isWrappable(value);
    if (getListener() && (typeof value !== "function" || target.hasOwnProperty(property))) {
      let nodes, node;
      if (wrappable && (nodes = getDataNodes(value))) {
        node = nodes._ || (nodes._ = createDataNode());
        node();
      }
      nodes = getDataNodes(target);
      node = nodes[property] || (nodes[property] = createDataNode());
      node();
    }
    return wrappable ? wrap$1(value) : value;
  },
  set() {
    return true;
  },
  deleteProperty() {
    return true;
  },
  ownKeys: ownKeys,
  getOwnPropertyDescriptor: proxyDescriptor
};
function setProperty(state, property, value) {
  if (state[property] === value) return;
  const array = Array.isArray(state);
  const len = state.length;
  const isUndefined = value === undefined;
  const notify = array || isUndefined === property in state;
  if (isUndefined) {
    delete state[property];
  } else state[property] = value;
  let nodes = getDataNodes(state),
      node;
  (node = nodes[property]) && node.$();
  if (array && state.length !== len) (node = nodes.length) && node.$();
  notify && (node = nodes._) && node.$();
}
function mergeStoreNode(state, value) {
  const keys = Object.keys(value);
  for (let i = 0; i < keys.length; i += 1) {
    const key = keys[i];
    setProperty(state, key, value[key]);
  }
}
function updatePath(current, path, traversed = []) {
  let part,
      prev = current;
  if (path.length > 1) {
    part = path.shift();
    const partType = typeof part,
          isArray = Array.isArray(current);
    if (Array.isArray(part)) {
      for (let i = 0; i < part.length; i++) {
        updatePath(current, [part[i]].concat(path), [part[i]].concat(traversed));
      }
      return;
    } else if (isArray && partType === "function") {
      for (let i = 0; i < current.length; i++) {
        if (part(current[i], i)) updatePath(current, [i].concat(path), [i].concat(traversed));
      }
      return;
    } else if (isArray && partType === "object") {
      const {
        from = 0,
        to = current.length - 1,
        by = 1
      } = part;
      for (let i = from; i <= to; i += by) {
        updatePath(current, [i].concat(path), [i].concat(traversed));
      }
      return;
    } else if (path.length > 1) {
      updatePath(current[part], path, [part].concat(traversed));
      return;
    }
    prev = current[part];
    traversed = [part].concat(traversed);
  }
  let value = path[0];
  if (typeof value === "function") {
    value = value(prev, traversed);
    if (value === prev) return;
  }
  if (part === undefined && value == undefined) return;
  value = unwrap(value);
  if (part === undefined || isWrappable(prev) && isWrappable(value) && !Array.isArray(value)) {
    mergeStoreNode(prev, value);
  } else setProperty(current, part, value);
}
function createStore(store, options) {
  const unwrappedStore = unwrap(store || {});
  const wrappedStore = wrap$1(unwrappedStore);
  function setStore(...args) {
    batch(() => updatePath(unwrappedStore, args));
  }
  return [wrappedStore, setStore];
}

const djangoListBaseSchema = external.object({
  count: external.number(),
  next: external.string().nullable(),
  previous: external.string().nullable()
});

class HTTPError extends Error {
    constructor(response, request, options) {
        const code = (response.status || response.status === 0) ? response.status : '';
        const title = response.statusText || '';
        const status = `${code} ${title}`.trim();
        const reason = status ? `status code ${status}` : 'an unknown error';
        super(`Request failed with ${reason}`);
        this.name = 'HTTPError';
        this.response = response;
        this.request = request;
        this.options = options;
    }
}

class TimeoutError extends Error {
    constructor(request) {
        super('Request timed out');
        this.name = 'TimeoutError';
        this.request = request;
    }
}

// eslint-disable-next-line @typescript-eslint/ban-types
const isObject = (value) => value !== null && typeof value === 'object';

const validateAndMerge = (...sources) => {
    for (const source of sources) {
        if ((!isObject(source) || Array.isArray(source)) && typeof source !== 'undefined') {
            throw new TypeError('The `options` argument must be an object');
        }
    }
    return deepMerge({}, ...sources);
};
const mergeHeaders = (source1 = {}, source2 = {}) => {
    const result = new globalThis.Headers(source1);
    const isHeadersInstance = source2 instanceof globalThis.Headers;
    const source = new globalThis.Headers(source2);
    for (const [key, value] of source.entries()) {
        if ((isHeadersInstance && value === 'undefined') || value === undefined) {
            result.delete(key);
        }
        else {
            result.set(key, value);
        }
    }
    return result;
};
const deepMerge = (...sources) => {
    let returnValue = {};
    let headers = {};
    for (const source of sources) {
        if (Array.isArray(source)) {
            if (!Array.isArray(returnValue)) {
                returnValue = [];
            }
            returnValue = [...returnValue, ...source];
        }
        else if (isObject(source)) {
            for (let [key, value] of Object.entries(source)) {
                if (isObject(value) && key in returnValue) {
                    value = deepMerge(returnValue[key], value);
                }
                returnValue = { ...returnValue, [key]: value };
            }
            if (isObject(source.headers)) {
                headers = mergeHeaders(headers, source.headers);
                returnValue.headers = headers;
            }
        }
    }
    return returnValue;
};

const supportsAbortController = typeof globalThis.AbortController === 'function';
const supportsStreams = typeof globalThis.ReadableStream === 'function';
const supportsFormData = typeof globalThis.FormData === 'function';
const requestMethods = ['get', 'post', 'put', 'patch', 'head', 'delete'];
const responseTypes = {
    json: 'application/json',
    text: 'text/*',
    formData: 'multipart/form-data',
    arrayBuffer: '*/*',
    blob: '*/*'
};
// The maximum value of a 32bit int (see issue #117)
const maxSafeTimeout = 2147483647;
const stop = Symbol('stop');

const normalizeRequestMethod = (input) => requestMethods.includes(input) ? input.toUpperCase() : input;
const retryMethods = ['get', 'put', 'head', 'delete', 'options', 'trace'];
const retryStatusCodes = [408, 413, 429, 500, 502, 503, 504];
const retryAfterStatusCodes = [413, 429, 503];
const defaultRetryOptions = {
    limit: 2,
    methods: retryMethods,
    statusCodes: retryStatusCodes,
    afterStatusCodes: retryAfterStatusCodes,
    maxRetryAfter: Number.POSITIVE_INFINITY
};
const normalizeRetryOptions = (retry = {}) => {
    if (typeof retry === 'number') {
        return {
            ...defaultRetryOptions,
            limit: retry
        };
    }
    if (retry.methods && !Array.isArray(retry.methods)) {
        throw new Error('retry.methods must be an array');
    }
    if (retry.statusCodes && !Array.isArray(retry.statusCodes)) {
        throw new Error('retry.statusCodes must be an array');
    }
    return {
        ...defaultRetryOptions,
        ...retry,
        afterStatusCodes: retryAfterStatusCodes
    };
};

// `Promise.race()` workaround (#91)
const timeout = async (request, abortController, options) => new Promise((resolve, reject) => {
    const timeoutID = setTimeout(() => {
        if (abortController) {
            abortController.abort();
        }
        reject(new TimeoutError(request));
    }, options.timeout);
    /* eslint-disable promise/prefer-await-to-then */
    void options
        .fetch(request)
        .then(resolve)
        .catch(reject)
        .then(() => {
        clearTimeout(timeoutID);
    });
    /* eslint-enable promise/prefer-await-to-then */
});
const delay = async (ms) => new Promise(resolve => {
    setTimeout(resolve, ms);
});

class Ky {
    // eslint-disable-next-line complexity
    constructor(input, options = {}) {
        var _a, _b;
        this._retryCount = 0;
        this._input = input;
        this._options = {
            // TODO: credentials can be removed when the spec change is implemented in all browsers. Context: https://www.chromestatus.com/feature/4539473312350208
            credentials: this._input.credentials || 'same-origin',
            ...options,
            headers: mergeHeaders(this._input.headers, options.headers),
            hooks: deepMerge({
                beforeRequest: [],
                beforeRetry: [],
                afterResponse: []
            }, options.hooks),
            method: normalizeRequestMethod((_a = options.method) !== null && _a !== void 0 ? _a : this._input.method),
            // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
            prefixUrl: String(options.prefixUrl || ''),
            retry: normalizeRetryOptions(options.retry),
            throwHttpErrors: options.throwHttpErrors !== false,
            timeout: typeof options.timeout === 'undefined' ? 10000 : options.timeout,
            fetch: (_b = options.fetch) !== null && _b !== void 0 ? _b : globalThis.fetch.bind(globalThis)
        };
        if (typeof this._input !== 'string' && !(this._input instanceof URL || this._input instanceof globalThis.Request)) {
            throw new TypeError('`input` must be a string, URL, or Request');
        }
        if (this._options.prefixUrl && typeof this._input === 'string') {
            if (this._input.startsWith('/')) {
                throw new Error('`input` must not begin with a slash when using `prefixUrl`');
            }
            if (!this._options.prefixUrl.endsWith('/')) {
                this._options.prefixUrl += '/';
            }
            this._input = this._options.prefixUrl + this._input;
        }
        if (supportsAbortController) {
            this.abortController = new globalThis.AbortController();
            if (this._options.signal) {
                this._options.signal.addEventListener('abort', () => {
                    this.abortController.abort();
                });
            }
            this._options.signal = this.abortController.signal;
        }
        this.request = new globalThis.Request(this._input, this._options);
        if (this._options.searchParams) {
            // eslint-disable-next-line unicorn/prevent-abbreviations
            const textSearchParams = typeof this._options.searchParams === 'string' ?
                this._options.searchParams.replace(/^\?/, '') :
                new URLSearchParams(this._options.searchParams).toString();
            // eslint-disable-next-line unicorn/prevent-abbreviations
            const searchParams = '?' + textSearchParams;
            const url = this.request.url.replace(/(?:\?.*?)?(?=#|$)/, searchParams);
            // To provide correct form boundary, Content-Type header should be deleted each time when new Request instantiated from another one
            if (((supportsFormData && this._options.body instanceof globalThis.FormData) ||
                this._options.body instanceof URLSearchParams) && !(this._options.headers && this._options.headers['content-type'])) {
                this.request.headers.delete('content-type');
            }
            this.request = new globalThis.Request(new globalThis.Request(url, this.request), this._options);
        }
        if (this._options.json !== undefined) {
            this._options.body = JSON.stringify(this._options.json);
            this.request.headers.set('content-type', 'application/json');
            this.request = new globalThis.Request(this.request, { body: this._options.body });
        }
    }
    // eslint-disable-next-line @typescript-eslint/promise-function-async
    static create(input, options) {
        const ky = new Ky(input, options);
        const fn = async () => {
            if (ky._options.timeout > maxSafeTimeout) {
                throw new RangeError(`The \`timeout\` option cannot be greater than ${maxSafeTimeout}`);
            }
            // Delay the fetch so that body method shortcuts can set the Accept header
            await Promise.resolve();
            let response = await ky._fetch();
            for (const hook of ky._options.hooks.afterResponse) {
                // eslint-disable-next-line no-await-in-loop
                const modifiedResponse = await hook(ky.request, ky._options, ky._decorateResponse(response.clone()));
                if (modifiedResponse instanceof globalThis.Response) {
                    response = modifiedResponse;
                }
            }
            ky._decorateResponse(response);
            if (!response.ok && ky._options.throwHttpErrors) {
                throw new HTTPError(response, ky.request, ky._options);
            }
            // If `onDownloadProgress` is passed, it uses the stream API internally
            /* istanbul ignore next */
            if (ky._options.onDownloadProgress) {
                if (typeof ky._options.onDownloadProgress !== 'function') {
                    throw new TypeError('The `onDownloadProgress` option must be a function');
                }
                if (!supportsStreams) {
                    throw new Error('Streams are not supported in your environment. `ReadableStream` is missing.');
                }
                return ky._stream(response.clone(), ky._options.onDownloadProgress);
            }
            return response;
        };
        const isRetriableMethod = ky._options.retry.methods.includes(ky.request.method.toLowerCase());
        const result = (isRetriableMethod ? ky._retry(fn) : fn());
        for (const [type, mimeType] of Object.entries(responseTypes)) {
            result[type] = async () => {
                // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
                ky.request.headers.set('accept', ky.request.headers.get('accept') || mimeType);
                const response = (await result).clone();
                if (type === 'json') {
                    if (response.status === 204) {
                        return '';
                    }
                    if (options.parseJson) {
                        return options.parseJson(await response.text());
                    }
                }
                return response[type]();
            };
        }
        return result;
    }
    _calculateRetryDelay(error) {
        this._retryCount++;
        if (this._retryCount < this._options.retry.limit && !(error instanceof TimeoutError)) {
            if (error instanceof HTTPError) {
                if (!this._options.retry.statusCodes.includes(error.response.status)) {
                    return 0;
                }
                const retryAfter = error.response.headers.get('Retry-After');
                if (retryAfter && this._options.retry.afterStatusCodes.includes(error.response.status)) {
                    let after = Number(retryAfter);
                    if (Number.isNaN(after)) {
                        after = Date.parse(retryAfter) - Date.now();
                    }
                    else {
                        after *= 1000;
                    }
                    if (typeof this._options.retry.maxRetryAfter !== 'undefined' && after > this._options.retry.maxRetryAfter) {
                        return 0;
                    }
                    return after;
                }
                if (error.response.status === 413) {
                    return 0;
                }
            }
            const BACKOFF_FACTOR = 0.3;
            return BACKOFF_FACTOR * (2 ** (this._retryCount - 1)) * 1000;
        }
        return 0;
    }
    _decorateResponse(response) {
        if (this._options.parseJson) {
            response.json = async () => {
                return this._options.parseJson(await response.text());
            };
        }
        return response;
    }
    async _retry(fn) {
        try {
            return await fn();
            // eslint-disable-next-line @typescript-eslint/no-implicit-any-catch
        }
        catch (error) {
            const ms = Math.min(this._calculateRetryDelay(error), maxSafeTimeout);
            if (ms !== 0 && this._retryCount > 0) {
                await delay(ms);
                for (const hook of this._options.hooks.beforeRetry) {
                    // eslint-disable-next-line no-await-in-loop
                    const hookResult = await hook({
                        request: this.request,
                        options: this._options,
                        error: error,
                        retryCount: this._retryCount
                    });
                    // If `stop` is returned from the hook, the retry process is stopped
                    if (hookResult === stop) {
                        return;
                    }
                }
                return this._retry(fn);
            }
            throw error;
        }
    }
    async _fetch() {
        for (const hook of this._options.hooks.beforeRequest) {
            // eslint-disable-next-line no-await-in-loop
            const result = await hook(this.request, this._options);
            if (result instanceof Request) {
                this.request = result;
                break;
            }
            if (result instanceof Response) {
                return result;
            }
        }
        if (this._options.timeout === false) {
            return this._options.fetch(this.request.clone());
        }
        return timeout(this.request.clone(), this.abortController, this._options);
    }
    /* istanbul ignore next */
    _stream(response, onDownloadProgress) {
        const totalBytes = Number(response.headers.get('content-length')) || 0;
        let transferredBytes = 0;
        return new globalThis.Response(new globalThis.ReadableStream({
            async start(controller) {
                const reader = response.body.getReader();
                if (onDownloadProgress) {
                    onDownloadProgress({ percent: 0, transferredBytes: 0, totalBytes }, new Uint8Array());
                }
                async function read() {
                    const { done, value } = await reader.read();
                    if (done) {
                        controller.close();
                        return;
                    }
                    if (onDownloadProgress) {
                        transferredBytes += value.byteLength;
                        const percent = totalBytes === 0 ? 0 : transferredBytes / totalBytes;
                        onDownloadProgress({ percent, transferredBytes, totalBytes }, value);
                    }
                    controller.enqueue(value);
                    await read();
                }
                await read();
            }
        }));
    }
}

/*! MIT License © Sindre Sorhus */
const createInstance = (defaults) => {
    // eslint-disable-next-line @typescript-eslint/promise-function-async
    const ky = (input, options) => Ky.create(input, validateAndMerge(defaults, options));
    for (const method of requestMethods) {
        // eslint-disable-next-line @typescript-eslint/promise-function-async
        ky[method] = (input, options) => Ky.create(input, validateAndMerge(defaults, options, { method }));
    }
    ky.create = (newDefaults) => createInstance(validateAndMerge(newDefaults));
    ky.extend = (newDefaults) => createInstance(validateAndMerge(defaults, newDefaults));
    ky.stop = stop;
    return ky;
};
const ky = createInstance();
var ky$1 = ky;

const CognitoStorageBase = "CognitoIdentityServiceProvider.48deo8skov5r59ghj5vqu8hv2h";
const protectedAPI = ky$1.extend({
  hooks: {
    beforeRequest: [
      (request) => {
        const lastAuthUser = localStorage.getItem(`${CognitoStorageBase}.LastAuthUser`);
        request.headers.set("Authorization", `Bearer ${localStorage.getItem(`${CognitoStorageBase}.${lastAuthUser}.accessToken`)}`);
      }
    ]
  }
});
const projectAPI = protectedAPI.extend({
  prefixUrl: "/api/projects"
});
const platformAPI = protectedAPI.extend({
  prefixUrl: "/api/platform"
});

const channelSchema = external.object({
  id: external.string(),
  name: external.string(),
  slug: external.string()
});
const clientSchema = external.object({
  id: external.string(),
  name: external.string(),
  state: external.string(),
  channels: external.array(channelSchema)
});
const clientListSchema = djangoListBaseSchema.extend({
  results: external.array(clientSchema)
});
const useClientList = () => {
  const filterStore = createStore({
    limit: 10,
    search: "",
    state: ["active", "pending"].join(","),
    ordering: "name",
    view: "nested"
  });
  const [filters] = filterStore;
  const autoRefreshParams = createMemo(() => ({
    search: filters.search
  }));
  const resource = createResource(autoRefreshParams, () => platformAPI.get("clients", {
    searchParams: filters
  }).then((res) => res.json()).then((r) => clientListSchema.parse(r)).then((res) => {
    if (filters.search.toLowerCase() === "blank") {
      res.results.push({
        id: "BLANK",
        name: "BLANK",
        channels: [],
        state: "active"
      });
    }
    return res;
  }));
  return {
    filters: filterStore,
    resource
  };
};
function fetchClient(id, searchParams) {
  return platformAPI.get(`clients/${id}`, {
    searchParams
  }).then((res) => res.json()).then((r) => runtimeParse(clientSchema, r));
}

const projectChannelSchema = external.object({
  channel_id: external.string(),
  channel_name: external.string(),
  channel_slug: external.string()
});
const projectSchema = external.object({
  forecast_project_name: external.string(),
  forecast_project_id: external.string(),
  cc_client_name: external.string(),
  cc_client_id: external.string(),
  channels: external.array(projectChannelSchema)
});
const projectListSchema = external.object({
  result: external.array(projectSchema),
  page: external.number(),
  max_page: external.number(),
  total_results_count: external.number()
});
external.object({
  search: external.string(),
  clients: external.array(clientSchema),
  channels: external.string().optional(),
  pageLimit: external.number()
});
const useProjectList = () => {
  const filterStore = createStore({
    search: "",
    clients: [],
    channels: void 0,
    pageLimit: 10
  });
  const [filters] = filterStore;
  const autoRefreshParams = createMemo(() => ({
    projects: filters.search ? [filters.search] : void 0,
    clients: filters.clients.map((client) => client.id),
    channels: filters.channels ? [filters.channels] : void 0,
    pageLimit: filters.pageLimit
  }));
  const resource = createResource(autoRefreshParams, (json) => projectAPI.post("linking", {
    json
  }).then((res) => res.json()).then((res) => runtimeParse(projectListSchema, res)));
  return {
    filters: filterStore,
    resource,
    async loadMore() {
      const nextPage = await projectAPI.post("linking", {
        json: {
          ...autoRefreshParams(),
          page: Number(resource[0]()?.page) + 1
        }
      }).then((res) => res.json()).then((res) => runtimeParse(projectListSchema, res));
      resource[1].mutate((prev) => {
        if (!prev)
          return nextPage;
        return {
          ...nextPage,
          result: [...prev.result, ...nextPage.result]
        };
      });
    }
  };
};
function projectDataFunction({ params }) {
  const [project, { mutate, refetch }] = createResource(() => params.id, (id) => {
    return projectAPI.get(`linking/${id}`).then((res) => res.json()).then((res) => runtimeParse(projectSchema, res.result[0]));
  });
  return {
    project,
    async removeChannel(projectId, channel) {
      await removeChannelFromProject(projectId, channel);
      if (project()?.channels.length === 1) {
        refetch();
      } else {
        mutate((prev) => {
          if (!prev)
            return;
          return {
            ...prev,
            channels: prev.channels.filter((ch) => ch.channel_name !== channel.channel_name)
          };
        });
      }
    },
    async addChannelToProject(projectId, channel) {
      await addChannelToProject(projectId, channel);
      if (project()?.channels.length === 0) {
        refetch();
      } else {
        mutate((prev) => {
          if (!prev)
            return;
          return {
            ...prev,
            channels: [channel, ...prev.channels]
          };
        });
      }
    }
  };
}
function removeChannelFromProject(projectId, channel) {
  return projectAPI.delete(`linking/${projectId}`, {
    json: { channel_name: channel.channel_name }
  });
}
function addChannelToProject(projectId, channel) {
  return projectAPI.post(`linking/${projectId}`, {
    json: {
      channel_id: channel.channel_id
    }
  });
}

const _tmpl$$3 = template(`<input class="input" placeholder="search">`),
      _tmpl$2$3 = template(`<div class="cui-flex"><div class="cui-flex-initial"></div><div class="cui-flex-grow"></div><div class="cui-flex-initial"></div></div>`),
      _tmpl$3$3 = template(`<select class="input"><option>None</option></select>`),
      _tmpl$4$2 = template(`<div class="cui-flex cui-mb-4 cui-mt-2"><div class="cui-flex-grow"></div><div class="cui-flex-grow"></div></div>`),
      _tmpl$5$2 = template(`<option></option>`),
      _tmpl$6$2 = template(`<div class="cui-mt-4 cui-text-center"></div>`);

const ProjectIndex = () => {
  const {
    filters: [filters, setFilters],
    resource: [projectResource],
    loadMore
  } = useProjectList();
  const {
    resource: [clientResource],
    filters: [_, setClientFiters]
  } = useClientList();
  const channelList = createMemo(() => {
    const channelSet = filters.clients.reduce((agg, cur) => {
      cur.channels.forEach(channel => agg.add(channel.name));
      return agg;
    }, new Set());
    return Array.from(channelSet);
  });
  return [createComponent(Sheet$1, {
    "class": "cui-m-1 cui-p-5",
    elevation: 2,

    get children() {
      return [(() => {
        const _el$ = _tmpl$2$3.cloneNode(true),
              _el$2 = _el$.firstChild,
              _el$3 = _el$2.nextSibling,
              _el$4 = _el$3.nextSibling;

        insert(_el$2, createComponent(Header, {
          title: "Projects"
        }));

        insert(_el$4, createComponent(Input, {
          get children() {
            const _el$5 = _tmpl$$3.cloneNode(true);

            addEventListener(_el$5, "input", debounce_1(e => setFilters('search', e.target?.value), 500), true);

            createRenderEffect(() => _el$5.value = filters.search);

            return _el$5;
          }

        }));

        return _el$;
      })(), (() => {
        const _el$6 = _tmpl$4$2.cloneNode(true),
              _el$7 = _el$6.firstChild,
              _el$8 = _el$7.nextSibling;

        insert(_el$7, createComponent(AutoComplete, {
          resource: clientResource,
          setFilters: setClientFiters,
          multiple: true,
          onInput: val => setFilters('clients', val),

          get value() {
            return filters.clients;
          },

          label: "Client"
        }));

        insert(_el$8, createComponent(Input, {
          label: "Channels",
          name: "channels",

          get children() {
            const _el$9 = _tmpl$3$3.cloneNode(true);
                  _el$9.firstChild;

            _el$9.$$input = e => setFilters('channels', e.currentTarget.value);

            insert(_el$9, createComponent(For, {
              get each() {
                return channelList();
              },

              children: item => (() => {
                const _el$11 = _tmpl$5$2.cloneNode(true);

                _el$11.value = item;

                insert(_el$11, item);

                return _el$11;
              })()
            }), null);

            createRenderEffect(_p$ => {
              const _v$ = filters.channels,
                    _v$2 = filters.clients.length === 0;

              _v$ !== _p$._v$ && (_el$9.value = _p$._v$ = _v$);
              _v$2 !== _p$._v$2 && (_el$9.disabled = _p$._v$2 = _v$2);
              return _p$;
            }, {
              _v$: undefined,
              _v$2: undefined
            });

            return _el$9;
          }

        }));

        return _el$6;
      })(), createComponent(ResourceLoader, {
        resource: projectResource,
        children: data => [createComponent(DataTable, {
          get items() {
            return data?.result ?? [];
          },

          fields: [{
            text: 'Project Name',
            value: 'forecast_project_name',
            size: 3
          }, {
            text: 'Project id',
            value: 'forecast_project_id',
            size: 1
          }, {
            text: 'Client',
            value: 'cc_client_name',
            size: 2
          }, {
            text: 'Channels',
            value: project => project.channels.map(c => c.channel_name).join(', '),
            size: 5
          }, {
            text: 'Actions',
            value: item => createComponent(Link, {
              get href() {
                return `/projects/${item.forecast_project_id}`;
              },

              get children() {
                return createComponent(Btn, {
                  btnType: "icon",

                  get children() {
                    return createComponent(Icon, {
                      children: "navigate_next"
                    });
                  }

                });
              }

            }),
            align: 'center',
            size: 1
          }],

          get fallback() {
            return createComponent(EmptyList, {});
          }

        }), (() => {
          const _el$12 = _tmpl$6$2.cloneNode(true);

          insert(_el$12, createComponent(Show, {
            get when() {
              return Number(data?.page) < Number(data?.max_page);
            },

            get children() {
              return createComponent(Btn, {
                btnType: "text",
                onClick: loadMore,
                children: "Load More"
              });
            }

          }));

          return _el$12;
        })()]
      })];
    }

  }), createComponent(Outlet, {})];
};

delegateEvents(["input"]);

const _tmpl$$2 = template(`<div class="cui-flex"><div class="cui-flex-grow cui-pr-2"></div><div class="cui-flex-shrink cui-pr-2"></div></div>`),
      _tmpl$2$2 = template(`<div class="cui-mt-4"></div>`),
      _tmpl$3$2 = template(`<select class="input"><option value="" selected hidden></option></select>`),
      _tmpl$4$1 = template(`<div class="cui-mt-2 cui-mb-4"><div class="label">Channel</div><div class="cui-flex cui-align-bottom"><div class="cui-flex-grow cui-pr-2"></div><div class="cui-text-xs"></div></div></div>`),
      _tmpl$5$1 = template(`<div class="cui-my-4"><h2 class="cui-text-lg cui-font-medium cui-text-gray-900 cui-mb-2">Linked channels</h2></div>`),
      _tmpl$6$1 = template(`<option>No Channels left</option>`),
      _tmpl$7 = template(`<option></option>`),
      _tmpl$8 = template(`<div class="cui-p-5 cui-text-center cui-text-gray-700">No channels are currently linked. Why not add one above?</div>`);

const ViewSidebar = () => {
  const navigate = useNavigate();
  const {
    project,
    removeChannel,
    addChannelToProject
  } = useData();
  const {
    resource: [ClientListResource],
    filters: [_, setFilters]
  } = useClientList();

  function close() {
    navigate('/projects');
  }

  const [loading, setLoading] = createSignal(false);
  const [channelId, setChannel] = createSignal();
  const [client, setClient] = createSignal();
  const selectedChannel = createMemo(() => {
    if (!channelId()) return;
    const foundChannel = client()?.channels.find(channel => channel.id === channelId());
    return foundChannel ? {
      channel_id: foundChannel.id,
      channel_name: foundChannel.name,
      channel_slug: foundChannel.slug
    } : undefined;
  });
  createEffect(() => {
    if (!project()) return;
    fetchClient(project()?.cc_client_id ?? '', {
      view: 'nested'
    }).then(setClient);
  });

  function confirmAndRemoveChannel(projectId, channel) {
    const confirmed = confirm(`Are you sure you want to unlink the ${channel.channel_name} channel from this project?`);
    if (!confirmed) return;
    removeChannel(projectId, channel);
  }

  return createComponent(Sidebar, {
    title: "Project info (from Forecast)",
    onClose: close,

    get children() {
      return createComponent(ResourceLoader, {
        resource: project,
        children: data => [(() => {
          const _el$ = _tmpl$$2.cloneNode(true),
                _el$2 = _el$.firstChild,
                _el$3 = _el$2.nextSibling;

          insert(_el$2, createComponent(Input, {
            label: "Project name",

            get children() {
              return data?.forecast_project_name;
            }

          }));

          insert(_el$3, createComponent(Input, {
            label: "Project ID",

            get children() {
              return data?.forecast_project_id;
            }

          }));

          return _el$;
        })(), (() => {
          const _el$4 = _tmpl$2$2.cloneNode(true);

          insert(_el$4, createComponent(Input, {
            label: "Client",

            get children() {
              return createComponent(Show, {
                get when() {
                  return !data?.channels.length;
                },

                fallback: () => data?.cc_client_name,

                get children() {
                  return createComponent(AutoComplete, {
                    setFilters: setFilters,
                    resource: ClientListResource,

                    get value() {
                      return client();
                    },

                    onInput: val => setClient(val)
                  });
                }

              });
            }

          }));

          return _el$4;
        })(), (() => {
          const _el$5 = _tmpl$4$1.cloneNode(true),
                _el$6 = _el$5.firstChild,
                _el$7 = _el$6.nextSibling,
                _el$8 = _el$7.firstChild,
                _el$11 = _el$8.nextSibling;

          insert(_el$8, createComponent(Input, {
            get children() {
              return createComponent(Show, {
                get when() {
                  return client();
                },

                get children() {
                  const _el$9 = _tmpl$3$2.cloneNode(true);
                        _el$9.firstChild;

                  _el$9.$$input = e => setChannel(e.currentTarget.value);

                  insert(_el$9, createComponent(For, {
                    get each() {
                      return client()?.channels.filter(channel => data?.channels.every(c => c.channel_id !== channel.id));
                    },

                    get fallback() {
                      return _tmpl$6$1.cloneNode(true);
                    },

                    children: channel => (() => {
                      const _el$15 = _tmpl$7.cloneNode(true);

                      insert(_el$15, () => channel.name);

                      createRenderEffect(() => _el$15.value = channel.id);

                      return _el$15;
                    })()
                  }), null);

                  createRenderEffect(() => _el$9.value = channelId());

                  return _el$9;
                }

              });
            }

          }));

          insert(_el$11, createComponent(Btn, {
            get loading() {
              return loading();
            },

            onClick: async () => {
              setLoading(true);
              await addChannelToProject(data?.forecast_project_id ?? '', selectedChannel());
              setLoading(false);
              setChannel();
            },

            get disabled() {
              return !selectedChannel();
            },

            children: "Add"
          }));

          return _el$5;
        })(), (() => {
          const _el$12 = _tmpl$5$1.cloneNode(true);
                _el$12.firstChild;

          insert(_el$12, createComponent(DataTable, {
            get items() {
              return data?.channels ?? [];
            },

            fallback: () => _tmpl$8.cloneNode(true),
            fields: [{
              text: 'Channel',
              value: 'channel_name',
              size: 10
            }, {
              text: 'Actions',
              size: 1,
              align: 'center',
              value: channel => createComponent(Btn, {
                btnType: "icon",
                onClick: () => confirmAndRemoveChannel(data?.forecast_project_id ?? '', channel),

                get children() {
                  return createComponent(Icon, {
                    children: "close"
                  });
                }

              })
            }]
          }), null);

          return _el$12;
        })()]
      });
    }

  });
};

delegateEvents(["input"]);

const QualificationState = external.enum(["active", "inactive", "expired"]);
const QualificationSource = external.enum(["croud_control", "360"]);
const QualificationSchema = external.object({
  id: external.string(),
  name: external.string(),
  description: external.string().nullable(),
  source: QualificationSource,
  state: QualificationState
});
external.object({
  limit: external.number().optional(),
  search: external.string().optional(),
  state: external.array(QualificationState).optional()
});
const QualificationListSchema = djangoListBaseSchema.extend({
  results: external.array(QualificationSchema)
});
const useQualificationList = () => {
  const filterStore = createStore({
    search: "",
    limit: 10,
    state: ["active"]
  });
  const [filters] = filterStore;
  const autoRefreshParams = createMemo(() => {
    return {
      search: filters.search,
      limit: filters.limit,
      ...filters.state?.length && {
        state: filters.state.join(",")
      }
    };
  });
  const resource = createResource(autoRefreshParams, (params) => platformAPI.get("qualifications", {
    searchParams: params
  }).then((res) => res.json()).then((r) => QualificationListSchema.parse(r)));
  return {
    filters: filterStore,
    resource
  };
};

const UserType = external.enum([
  "agency",
  "network"
]);
const UserSchema = external.object({
  id: external.string(),
  type: UserType,
  first_name: external.string().nullable(),
  last_name: external.string().nullable(),
  email: external.string().nullable()
});
const ModifiableValueModifier = external.enum(["and", "or"]);
const ModifiableValue = (value) => external.object({
  value,
  modifier: ModifiableValueModifier
});
const parseModifiedValue = (value, modifier) => {
  return `${modifier === "and" ? "*" : ""}${value}`;
};
external.object({
  search: external.string().optional(),
  type: UserType.optional(),
  qualifications: ModifiableValue(external.array(QualificationSchema)),
  clients: ModifiableValue(external.array(clientSchema)),
  limit: external.number().optional()
});
const UserListSchema = djangoListBaseSchema.extend({
  results: external.array(UserSchema)
});
const useUserList = (defaultFilters) => {
  const filterStore = createStore({
    search: void 0,
    type: void 0,
    limit: 10,
    qualifications: {
      value: [],
      modifier: "or"
    },
    clients: {
      value: [],
      modifier: "or"
    },
    ...defaultFilters
  });
  const [filters] = filterStore;
  const autoRefreshParams = createMemo(() => {
    return {
      search: filters.search,
      type: filters.type,
      ...filters.type === "network" && {
        ...filters.qualifications?.value.length && {
          qualification_id: parseModifiedValue(filters.qualifications?.value.map(({ id }) => id).join(","), filters.qualifications.modifier)
        },
        ...filters.clients.value.length && {
          client_id: parseModifiedValue(filters.clients.value.map(({ id }) => id).join(","), filters.clients.modifier)
        }
      }
    };
  });
  const resource = createResource(autoRefreshParams, (params) => {
    return platformAPI.get("users", {
      searchParams: params
    }).then((res) => res.json()).then((r) => UserListSchema.parse(r));
  });
  return {
    resource,
    filters: filterStore
  };
};

const _tmpl$$1 = template(`<div class="cui-flex-none cui-pl-2"></div>`),
      _tmpl$2$1 = template(`<div class="cui-flex cui-flex-grow cui-items-center"><div class="cui-flex-grow">Qualifications</div></div>`),
      _tmpl$3$1 = template(`<div class="cui-flex cui-justify-end"></div>`),
      _tmpl$4 = template(`<div class="cui-flex cui-flex-grow cui-items-center"><div class="cui-flex-grow">Clients</div></div>`),
      _tmpl$5 = template(`<div class="cui-mb-4"><h3 class="cui-text-2xl cui-mb-4">Croudie picker</h3></div>`),
      _tmpl$6 = template(`<div class="cui-w-9/12 cui-bg-gray-100 cui-py-2 cui-px-3"><div class="cui-flex cui-justify-end"></div></div>`);

const PickerModal = props => {
  const {
    resource: [userList],
    filters: [userFilters, setUserFilters]
  } = useUserList({
    type: 'network',
    search: ''
  });
  const {
    resource: [qualificationList],
    filters: [_, setQualificationFilters]
  } = useQualificationList();
  const {
    resource: [clientList],
    filters: [_clientFilters, setClientFilters]
  } = useClientList();

  const getUserType = (type, singular) => {
    switch (type) {
      case 'agency':
        return singular ? 'Employee' : 'Employees';

      case 'network':
        return singular ? 'Croudie' : 'Croudies';

      default:
        return '';
    }
  };

  const [expandedState, setExpadedState] = createStore({
    qualifications: {
      expanded: false,
      input: createSignal(undefined)
    },
    clients: {
      expanded: false,
      input: createSignal(undefined)
    }
  });
  return createComponent(Dialog, {
    ref(r$) {
      const _ref$ = props.ref;
      typeof _ref$ === "function" ? _ref$(r$) : props.ref = r$;
    },

    get show() {
      return props.show;
    },

    get onShowUpdate() {
      return props.onUpdateShow;
    },

    get children() {
      return createComponent(Sheet$1, {
        tag: "section",
        "class": "cui-flex cui-h-full cui-overflow-hidden",
        elevation: 24,

        get children() {
          return [createComponent(Sheet$1, {
            "class": "cui-h-full cui-w-3/12 cui-px-3 cui-py-3 cui-overflow-y-auto",

            get children() {
              const _el$ = _tmpl$5.cloneNode(true);
                    _el$.firstChild;

              insert(_el$, createComponent(SearchInput, {
                get value() {
                  return userFilters.search;
                },

                onInput: val => setUserFilters('search', val),

                get placeholder() {
                  return `Search by ${getUserType(userFilters.type, true)} name`;
                }

              }), null);

              insert(_el$, createComponent(ExpansionPanel, {
                get children() {
                  return [createComponent(ExpansionPanel.Item, {
                    get children() {
                      return [createComponent(ExpansionPanel.Item.Header, {
                        get children() {
                          return ["User type (", memo(() => getUserType(userFilters.type)), ")"];
                        }

                      }), createComponent(ExpansionPanel.Item.Content, {
                        get children() {
                          return createComponent(ButtonGroup, {
                            get value() {
                              return userFilters.type;
                            },

                            onInput: val => setUserFilters('type', val),

                            get children() {
                              return [createComponent(ButtonGroup.Button, {
                                value: 'network',

                                get children() {
                                  return getUserType('network');
                                }

                              }), createComponent(ButtonGroup.Button, {
                                value: 'agency',

                                get children() {
                                  return getUserType('agency');
                                }

                              })];
                            }

                          });
                        }

                      })];
                    }

                  }), createComponent(Show, {
                    get when() {
                      return userFilters.type === 'network';
                    },

                    get children() {
                      return [createComponent(ExpansionPanel.Item, {
                        get expanded() {
                          return expandedState.qualifications.expanded;
                        },

                        onUpdateExpanded: val => {
                          setExpadedState('qualifications', 'expanded', val);

                          if (val) {
                            expandedState.qualifications.input?.[0]()?.focus();
                          }
                        },

                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            get children() {
                              const _el$3 = _tmpl$2$1.cloneNode(true),
                                    _el$4 = _el$3.firstChild;
                                    _el$4.firstChild;

                              insert(_el$4, () => userFilters.qualifications.value.length ? ` (${userFilters.qualifications.value.length})` : '', null);

                              insert(_el$3, createComponent(Show, {
                                get when() {
                                  return userFilters.qualifications.value.length;
                                },

                                get children() {
                                  const _el$6 = _tmpl$$1.cloneNode(true);

                                  insert(_el$6, createComponent(Btn, {
                                    btnType: "text",
                                    size: "small",
                                    onClick: e => {
                                      setUserFilters('qualifications', {
                                        value: [],
                                        modifier: 'or'
                                      });
                                      setExpadedState('qualifications', 'expanded', false);
                                      e.stopPropagation();
                                    },
                                    children: "Clear"
                                  }));

                                  return _el$6;
                                }

                              }), null);

                              return _el$3;
                            }

                          }), createComponent(ExpansionPanel.Item.Content, {
                            get children() {
                              return [createComponent(AutoComplete, {
                                get forwardRef() {
                                  return expandedState.qualifications.input;
                                },

                                resource: qualificationList,
                                setFilters: setQualificationFilters,

                                get value() {
                                  return userFilters.qualifications.value;
                                },

                                multiple: true,
                                onInput: val => {
                                  return setUserFilters('qualifications', 'value', val);
                                }
                              }), (() => {
                                const _el$7 = _tmpl$3$1.cloneNode(true);

                                insert(_el$7, createComponent(ButtonGroup, {
                                  get value() {
                                    return userFilters.qualifications.modifier;
                                  },

                                  onInput: val => setUserFilters('qualifications', 'modifier', val),
                                  size: "small",

                                  get children() {
                                    return [createComponent(ButtonGroup.Button, {
                                      value: "and",
                                      children: "And"
                                    }), createComponent(ButtonGroup.Button, {
                                      value: "or",
                                      children: "Or"
                                    })];
                                  }

                                }));

                                return _el$7;
                              })()];
                            }

                          })];
                        }

                      }), createComponent(ExpansionPanel.Item, {
                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            children: "Hourly rate"
                          }), createComponent(ExpansionPanel.Item.Content, {})];
                        }

                      }), createComponent(ExpansionPanel.Item, {
                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            children: "Languages"
                          }), createComponent(ExpansionPanel.Item.Content, {})];
                        }

                      }), createComponent(ExpansionPanel.Item, {
                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            children: "Market verticals"
                          }), createComponent(ExpansionPanel.Item.Content, {})];
                        }

                      }), createComponent(ExpansionPanel.Item, {
                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            children: "Location"
                          }), createComponent(ExpansionPanel.Item.Content, {})];
                        }

                      }), createComponent(ExpansionPanel.Item, {
                        get expanded() {
                          return expandedState.clients.expanded;
                        },

                        onUpdateExpanded: val => {
                          setExpadedState('clients', 'expanded', val);

                          if (val) {
                            expandedState.clients.input?.[0]()?.focus();
                          }
                        },

                        get children() {
                          return [createComponent(ExpansionPanel.Item.Header, {
                            get children() {
                              const _el$8 = _tmpl$4.cloneNode(true),
                                    _el$9 = _el$8.firstChild;
                                    _el$9.firstChild;

                              insert(_el$9, () => userFilters.clients.value.length ? ` (${userFilters.clients.value.length})` : '', null);

                              insert(_el$8, createComponent(Show, {
                                get when() {
                                  return userFilters.clients.value.length;
                                },

                                get children() {
                                  const _el$11 = _tmpl$$1.cloneNode(true);

                                  insert(_el$11, createComponent(Btn, {
                                    btnType: "text",
                                    size: "small",
                                    onClick: e => {
                                      setUserFilters('clients', {
                                        value: [],
                                        modifier: 'or'
                                      });
                                      setExpadedState('clients', 'expanded', false);
                                      e.stopPropagation();
                                    },
                                    children: "Clear"
                                  }));

                                  return _el$11;
                                }

                              }), null);

                              return _el$8;
                            }

                          }), createComponent(ExpansionPanel.Item.Content, {
                            get children() {
                              return [createComponent(AutoComplete, {
                                get forwardRef() {
                                  return expandedState.clients.input;
                                },

                                resource: clientList,
                                setFilters: setClientFilters,

                                get value() {
                                  return userFilters.clients.value;
                                },

                                multiple: true,
                                onInput: val => {
                                  return setUserFilters('clients', 'value', val);
                                }
                              }), (() => {
                                const _el$12 = _tmpl$3$1.cloneNode(true);

                                insert(_el$12, createComponent(ButtonGroup, {
                                  get value() {
                                    return userFilters.clients.modifier;
                                  },

                                  onInput: val => setUserFilters('clients', 'modifier', val),
                                  size: "small",

                                  get children() {
                                    return [createComponent(ButtonGroup.Button, {
                                      value: "and",
                                      children: "And"
                                    }), createComponent(ButtonGroup.Button, {
                                      value: "or",
                                      children: "Or"
                                    })];
                                  }

                                }));

                                return _el$12;
                              })()];
                            }

                          })];
                        }

                      })];
                    }

                  })];
                }

              }), null);

              return _el$;
            }

          }), (() => {
            const _el$13 = _tmpl$6.cloneNode(true),
                  _el$14 = _el$13.firstChild;

            insert(_el$14, createComponent(Btn, {
              btnType: 'icon',
              onClick: () => props.onUpdateShow(false),

              get children() {
                return createComponent(Icon, {
                  children: "close"
                });
              }

            }));

            insert(_el$13, createComponent(ResourceLoader, {
              resource: userList,
              children: data => JSON.stringify(data)
            }), null);

            return _el$13;
          })()];
        }

      });
    }

  });
};

const _tmpl$ = template(`<link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">`),
      _tmpl$2 = template(`<style>@import "https://unpkg.com/@croud-ui/css/dist/main.min.css"; @import "https://unpkg.com/@croud-ui/solid-foundations/dist/style.css"</style>`),
      _tmpl$3 = template(`<div></div>`);

const WebComponentWrapper = props => {
  return [_tmpl$.cloneNode(true), _tmpl$2.cloneNode(true), memo(() => props.children)];
};

customElement('projects-admin', {}, () => {
  const Routes = useRoutes([{
    path: '/projects',
    component: () => createComponent(ProjectIndex, {}),
    children: [{
      path: '/',
      component: () => _tmpl$3.cloneNode(true)
    }, {
      path: '/:id',
      component: () => createComponent(ViewSidebar, {}),
      data: projectDataFunction
    }]
  }]);
  return createComponent(WebComponentWrapper, {
    get children() {
      return createComponent(Router, {
        base: "settings",

        get children() {
          return createComponent(Routes, {});
        }

      });
    }

  });
});
customElement('croudie-picker', {
  show: false
}, props => {
  let picker = undefined;
  return createComponent(WebComponentWrapper, {
    get children() {
      return createComponent(PickerModal, {
        ref(r$) {
          const _ref$ = picker;
          typeof _ref$ === "function" ? _ref$(r$) : picker = r$;
        },

        get show() {
          return props.show;
        },

        onUpdateShow: val => {
          picker?.dispatchEvent(new CustomEvent('update-show', {
            bubbles: true,
            cancelable: false,
            composed: true,
            detail: val
          }));
        }
      });
    }

  });
});
